%Function file for obtaining absorptance of active layer of OPV stack
function [Abstotal_check] = absorptance(nglass,nITO,nETL,nactivelayer,nHTL,nAl,...
    TotalNumberLayers,M,t,ActiveLayer1,stepDiff)

lambda_s = 5*(1:M) + 295; %Matrix holding wavelength values (nm)      
lambda_sm = (lambda_s)*10^-9;   %Matrix holding wavelength values (m)
TotalNumberLayers = TotalNumberLayers-1; %Total number of layers of OPV stack
Abstotal_check=zeros(M,90); %Absorptance of active layer
%Loop over wavelength
bb=1;
%cnt=0;
while bb <= M
    %if(cnt==0)
    lambda = lambda_sm(bb); %for every iteration across the wavelength sweep, the wavelength
    %from the matrix lambda_s is assigned to lambda.
    %Thickness of each layer of OPV stack (m)  
    n0 = 1;              % air
    n(1) = nglass(bb);   % glass 
    n(2) = nITO(bb);     % electrode
    n(3) = nETL(bb);     % ETL
    n(4) = nactivelayer(bb); % Active layer
    n(5) = nHTL(bb); % HTL
    n(6) = nAl(bb); % electrode
    n(7)=1; % air
    n(8)=1; % air
    nn=zeros(1,TotalNumberLayers); %Real part of refractive index across all layers for wavelength lambda
    k=zeros(1,TotalNumberLayers); %Extinction coefficient across all layers for wavelength lambda
    for g = 1:TotalNumberLayers
        nn(g) = real(n(g));
        k(g) = imag(n(g));
    end
    %end
    angle=zeros(90,1); %Matrix holding angle value in one degree increments (degree)
    % Loop over angle
    % FOR LOOP OVER ANGLE 
    for j = 1:90
        phi0 = (j-1)*pi/180; %Dummy variable holding angle of incidence increments
        angle(j,1) = (phi0*180)/pi;
        q0 = n0*cos(phi0); %Refractive index with the inclusion of angle for air
          %(given in Petterson paper)
        q=zeros(TotalNumberLayers+1,1); %Refractive index with the inclusion of angle for OPV layers
          %(given in Petterson paper)
        eta=zeros(TotalNumberLayers+1,1); %One portion of the layer phase thickness (eta*t) 
        L=zeros(2,2,TotalNumberLayers); %Layer matrix from transfer matrix modelling
        for g = 1:TotalNumberLayers
            q(g,1) = ((n(g))^2 - ((n0)^2*(sin(phi0))^2))^0.5; 
            eta(g,1) = ((2*pi)/(lambda))*q(g,1);
            L(:,:,g) = [(exp(-1i*eta(g,1)*t(g))),(0);(0),(exp(1i*eta(g,1)*t(g)))];
        end
        q(g+1,1) = ((n(g+1))^2 - ((n0)^2*(sin(phi0))^2))^0.5;  
        eta(g+1,1) = ((2*pi)/(lambda))*q(g+1,1);           
        phi(1,1) = asin(sin(phi0)*n0/n(1)); %Snell's law to find change in angle of incidence with layers in the opv
        for g=2:TotalNumberLayers+1
            phi(g,1) = asin(sin(phi(g-1,1))*n(g-1)/n(g));
        end
        rp=zeros(1,TotalNumberLayers+1); %Reflection coefficient for p polarised light
        rs=zeros(1,TotalNumberLayers+1); %Reflection coefficient for s polarised light
        tp=zeros(1,TotalNumberLayers+1); %Transmission coefficient for p polarised light
        ts=zeros(1,TotalNumberLayers+1); %Transmission coefficient for s polarised light
        rp(1) = (((n(1))*cos(phi0)) - ((n0)*cos(phi(1,1))))/(((n(1))*cos(phi0)) + ((n0)*cos(phi(1,1))));  
        rs(1) = ((q0 - q(1))/(q0 + q(1)));
        tp(1) = (2*q0)/((n(1)*cos(phi0)) + ((n0)*cos(phi(1,1)))); 
        ts(1) = ((2*q0)/(q0 + q(1)));
        for g = 2:TotalNumberLayers+1
            rp(g) = (((n(g))*cos(phi(g-1,1))) - ((n(g-1))*cos(phi(g,1))))/(((n(g))*cos(phi(g-1,1))) + ((n(g-1))*cos(phi(g,1))));  
            rs(g) = ((q(g-1,1) - q(g,1))/(q(g-1,1) + q(g,1)));
            tp(g) = (2*q(g-1,1))/((n(g)*cos(phi(g-1,1))) + ((n(g-1))*cos(phi(g,1)))); 
            ts(g) = ((2*q(g-1,1))/(q(g-1,1) + q(g,1)));
        end  
        Ip=zeros(2,2,TotalNumberLayers+1); %Interface matrix for p polarised light
        Is=zeros(2,2,TotalNumberLayers+1); %Interface matrix for s polarised light
        for g = 1:TotalNumberLayers+1
              Ip(:,:,g) = [(1/tp(g)),(rp(g)/tp(g));(rp(g)/tp(g)),(1/tp(g))]; 
              Is(:,:,g) = [(1/ts(g)),(rs(g)/ts(g));(rs(g)/ts(g)),(1/ts(g))];  
        end
        S_mp(:,:,2) = Ip(:,:,2);  %Product of Ip and Lm for p polarized light starting from the
         %coherent layers after the first layer of glass upto just before the second
         %glass layer  
        S_ms(:,:,2) = Is(:,:,2); %Product of Is and Lm for s polarized light starting from the
         %coherent layers after the first layer of glass upto just before the second
         %glass layer  
        for g = 3:TotalNumberLayers
            S_mp(:,:,g) = S_mp(:,:,g-1)*L(:,:,g-1)*Ip(:,:,g);
            S_ms(:,:,g) = S_ms(:,:,g-1)*L(:,:,g-1)*Is(:,:,g);
        end
        S_pp(:,:,2) = ((Ip(:,:,2)*L(:,:,2))^-1)*S_mp(:,:,TotalNumberLayers);
        S_ps(:,:,2) = ((Is(:,:,2)*L(:,:,2))^-1)*S_ms(:,:,TotalNumberLayers);
        for g = 3:TotalNumberLayers
            S_pp(:,:,g) = ((Ip(:,:,g)*L(:,:,g))^-1)*S_pp(:,:,g-1);
            S_ps(:,:,g) = ((Is(:,:,g)*L(:,:,g))^-1)*S_ps(:,:,g-1);
        end
        SSp = S_mp(:,:,TotalNumberLayers); %Consists of S matrix for p polarised light upto the
          %second glass layer
        SSs = S_ms(:,:,TotalNumberLayers); %Consists of S matrix for s polarised light upto the second glass layer      
        r10p = (((n(1)^2)*q0 - (n0^2)*q(1,1))/((n0^2)*q(1,1) + (n(1)^2)*q0)); %Reflection coefficient for first layer of glass for p polarised light
        t10p = (2*n(1)*n0*q(1,1))/((n0^2)*q(1,1) + (n(1)^2)*q0); %Transmission coefficient for first layer of glass for p polarised light
        Ibar01p = (1/(abs(tp(1)))^2)*[1,-(abs(r10p*conj(r10p)));(abs(rp(1)))^2,((abs(tp(1)*conj(t10p)))^2 - (abs(rp(1)*conj(r10p)))^2)]; %Interface matrix for glass-air interface 
        %for p polarised light
        Lbar1 = [(abs(exp(-1i*eta(1,1)*t(1))))^2,0;0,(abs(exp(1i*eta(1,1)*t(1))))^2]; %Layer matrix for first layer of glass
           
        % Ibar12p turns the rest of the matrix into an interface matrix element
        Ibar12p = [(abs(SSp(1,1)))^2,-(abs(SSp(1,2))^2);(abs(SSp(2,1)))^2,(((abs(det(SSp)))^2 - (abs(SSp(1,2)*SSp(2,1)))^2)/((abs(SSp(1,1)))^2))];
        %Conversion of coherent interface into incoherent interface for p polarised light
        Sbarip = Ibar12p; %Conversion of coherent interface into incoherent interface for p polarised light
        Sbarp(:,:,bb,j) = Ibar01p*Lbar1*Ibar12p; %Final S matrix for p polarised light
        IntAdjp = [1,0]*Sbarip*[1/Sbarp(1,1,bb,j);0]; %Drop in electric field due to the incoherent layer of p polarised light
        IglassITOp(bb,j) = IntAdjp; %Drop in electric field due to the incoherent layer of p polarised light
           
           % Incoherent layers - glass S
        r10s = ((q(1,1) - q0)/(q(1,1) + q0)); %Reflection coefficient for first layer of glass for s polarised light
        t10s = ((2*q(1,1))/(q(1,1) + q0)); %Transmission coefficient for first layer of glass for s polarised light
        Ibar01s = (1/(abs(ts(1)))^2)*[1,-(abs(r10s*conj(r10s)));(abs(rs(1)))^2,((abs(ts(1)*conj(t10s)))^2 - (abs(rs(1)*conj(r10s)))^2)]; 
        %%Interface matrix for glass-air interface for s polarised light
        Lbar1 = [(abs(exp(-1i*eta(1,1)*t(1))))^2,0;0,(abs(exp(1i*eta(1,1)*t(1))))^2]; %Layer matrix for first layer of glass
           
           % Ibar12s turns the rest of the matrix into an interface matrix element
        Ibar12s = [(abs(SSs(1,1)))^2,-(abs(SSs(1,2))^2);(abs(SSs(2,1)))^2,(((abs(det(SSs)))^2 - (abs(SSs(1,2)*SSs(2,1)))^2)/((abs(SSs(1,1)))^2))];
        %%Conversion of coherent interface into incoherent interface for s polarised light
        Sbaris = Ibar12s; %%Conversion of coherent interface into incoherent interface for s polarised light
        Sbars(:,:,bb,j) = Ibar01s*Lbar1*Ibar12s; %Final S matrix for s polarised light
        IntAdjs = [1,0]*Sbaris*[1/Sbars(1,1,bb,j);0]; %Drop in electric field due to the incoherent layer of s polarised light
        IglassITOs(bb,j) = IntAdjs; %Drop in electric field due to the incoherent layer of s polarised light
        ttp = 1/SSp(1,1); %Transmittance of OPV stack for p polarized light considering cohenerent interface
        tts = 1/SSs(1,1); %Transmittance of OPV stack for s polarized light considering cohenerent interface

        D=zeros(1,TotalNumberLayers); %Total number of steps within each layer of OPV stack when calculating absorptance
        Absorption_p=zeros(1,TotalNumberLayers); %Absorptance of p polarized light in each layer of OPV stack
        Absorption_s=zeros(1,TotalNumberLayers); %Absorptance of s polarized light in each layer of OPV stack
        Absorptotal_p=zeros(1,TotalNumberLayers); %Total absorptance of p polarized light in OPV stack
        Absorptotal_s=zeros(1,TotalNumberLayers); %Total absorptance of s polarized light in OPV stack
        Absnet=zeros(1,TotalNumberLayers);        %Total absorptance of unpolarized light
        for g = ActiveLayer1:ActiveLayer1 %We want absorptance only over the active layer to calculate power generated in the OPV stack
            step = stepDiff; %Step length assigned to step to measure absorptance across the OPV layer of the stack        
            D(g) = t(g)/step;       
            D(g) = round(D(g));
            EEp=zeros(1,D(g)); %Resultant of the electric fields Ep1 and Ep2
            ABSp=zeros(1,D(g)); %Absorption of p polarised light in layer
            EEs=zeros(1,D(g)); %Resultant of the electric field Es
            ABSs=zeros(1,D(g)); %Absorption of s polarised light in layer
            for v = 1:D(g)
                x = v*step; %Considering a particular point within the layer under consideration in the OPV stack
                L_active = [(exp(-i*eta(g,1)*(t(g) - x))),(0);(0),(exp(i*eta(g,1)*(t(g) - x)))]; %Layer matrix at that particular point
                Mp = L_active*S_pp(:,:,g); %Transfer matrix model upto the point considered by x for p polarized light.
                Ep1 = ttp*(Mp(1,1) + Mp(2,1))*cos(phi(g,1)); %Electric field of p-polarised light-perpendicular to
                %the plane of the OPV  
                Ep2 = ttp*(Mp(1,1) - Mp(2,1))*sin(phi(g,1)); %Electric field of p-polarised light-perpendicular to
                %the plane of the OPV
                EEp(v) = abs(Ep1)^2 + abs(Ep2)^2;
                ABSp(v) = ((4*pi*nn(g)*k(g))/(lambda*cos(phi0)))*EEp(v);
                Ms = L_active*S_ps(:,:,g); %Transfer matrix model upto the point considered by x for s polarized light.
                Es = tts*(Ms(1,1) + Ms(2,1)); %Electric field of s-polarised light-parallel to the plane of the OPV 
                EEs(v) = abs(Es)^2; %Resultant of the electric fields Es
                ABSs(v) = ((4*pi*nn(g)*k(g))/(lambda*cos(phi0)))*EEs(v);      
            end
            Ap=zeros(TotalNumberLayers,D(g)); %Absorptance for p polarized light in each layer for every step in OPV stack
            As=zeros(TotalNumberLayers,D(g)); %Absorptance for s polarized light in each layer for every step in OPV stack
            for v = 1:D(g)
                Ap(g,v) = ABSp(v)*step;
                As(g,v) = ABSs(v)*step;
            end
            Absorption_p(g) = IglassITOp(bb,j)*sum(Ap(g,:));
            Absorption_s(g) = IglassITOs(bb,j)*sum(As(g,:));
            Absorptotal_p(g) = Absorption_p(g);
            Absorptotal_s(g) = Absorption_s(g);
            Absnet(g)=(Absorptotal_p(g)+Absorptotal_s(g))/2;
        end
           Abstotal_check(bb,j) = Absnet(4);
           
    end
           bb=bb+1;
end    
end


