%Calculates water consumption during evaporative cooling
function [watercons_evap]=evapcooling_water(dena,V,ns,Aground,Tao,rhao,efficiencyevap)

Twb=(Tao*atan(0.151977*(rhao+8.313659)^0.5))+atan(Tao+rhao)-...
    atan(rhao-1.676331)+(0.00391838*((rhao)^(1.5))*atan(0.023101*rhao))...
    -4.686035; % Wet-bulb temperature (C)

Paosat_evap=exp((-5800.2206/(Twb+273.15))+1.3914993-....
(0.04860239*(Twb+273.15))+(0.41764768e-4*((Twb+273.15)^2))...
-(0.14452093e-7*((Twb+273.15)^3))+(6.5459673*log((Twb+273.15)))); %Saturation pressure of outside air at
% Wet bulb temperature(Pa)

Paosat=exp((-5800.2206/(Tao+273.15))+1.3914993-....
(0.04860239*(Tao+273.15))+(0.41764768e-4*((Tao+273.15)^2))...
-(0.14452093e-7*((Tao+273.15)^3))+(6.5459673*log((Tao+273.15)))); %Saturation pressure of outside air at
% ambient temperature(Pa)

Pao_act = (rhao/100)*Paosat; %Partial pressure accounting for relative humidity of outside air (Pa)

qout=Pao_act*0.622/101325; 

wout = qout/(1-qout); %Humidity ratio of outside air

Paosat_evapact = Pao_act+(efficiencyevap*(Paosat_evap-Pao_act)); %determining saturation pressure based on
%whether evaporation cooling pad is active or not

qin=Paosat_evapact*0.622/101325;

win = qin/(1-qin); %Determining corresponding humidity ratio

Volflow=ns*V/Aground; %Air flow rate per unit area (m/s)

watercons_evap = dena*Volflow*(win-wout); %Amount of water consumption per unit area (kg/m2-s)
end