%Function for calculating relative humidity beneath shades inside
%greenhouse
function [trans,vent,infiltration,rhnew,mhum] = humidity(efficiencyevap,Aground,achinf,...
    timestep,dena,cpa,fp,rh,Tao,rhao,ns,V,P,L,LAI,Netenergy,c1,c2,c3,c4,c5,c6,Told)

Tdp=(Tao.*atan(0.151977*(rhao+8.313659).^0.5))+atan(Tao+rhao)-...
    atan(rhao-1.676331)+(0.00391838*((rhao).^(1.5)).*atan(0.023101*rhao))...
    -4.686035;%Dew-point temperature (C)
Tdp=(efficiencyevap*Tdp)+(Tao.*(1-efficiencyevap)); %Accounting for evaporative efficiency
Pai=rh*exp((-5800.2206/(Told(3)+273.15))+1.3914993-(0.04860239*(Told(3)+273.15))...
    +(0.41764768e-4*((Told(3)+273.15)^2))-(0.14452093e-7*((Told(3)+273.15)^3))+...
    (6.5459673*log((Told(3)+273.15)))); %Vapor pressure of air inside the greenhouse (Pa)
Paisat=exp((-5800.2206/(Told(3)+273.15))+1.3914993-(0.04860239*(Told(3)+273.15))...
    +(0.41764768e-4*((Told(3)+273.15)^2))-(0.14452093e-7*((Told(3)+273.15)^3))+...
    (6.5459673*log((Told(3)+273.15)))); %Saturated vapor pressure of air inside the 
%greenhouse (Pa)
eai=0.622*Pai/(P-Pai); %Humidity ratio of air inside the greenhouse
Pao=(rhao/100)*exp((-5800.2206/(Tao+273.15))+1.3914993-(0.04860239*(Tao+273.15))...
    +(0.41764768e-4*((Tao+273.15)^2))-(0.14452093e-7*((Tao+273.15)^3))+...
    (6.5459673*log((Tao+273.15)))); %Vapor pressure of air outside the greenhouse (Pa)
Paosat=exp((-5800.2206/(Tdp+273.15))+1.3914993-(0.04860239*(Tdp+273.15))...
    +(0.41764768e-4*((Tdp+273.15)^2))-(0.14452093e-7*((Tdp+273.15)^3))+...
    (6.5459673*log((Tdp+273.15)))); %Saturated vapor pressure of air outside the greenhouse
%(Pa)
Pv=exp((-5800.2206/(Told(2)+273.15))+1.3914993-(0.04860239*(Told(2)+273.15))...
    +(0.41764768e-4*((Told(2)+273.15)^2))-(0.14452093e-7*((Told(2)+273.15)^3))+...
    (6.5459673*log((Told(2)+273.15)))); %Vapor pressure of vegetation (Pa)

Ig=0.25*Netenergy/Aground; %Solar insolation absorbed by plants (W/m2)

%Computing transpiration below
a=c1*log(1+(c2*(LAI^c3)));
ht=c4*LAI*(1-(c5*exp(-Ig/c6)));
if(Pv<Pai)
    trans=(a/L)*Ig*timestep*L;
else
    trans=(a/L)*Ig*timestep*L+(ht*timestep*(Pv-Pai)*L/(L*0.665e-3*P));
end
%Computing transpiration above

%Account for vapor pressure of air entering the greenhouse when evaporative
%cooling is on
if(fp==1)
Paovent=Pao+(efficiencyevap*(Paosat-Pao));

else

Paovent=Pao;
end
vent=dena*cpa*(ns*V/Aground)*(Pai-Paovent)/(0.665e-3*P); %Latent energy due to ventiation
%(J/m2)
infiltration=dena*cpa*timestep*(achinf*V/(3600*Aground))*(Pai-Pao)/(0.665e-3*P);
%Latent energy due to infiltration (J/m2)
mdryair=(P-Pai)*V/(287*(Told(3)+273.15)); %Mass of air excluding the water content inside
%the greenhouse (kg)
mdryairarea=mdryair/Aground; %Mass per unit area of air excluding the water content inside
%the greenhouse (kg/m2)
mwaterairarea=eai*mdryairarea; %Water content per unit area in air (kg/m2)
mwater=((trans-infiltration-vent)/(L)); %Computing water content in the air after changes
%due to transpiration, ventilation and infiltration (kg/m2)
mwatercurrent=mwaterairarea+mwater; %Updated value after accounting for mwater (kg/m2)
eaicurrent=mwatercurrent/mdryairarea; %Updated value of humidity ratio 
Painew=(P*eaicurrent)/(0.622+eaicurrent); %Vapor pressure of air (Pa)
rhnew=Painew/Paisat; %Updated relative humidity
mhum=0;
%Loop that makes sure, relative humidity never exceeds 1 (not possible
%realistically) or drops below 60% (control limit)

%% Humidity control to ensure relative humidity is above 60 %.
if(rhnew>1)
    rhnew=1;
end
if(rhnew<0.6)
    Painow=Painew;
    mwaternow=Painow*V/(461.5*(Told(3)+273.5));
    rhnew=0.6;
    Paimod=rhnew*exp((-5800.2206/(Told(3)+273.15))+1.3914993-(0.04860239*(Told(3)+273.15))...
    +(0.41764768e-4*((Told(3)+273.15)^2))-(0.14452093e-7*((Told(3)+273.15)^3))+...
    (6.5459673*log((Told(3)+273.15))));
    mwaterairmod=Paimod*V/(461.5*(Told(3)+273.5));    
    mhum=(mwaterairmod)-(mwaternow);
    mhum=mhum/Aground;
    
end

end

