%Function to calculate relative humidity of air above shades 
function rhnew = humidityup(Aground,achinf,timestep,dena,cpa,rh,Tao,rhao,V,P,L,Told)

Pai=rh*exp((-5800.2206/(Told(7)+273.15))+1.3914993-(0.04860239*(Told(7)+273.15))...
    +(0.41764768e-4*((Told(7)+273.15)^2))-(0.14452093e-7*((Told(7)+273.15)^3))+...
    (6.5459673*log((Told(7)+273.15)))); %Vapor pressure of air inside the greenhouse (Pa)

Paisat=exp((-5800.2206/(Told(7)+273.15))+1.3914993-(0.04860239*(Told(7)+273.15))...
    +(0.41764768e-4*((Told(7)+273.15)^2))-(0.14452093e-7*((Told(7)+273.15)^3))+...
    (6.5459673*log((Told(7)+273.15)))); %Saturated vapor pressure of air inside the 
%greenhouse (Pa)

Pao=(rhao/100)*exp((-5800.2206/(Tao+273.15))+1.3914993-(0.04860239*(Tao+273.15))...
    +(0.41764768e-4*((Tao+273.15)^2))-(0.14452093e-7*((Tao+273.15)^3))+...
    (6.5459673*log((Tao+273.15)))); %Vapor pressure of air outside the greenhouse (Pa)
eai=0.622*Pao/(P-Pao); %Humidity ratio of air inside the greenhouse

infiltration=dena*cpa*timestep*(achinf*V/(3600*Aground))*(Pai-Pao)/(0.665e-3*P); 
%Latent energy due to infiltration (J/m2)
mdryair=(P-Pai)*V/(287*(Told(7)+273.15)); %Mass of air excluding the water content inside
%the greenhouse (kg)
mdryairarea=mdryair/Aground; %Mass per unit area of air excluding the water content inside
%the greenhouse (kg/m2)
mwaterairarea=eai*mdryairarea; %Water content per unit area in air (kg/m2)
mwater=((-infiltration)/(L)); %Computing water content in the air after changes
%due to infiltration (kg/m2)
mwatercurrent=mwaterairarea+mwater; %Updated value after accounting for mwater (kg/m2)
eaicurrent=mwatercurrent/mdryairarea; %Humidity ratio of air inside the greenhouse
Painew=(P*eaicurrent)/(0.622+eaicurrent); %Vapor pressure of air (Pa)
rhnew=Painew/Paisat;  %Updated relative humidity

if(rhnew>1)
    rhnew=1;
end

end

