%Function file to compute temperature of all components in a greenhouse.
%This function file is for computing the case scenario when shades are not
%rolled out
function F = hvac_fnroof2(heat_totallamps,achinf,Netenergyroofabs,timestep,Cg,Aground,peri_heatloss,Perimeter,kroof,troof,transmittance_roof,transmittance_wall,Rij,ts1,ts2,Fvcplant,Qbenchheat,Ts,Mp,cpw,Tao,dena,cpa,P,...
    L,rh,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,ho,LAI,TA,v,Twb,Q,Netenergy,c1,c2,c3,c4,c5,c6,Awalls,x)


Ac=Ac*0.85;
Uroof=1/((troof/kroof));
Rbb(1) = sig*(x(6)+273.5)^4; %Radiation from ground. For dry ground, radiation temperature 
%is considered equivalent to the wall/roof temperature
Rti(1) = (Rij/2)*(1+cos((90-TA)*pi()/180))+((Rbb(1)/2)*(1-cos((90-TA)*pi()/180))); %Net reflected and 
%radiation from sky
eai = rh*(0.004055+(0.0001152*x(3))+(0.00002167*x(3)*x(3))); %same for air inside the greenhouse
Pai = (eai*P)/(0.62198+eai);%Partial pressure for air
ev  = 0.004055+(0.0001152*x(2))+(0.00002167*x(2)*x(2));%Humidity ratio for vegetation
Pv = (ev*P)/(0.62198+ev);%Partial pressure for vegetation
hgai = (1.38*(abs((x(1)-x(3)))^(1/3))); %Internal convection heat transfer coefficient 
%between ground and air
hacl = (1.38*(abs((x(3)-x(4)))^(1/3))); %Internal convection heat transfer coefficient 
%between roof and air
hcip = (1.38*(abs((x(2)-x(3)))^(1/3))); %Internal convection heat transfer coefficient 
%between plant and air
Ig=0.25*Netenergy/(Aground); %Solar insolation absorbed by plants

%Transpiration calculation 
a=c1*log(1+(c2*(LAI^c3)));
ht=c4*LAI*(1-(c5*exp(-Ig/c6)));
if(Pv<Pai)
    trans=(a/L)*Ig*L;
else
    trans=(a/L)*Ig*L+(ht*(Pv-Pai)*L/(L*0.665e-3*P));
end

%Energy balance is as given below. Equations discussed in detail in the
%supporting information. Componenets inside the greenhouse is as described
%below:

%1-Top surface of ground
%2-Vegetation
%3-Air beneath the shades inside the greenhouse
%4-Inner surface of roof
%5-Inner surface of ground
%6-Outer surface of roof (Inner and outer surface of roof can be combined
%as well- This is explained in the supporting information)
%7-Air above the shades inside the greenhouse
F(1) = -(hgai*timestep*(x(1)-x(3)))-...
       (Ev*timestep*sig*((x(1)+273.5)^4-(x(2)+273.5)^4))-...
       ((kg*timestep*(x(1)-x(5)))/ts1)-...
          (peri_heatloss*timestep*Perimeter*(x(1)-Tao)/Aground);




   
F(2) = (timestep*Qbenchheat)+(0.25*timestep*Netenergy/(Aground)) - Ev*timestep*sig*((x(2)+273.5)^4-(x(1)+273.5)^4)-...
        (hcip*timestep*(x(2)-x(3)))...
        -(timestep*trans)-...
        sig*timestep*Ec*Fvcplant*((x(2)+273.5)^4-(x(4)+273.5)^4)-sig*timestep*transmittance_roof*Ev*((x(2)+273.5)^4-Ts^4)...
        -sig*timestep*transmittance_wall*Ev*((x(2)+273.5)^4-Ts^4)-((Mp*cpw*(x(2)-Told(2))));

     
F(3) = (0.5*timestep*Netenergy/(Aground))+(hcip*timestep*(x(2)-x(3)))+(hgai*(x(1)-x(3)))-...
        (((dena*timestep*cpa*v/Aground)*(((x(3)-Twb)*fp)-...
        ((Tao-x(3))*(1-fp)))))-hacl*timestep*((Ac)/Aground)*(x(3)-x(4))-...
        (dena*achinf*cpa*timestep*(V/(Ac*3600))*(x(3)-Tao))*(Ac/Aground)-...
          ((dena*cpa*V*(x(3)-Told(3)))/Aground)+(timestep*Q)+(timestep*heat_totallamps);

                  
F(4)= (0.25*timestep*Netenergyroofabs)-hacl*((Ac+Awalls)/Aground)*timestep*(x(4)-x(3))-Fvcplant*sig*timestep*((x(4)+273.5)^4-(x(2)+273.5)^4)-...
      Uroof*timestep*((Ac+Awalls)/Aground)*((x(4)-x(6)));

F(5) = kg*timestep*(x(1)-x(5))/ts1-kg*timestep*(x(5)-Tgw)/ts2-(Cg*tg*(x(5)-Told(5)));

F(6)=(0.25*timestep*Netenergyroofabs)+Uroof*timestep*((Ac+Awalls)/Aground)*((x(4)-x(6)))-(ho*timestep*((Ac+Awalls)/Aground)*(x(6)-Tao))-...
      (Ec*timestep*((Ac+Awalls)/Aground)*((sig*(x(6)+273.5)^4)-Rti(1)));
  
F(7)=x(7)-x(3);

end

