%Function file to compute temperature of all components in a greenhouse.
%This function file is for computing the case scenario when shades are 
%rolled out - Component nomenclature is explained in hvac_fnroof2 function
%file
function F = hvac_fnroofshade2(heat_totallamps,achinf,Netenergyroofabs,timestep,Cg,Aground,peri_heatloss,Perimeter,kroof,troof,transmittance_roof,transmittance_wall,Rij,ts1,ts2,Fvcplant,Qbenchheat,Netenergyroof,Ts,...
    Mp,cpw,Tao,dena,cpa,P,L,rh,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,V1,ho,LAI,TA,v,Twb,Q,Netenergy,tnsmvty,c1,c2,c3,c4,c5,c6,Awalls,x)
Ac=Ac*0.85; %roof glass area.
Uroof=1/((troof/kroof));
Rbb(1) = sig*(x(6)+273.5)^4; %Radiation from ground. For dry ground, radiation temperature is considered equivalent to the wall/roof temperature
%Rbb(2) = sig*(x(6)+273.5)^4;
%Net reflected and radiation from sky
Rti(1) = (Rij/2)*(1+cos((90-TA)*pi()/180))+((Rbb(1)/2)*(1-cos((90-TA)*pi()/180)));
%Rti(2) = (Rij/2)*(1+cos((90-TA)*pi()/180))+((Rbb(2)/2)*(1-cos((90-TA)*pi()/180)));
eai = rh*(0.004055+(0.0001152*x(3))+(0.00002167*x(3)*x(3))); %same for air inside the greenhouse
Pai = (eai*P)/(0.62198+eai);%Partial pressure for air
ev  = 0.004055+(0.0001152*x(2))+(0.00002167*x(2)*x(2));%Humidity ratio for vegetation
Pv = (ev*P)/(0.62198+ev);%Partial pressure for vegetation
hgai = (1.38*(abs((x(1)-x(3)))^(1/3))); %Internal convection heat transfer coefficient between ground and air
hcla = (1.38*(abs((x(7)-x(4)))^(1/3)));
hcip = (1.38*(abs((x(2)-x(3)))^(1/3))); %Internal convection heat transfer coefficient between plant and air
haa = (1.38*(abs((x(3)-x(7)))^(1/3)));
Netenergywall=Netenergy-Netenergyroof;
Netenergybelow=(tnsmvty*Netenergyroof)+Netenergywall;
Ig=0.25*Netenergybelow/(Aground);
a=c1*log(1+(c2*(LAI^c3)));
ht=c4*LAI*(1-(c5*exp(-Ig/c6)));
if(Pv<Pai)
    trans=(a/L)*Ig*L;
else
    trans=(a/L)*Ig*L+(ht*(Pv-Pai)*L/(L*0.665e-3*P));
end

F(1) = -(hgai*timestep*(x(1)-x(3)))-...
       (Ev*sig*timestep*((x(1)+273.5)^4-(x(2)+273.5)^4))-...
       ((kg*timestep*(x(1)-x(5)))/ts1)-...
          (peri_heatloss*timestep*Perimeter*(x(1)-Tao)/Aground);

    F(2) =(timestep*Qbenchheat)+(0.25*timestep*Netenergybelow/(Aground)) - ...
        Ev*sig*timestep*((x(2)+273.5)^4-(x(1)+273.5)^4)-...
        (hcip*timestep*(x(2)-x(3)))-...
        Ev*timestep*sig*Fvcplant*tnsmvty*((x(2)+273.5)^4-(x(4)+273.5)^4)...
        -(timestep*trans)-sig*timestep*transmittance_roof*Ev*tnsmvty*((x(2)+273.5)^4-Ts^4)...
        -sig*timestep*transmittance_wall*Ev*tnsmvty*((x(2)+273.5)^4-Ts^4)-...
        ((Mp*cpw*(x(2)-Told(2))));

   
     
F(3) = (0.5*timestep*Netenergybelow/(Aground))+(hcip*timestep*(x(2)-x(3)))+...
    (hgai*timestep*(x(1)-x(3)))-...
        (((dena*cpa*timestep*v/Aground)*(((x(3)-Twb)*fp)-...
        ((Tao-x(3))*(1-fp)))))-haa*timestep*tnsmvty*(x(3)-x(7))-...
        (dena*achinf*cpa*timestep*(V1/(Ac*3600))*(x(3)-Tao))*(Ac/Aground)-...
          ((dena*cpa*V1*(x(3)-Told(3)))/Aground)+(timestep*Q)+...
          (timestep*heat_totallamps);

                  
F(4)= (0.25*timestep*Netenergyroofabs)+...
    Ev*sig*timestep*Fvcplant*tnsmvty*((x(2)+273.5)^4-(x(4)+273.5)^4)-...
    hcla*timestep*((Ac+Awalls)/Aground)*(x(4)-x(7))-...
      Uroof*timestep*((Ac+Awalls)/Aground)*((x(4)-x(6)));

F(5) = kg*timestep*(x(1)-x(5))/ts1-kg*timestep*(x(5)-Tgw)/ts2-...
    (Cg*tg*(x(5)-Told(5)));

F(6)=(0.25*timestep*Netenergyroofabs)+Uroof*timestep*((Ac+Awalls)/Aground)*((x(4)-x(6)))-...
    (ho*timestep*((Ac+Awalls)/Aground)*(x(6)-Tao))-...
     (Ec*timestep*((Ac+Awalls)/Aground)*((sig*(x(6)+273.5)^4)-Rti(1)));

F(7)=((1-tnsmvty)*timestep*0.5*Netenergyroof/Aground)+...
    haa*timestep*tnsmvty*(x(3)-x(7))+...
    hcla*timestep*((Ac+Awalls)/Aground)*(x(4)-x(7))-...
        (dena*achinf*cpa*timestep*((V-V1)/(Ac*3600))*(x(7)-Tao))*(Ac/Aground)...
        -((dena*cpa*(V-V1)*(x(7)-Told(7)))/Aground);

end

