%Function to obtain reflectance and transmittance of OPV stack
function [R,T] = optics(nglass,nITO,nETL,nactivelayer,nHTL,nAl,nglass2,...
    a,final,TotalNumberLayers,M,t)

T=zeros(M,90); %Total transmittance of OPV stack across wavelength and angle sweep
R=zeros(M,90); %Total reflectance of OPV stack across wavelength and angle sweep                      
lambda_s = 5*(1:M) + 295;  %Matrix holding wavelength values (nm)     
lambda_sm = (lambda_s)*10^-9; %Matrix holding wavelength values (m)     
%Loop over wavelength
for bb = 1:M  
   %Refractive index data
    n0 = 1; % air        
    n(1) = nglass(bb);  % glass  
    n(2) = nITO(bb); % electrode
    n(3) = nETL(bb); % ETL
    n(4) = nactivelayer(bb); % Active layer
    n(5) = nHTL(bb); % HTL
    n(6) = nAl(bb);  % electrode
    n(7) = nglass2(bb); % glass
    n(8)=1; % air
    n(9)=1; % air
    lambda = lambda_sm(bb); %for every iteration across the wavelength sweep, the wavelength
    %from the matrix lambda_s is assigned to lambda.
    nn=zeros(TotalNumberLayers+1,1); %Real part of refractive index across all layers for wavelength lambda
    k=zeros(TotalNumberLayers+1,1); %Extinction coefficient across all layers for wavelength lambda
    for g = 1:TotalNumberLayers+1
        nn(g) = real(n(g));
        k(g) = imag(n(g));
    end
    angle=zeros(90,1); %Matrix holding angle value in one degree increments (degree)
    % Loop over angle
    for j = 1:90    
          phi0 = (j-1)*pi/180; %Dummy variable holding angle of incidence increments
          angle(j,1) = (phi0*180)/pi; 
          q0 = n0*cos(phi0); %Refractive index with the inclusion of angle for air
          %(given in Petterson paper)
          q=zeros(TotalNumberLayers+1,1); %Refractive index with the inclusion of angle for OPV layers
          %(given in Petterson paper)
          eta=zeros(TotalNumberLayers+1,1); %One portion of the layer phase thickness (eta*t) 
          Lm=zeros(2,2,TotalNumberLayers); %Layer matrix from transfer matrix modelling 
          for g = 1:TotalNumberLayers             
              q(g,1) = ((n(g))^2 - ((n0)^2*(sin(phi0))^2))^0.5; 
              eta(g,1) = ((2*pi)/(lambda))*q(g,1); 
              Lm(:,:,g) = [(exp(-1i*eta(g,1)*t(g))),(0);(0),(exp(1i*eta(g,1)*t(g)))]; 
          end
          q(g+1,1) = ((n(g+1))^2 - ((n0)^2*(sin(phi0))^2))^0.5;
          eta(g+1,1) = ((2*pi)/(lambda))*q(g+1,1);         
          phi(1,1) = asin(sin(phi0)*n0/n(1)); %Snell's law to find change in angle of incidence with layers
          %in the opv  
          for g=2:TotalNumberLayers+1
              phi(g,1) = asin(sin(phi(g-1,1))*n(g-1)/n(g)); 
          end
          rp=zeros(1,TotalNumberLayers+1); %Reflection coefficient for p polarised light
          rs=zeros(1,TotalNumberLayers+1); %Reflection coefficient for s polarised light
          tp=zeros(1,TotalNumberLayers+1); %Transmission coefficient for p polarised light
          ts=zeros(1,TotalNumberLayers+1); %Transmission coefficient for s polarised light
          rp(1) = (((n(1))*cos(phi0)) - ((n0)*cos(phi(1,1))))/(((n(1))*cos(phi0)) +...
              ((n0)*cos(phi(1,1)))); 
          rs(1) = ((q0 - q(1,1))/(q0 + q(1,1)));
          tp(1) = (2*q0)/((n(1)*cos(phi0)) + ((n0)*cos(phi(1,1)))); 
          ts(1) = ((2*q0)/(q0 + q(1,1)));
          for g = 2:TotalNumberLayers+1             
          rp(g) = (((n(g))*cos(phi(g-1,1))) - ((n(g-1))*cos(phi(g,1))))...
              /(((n(g))*cos(phi(g-1,1))) + ((n(g-1))*cos(phi(g,1)))); 
          rs(g) = ((q(g-1,1) - q(g,1))/(q(g-1,1) + q(g,1)));
          tp(g) = (2*q(g-1,1))/((n(g)*cos(phi(g-1,1))) + ((n(g-1))*cos(phi(g,1)))); 
          ts(g) = ((2*q(g-1,1))/(q(g-1,1) + q(g,1)));
          end 
          Ip=zeros(2,2,TotalNumberLayers+1); %Interface matrix for p polarised light
          Is=zeros(2,2,TotalNumberLayers+1); %Interface matrix for s polarised light
          for g = 1:TotalNumberLayers+1
              Ip(:,:,g) = [(1/tp(g)),(rp(g)/tp(g));(rp(g)/tp(g)),(1/tp(g))]; 
              Is(:,:,g) = [(1/ts(g)),(rs(g)/ts(g));(rs(g)/ts(g)),(1/ts(g))];  
          end
          S_mp(:,:,a(1)+1) = Ip(:,:,a(1)+1);  %Product of Ip and Lm for p polarized light starting from the
         %coherent layers after the first layer of glass upto just before the second
         %glass layer  
          S_ms(:,:,a(1)+1) = Is(:,:,a(1)+1); %Product of Is and Lm for s polarized light starting from the
         %coherent layers after the first layer of glass upto just before the second
         %glass layer  
          for g=(a(1)+2):a(final) %Computing S matrix for coherent layers between two glass layer
              S_mp(:,:,g) = S_mp(:,:,g-1)*Lm(:,:,g-1)*Ip(:,:,g);
              S_ms(:,:,g) = S_ms(:,:,g-1)*Lm(:,:,g-1)*Is(:,:,g);
          end
          SSp = S_mp(:,:,a(final)); %Consists of S matrix for p polarised light upto the
          %second glass layer
          SSs = S_ms(:,:,a(final)); %Consists of S matrix for s polarised light upto the
          %second glass layer
          Ibarcohp1=[abs(SSp(1,1))^2, -abs(SSp(1,2))^2; abs(SSp(2,1))^2, ...
              ((det(SSp))^2-abs((SSp(1,2)*SSp(2,1)))^2)/abs(SSp(1,1))^2]; %Combining S matrix for p polarized light 
          %of coherent interface into one equivalent incoherent interface
          Ibarcohs1=[abs(SSs(1,1))^2, -abs(SSs(1,2))^2; abs(SSs(2,1))^2, ...
              ((det(SSs))^2-abs((SSs(1,2)*SSs(2,1)))^2)/abs(SSs(1,1))^2]; %Combining S matrix for s polarized light 
          %of coherent interface into one equivalent incoherent interface
          rp10(1) = (-((n(1))*cos(phi0)) + ((n0)*cos(phi(1,1))))/...
              (((n(1))*cos(phi0)) + ((n0)*cos(phi(1,1)))); %Reflection coefficient for first layer of glass for 
          %p polarised light
          rs10(1) = ((-q0 + q(1,1))/(q0 + q(1,1))); %Reflection coefficient for first layer of glass for s 
          %polarised light
          tp10(1) = (2*q(1,1))/((n(1)*cos(phi0)) + ...
              ((n0)*cos(phi(1,1)))); %Transmission coefficient for first layer of glass for p polarised light
          ts10(1) = ((2*q(1,1))/(q0 + q(1,1))); %Transmission coefficient for first layer of glass for s polarised 
          %light
          Ibar01p = (1/abs(tp(1))^2)*[1, -abs(rp10(1))^2; abs(rp(1))^2, ...
              abs(tp(1)*tp10(1))^2-abs(rp(1)*rp10(1))^2]; %Interface matrix for glass-air interface for p 
          %polarised light
          Ibar01s = (1/abs(ts(1))^2)*[1, -abs(rs10(1))^2; abs(rs(1))^2, ...
              abs(ts(1)*ts10(1))^2-abs(rs(1)*rs10(1))^2]; %Interface matrix for glass-air interface for s 
          %polarised light
          Lbar1 = [(abs(exp(-1i*eta(1,1)*t(1))))^2,0;0,...
              (abs(exp(1i*eta(1,1)*t(1))))^2]; %Layer matrix for first layer of glass
          Lbar6 = [(abs(exp(-1i*eta(a(final),1)*t(a(final)))))^2,0;0,...
              (abs(exp(1i*eta(a(final),1)*t(a(final)))))^2]; %Layer matrix for second layer of glass
          S_mp2(:,:,a(final)+1) = Ip(:,:,a(final)+1); %Consists of S matrix for p polarised light after the
          %second glass layer to the end of the OPV stack
          S_ms2(:,:,a(final)+1) = Is(:,:,a(final)+1); %Consists of S matrix for s polarised light after the
          %second glass layer to the end of the OPV stack
          for g=(a(final)+2):TotalNumberLayers+1
              S_mp2(:,:,g) = S_mp2(:,:,g-1)*Lm(:,:,g-1)*Ip(:,:,g);
              S_ms2(:,:,g) = S_ms2(:,:,g-1)*Lm(:,:,g-1)*Is(:,:,g);
          end
          SSp2 = S_mp2(:,:,TotalNumberLayers+1); 
          SSs2 = S_ms2(:,:,TotalNumberLayers+1);
          Ibarcohp2=[abs(SSp2(1,1))^2, -abs(SSp2(1,2))^2; abs(SSp2(2,1))^2, ...
              ((det(SSp2))^2-abs((SSp2(1,2)*SSp2(2,1)))^2)/abs(SSp2(1,1))^2]; %Combining S matrix for p 
          %polarized light of coherent interface into one equivalent incoherent interface
          Ibarcohs2=[abs(SSs2(1,1))^2, -abs(SSs2(1,2))^2; abs(SSs2(2,1))^2, ...
              ((det(SSs2))^2-abs((SSs2(1,2)*SSs2(2,1)))^2)/abs(SSs2(1,1))^2]; %Combining S matrix for s 
          %polarized light of coherent interface into one equivalent incoherent interface
          SSpnet=Ibar01p*Lbar1*Ibarcohp1*Lbar6*Ibarcohp2; %Total transfer matrix for all layers for p 
          %polarized light
          SSsnet=Ibar01s*Lbar1*Ibarcohs1*Lbar6*Ibarcohs2; %Total transfer matrix for all layers for s 
          %polarized light
          Rpnet = SSpnet(2,1)/SSpnet(1,1); %Net reflectance of OPV stack for p polarized light
          Rsnet = SSsnet(2,1)/SSsnet(1,1); %Net reflectance of OPV stack for s polarized light
          Tpnet = ((1/SSpnet(1,1))*real(nn(TotalNumberLayers)*...
              cos(phi(TotalNumberLayers,1))))/(n0*cos(phi0)); %Net transmittance of OPV stack for p 
          %polarized light
          Tsnet = ((1/SSsnet(1,1))*real(nn(TotalNumberLayers)*...
              cos(phi(TotalNumberLayers,1))))/(n0*cos(phi0)); %Net transmittance of OPV stack for s 
          %polarized light
          Rnet = (Rpnet+Rsnet)/2; %Net reflectance of OPV stack
          Tnet = (Tpnet+Tsnet)/2; %Net transmittance of OPV stack
          R(bb,j)=real(Rnet); %Assign Rnet value to R.
          T(bb,j)=real(Tnet); %Assign Tnet value to T.
          
    end
end
a=1;

end

          
    