clear all
close all
clc
tic
pcov1=[1,0.8,0.6,0.4,0.2];
%% Variable names for key results
for loop=1:5
    
%% Constant parameters
pcov=pcov1(1,loop); %Variable that iterates coverage ratios of solar cell 
% on greenhouse roof through the loop consisting of all the specified
% values in pcov1.
dena = 1.225; %Density of air (kg/m3)
cpa = 1003; %Specific heat of air (J/kg.K)
P = 101000; %Barometric pressure (Pa)
Ma = 0.02897; %Molecular weight of air (kg/mol)
L = 2450000; %Latent heat of evaporization (J/kg.K)
sig = 5.67e-08; %Stefan-Boltzmann constant (W/K4m2)
Mw = 0.018; %Molecular weight of water (kg/mol)
M=341; %Size of wavelength matrix for modelling the optical parameters 
% (transmittance, reflectance and absorptance) of the OSC stack on
% greenhouse roof
M_glass=341; %Size of wavelength matrix for modelling the optical parameters 
% (transmittance, reflectance and absorptance) of the wall. 
g=9.81; %acceleration due to gravity (m/s2)
mu=1.81e-05; %Dynamic viscosity of air (kg/m-s)
ka=0.03; %Thermal conductivity of air (W/m-K)
C = 3E8; %Speed of light (m/s) 
eta0 = 8.854E-12; %Free permativity (C^2)/(N m^2)                                       
h = 6.626E-34; %Planck's constant (J-s)                                          
qe = 1.602E-19; %Electron charge (C)  
%c1-c6 given below are empirical values to calculate transpiration energy
%and moisture loss from the plants to air inside the greenhouse
c1=0.154;
c2=1.10;
c3=1.13;
c4=1.65;
c5=0.56;
c6=13;

%% Input-Greenhouse geometric properties
length = 29.2608; %length of the greenhouse (m) 
width = 7.3152; %width of the greenhouse (m)                 
span = 1; %Span of the greenhouse
width=width*span; %width of the greenhouse accounting for the span (m)
Anwins_cond=1;  %Condition denoting whether greenhouse north facing wall is
%insulated or not. (1 denotes insulated opaque wall, 0 denotes transparent wall)
wall = 3.048; %Eaves height of the greenhouse (m)
ts1=0.5; %Thickness of top surface layer of ground (m)
ts2=3-ts1; %Thickness of inner surface layer of ground (m)
tg=ts2; %Assign ts2 again to tg (m)
TA = 27; %Tilt angle of the greenhouse (degrees)
%% Input-Plant properties
daycntr=1; %iterative value that keeps track of daily changes in plant output. 
Mp=5; %Assumed fresh weight of plant for computing greenhouse energy balance (kg/m2)
LAI=2; %Assumed leaf area index of plant for computing greenhouse energy balance 
%(m2-plant/m2-ground)
cpw=4180; %Specific heat of plant (J/kg-K)
Ev = 0.96; %Emissivity of plant 
day=1; %iterative value that keeps track of daily changes in plant output.
doyem=1;%Day of year of crop 
npl(1,doyem)=18; % Plant density of lettuce(Number of plants m-2)
la0(1,doyem)=68.4e-5; %Intital leaf area (m2 plant-1)
lai_current=la0(1,doyem); %Variable that stores the most current value of leaf area
%index each loop. 
wlvi(1,doyem)=1.12e-3*npl(1,doyem)/2; %Initial dry weight of leaves (g m-2)
wsti(1,doyem)=1.12e-3*npl(1,doyem)/2; %Intial dry weight of stems (g m-2)
wrti(1,doyem)=0; %Initial dry weight of the roots (g m-2)
wlvdi(1,doyem)=0;%Initial dry weight of dead leaves (g m-2)
wsoi(1,doyem)=0; %Initial dry weight of storage organs (g m-2)
idvs(1,1)=0; %Initial development stage of plants
ilai(1,doyem)=la0(1,doyem); %Initial leaf area index (m2 leaf m-2 ground) 
ieai(1,doyem)=0; %Initial ear area index (ha ear m-2 ground)
tadrw(1,day)=wlvi(1,day)+wsti(1,day)+wsoi(1,day); 
%Total dry weight above ground (g DM m-2)
amx=1.11e-3; %Potential CO2 assimilation rate at light saturation for 
%individual leaves (kg CO2 ha-1 leaf h-1)-equivalent of 1.11 mg CO2/m2/s
%This is the general assumption for C3 species and denotes the 
%assimilation capacity of full grown leaves at the top of the canopy
eff(1,1)=12.5e-6; %Initial light conversion factor for individual leaves
%(gram CO2/J)
kbl_nor=0.5; %extinction coefficient of leaves for direct radiation when
%solar insolation is directly above the surface under consideration
%(m2 ground m-2 leaf)
xgauss=[0.0469101,0.2307534,0.5,0.7692465,0.9530899]; %Steps for 
%gaussian integration
wgauss=[0.1184635, 0.2393144, 0.284444444,0.2393144,0.1184635];
%Weight offered for each step given in xgauss
mainlv=0.03; %Maintenance respiration coefficient of leaves
%(g CH2O g-1 DM hr-1)
mainst=0.015;%Maintenance respiration coefficient of stems 
mainrt=0.015;%Maintenance respiration coefficient of roots
mainso=0.01;%Maintenance respiration coefficient of storage organs
Tref=25; %Reference temperature at which maintenance coefficients
%are defined(degree celsius)
Q10=2; %Maintenance coefficient increases by a factor defined here for
%a temperature rise of 10 0C.
cflv=0.459; %Mass fraction carbon in the leaves (g C g-1 DM) 
cfst=0.494; %Mass fraction carbon in the stems (g C g-1 DM)
cfrt=0.467; %Mass fraction carbon in the roots (g C g-1 DM)
cfso=0.471; %Mass fraction carbon in the storage organs (g C g-1 DM)
loss_so=0.947; %Conversion loss factor when stem reserves are 
%remobilized-from starch to glucose.
asrqrt=1.444; %Conversion of carbohydrate to dry matter for root 
%(g CH20/g dry matter)
asrqlv=1.463; %Conversion of carbohydrate to dry matter for leaves 
%(g CH20/g dry matter)
asrqst=1.513; %Conversion of carbohydrate to dry matter for stem 
%(g CH20/g dry matter)
%Storage organ not considered for lettuce
sla_100=75; %Specific leaf area for plant at 100 micromoles m-2 s-1 light across
% 14 hours of photoperiod
sla_200=75; %Specific leaf area for plant at 200 micromoles m-2 s-1 light across
% 14 hours of photoperiod
sla_300=75; %Specific leaf area for plant at 300 micromoles m-2 s-1 light across
% 14 hours of photoperiod
sla_400=75; %Specific leaf area for plant at 400 micromoles m-2 s-1 light across
% 14 hours of photoperiod
sla_500=75; %Specific leaf area for plant at 500 micromoles m-2 s-1 light across
% 14 hours of photoperiod

rgrl=0.009; %Relative growth rate of leaves per degree-day (degree Celsius per day)
Tbase=0; %Base temperature for juvenile leaf area growth (degree Celsius)
laicr=4; %Critical leaf area index beyond which death to self-shading (m2-leaf/m2-ground)
cq10_gr=1.6; %Temperature factor associated with growth rate
[num,text,raw]=xlsread('bolting.xlsx'); %spreadsheet consisting of temperature
%dependent days to bolting
bolting_temp=num(:,2); %Denotes number of days to bolting (days)

[num,text,raw]=xlsread('spectraleffect_photosynthesis.xlsx'); 
%spreadsheet consisting of wavelength dependent relative quantum yield and
%absorptance of plant 
wlngth=num(:,4); % PAR (400 - 700 nm) Wavelength (nm)
rqy=num(:,5); %Relative quantum yield of plant as a function of wavelength
% within the PAR wavelength region (400-700 nm)  over an incremental wavelength 
% of 1 nm
inten_fraction1=num(:,9); %Fraction of light in each wavelength within the
%PAR wavelength region (400-700 nm)  over an incremental wavelength of 1 nm
inten_fraction=zeros(61,1); %Fraction of light in each wavelength within the
%PAR wavelength region (400-700 nm)  over an incremental wavelength of 5 nm
abs_plntavg=zeros(61,1); %Absorptance of light by plants in each wavelength 
%within the PAR wavelength region (400-700 nm)  over an incremental wavelength of 5 nm
rqy_avg=zeros(61,1);  %Relative quantum yield of light by plants in each wavelength 
%within the PAR wavelength region (400-700 nm)  over an incremental wavelength of 5 nm
for i=1:60
    inten_fraction(i,1)=sum(inten_fraction1((i*5)-4:(i*5)));
end
inten_fraction(61,1)=inten_fraction1(301,1);
abs_plnt=num(:,7); %absorptance of plant in PAR wavelength region between 400-700 nm 
% over an incremental wavelength of 5 nm
for i=1:60
    abs_plntavg(i,1)=abs_plnt((i*5)-4);
    rqy_avg(i,1)=rqy((i*5)-4);
end
abs_plntavg(61,1)=abs_plnt(301,1);
rqy_avg(61,1)=rqy(301,1);
frac_lightabs=abs_plntavg.*inten_fraction.*rqy_avg; %Fraction of light absorbed in
%PAR wavelength region between 400-700 nm
amax_spec(1,1)=sum(frac_lightabs(:,1)); %Converting light absorbed to net
%CO2 consumed (mmoles CO2 m-2 s-1)
sumfraclight(1,1)=sum(inten_fraction(:,1)); %Total fraction of light in the
%PAR wavelength region between 400-700 nm
Amax_final(1,1)=amx; %Maximum assimilation rate of CO2 (g CO2 m-2 s-1)
eff_spectra(:,1)=eff(1,1).*inten_fraction(:,1).*1./sum(inten_fraction(:,1));
%Carbon dioxide uptake per Joule of light (g CO2/J light-wavelength)

[num,text,raw]=xlsread('plant_transmittance_reflectance.xlsx'); 
%Spreadsheet comprising of plant reflectance and transmittance as a
%function of wavelength in the PAR region (400-700 nm)
wavelength1=num(:,1); %Tempoarary storage for wavelength (nm)
wavelength1(isnan(wavelength1)) = [];
ref_plant1=num(:,2); %Temporary storage for reflectance of plant 
ref_plant1(isnan(ref_plant1)) = [];
wavelength=400:5:700; %Wavelength (nm)
wavelength=wavelength';
ref_plant=interp1(wavelength1,ref_plant1,wavelength); %Reflectance of plant
ref_plant=ref_plant/100; %Converting from percentage to fraction
wavelength2=num(:,3); %Tempoarary storage for wavelength (nm)
wavelength2(isnan(wavelength2)) = [];
tnsmvty_plant1=num(:,4); %Temporary storage for transmittance of plant 
tnsmvty_plant1(isnan(tnsmvty_plant1)) = [];
tnsmvty_plant=interp1(wavelength2,tnsmvty_plant1,wavelength); %Transmittance 
%of plant
tnsmvty_plant=tnsmvty_plant/100; %converting from percentage to fraction
sig1=tnsmvty_plant+ref_plant; %Scattering coefficient of plant (sum of 
%reflectance and transmittance) as a function of PAR wavelength (400 - 700
%nm)
sqv=sqrt(1-sig1); %Temporary variable utilized in calculating 
%Reflection coefficient of the canopy for diffuse and direct radiation
refh=(1-sqv)./(1+sqv);  %Reflection coefficient of plant canopy for diffuse 
%radiation
blueamt(1,1)=sum(inten_fraction(1:21,1))/sum(inten_fraction(:,1));
%Fraction of blue light in each light treatment
blueamt(1,1)=blueamt(1,1)*100; %Percentage of blue light in each light
%treatment
blueamt(1,1)=round(blueamt(1,1)); %Rounding up the percentage of blue 
%light
fsh(1,1)=0.85; %Fraction of carbohydrate partitioned to shoot
frt(1,1)=0.15; %Fraction of carbohydrate partitioned to root
frt_up=0.26; %Upper limit of fraction partitioned to 
%root 
fsh_up=1-frt_up; %Lower limit of fraction partitioned to
%shoot 
frt_low=0.1; %Lower limit of fraction partitioned to
%root 
fsh_low=1-frt_low; %Upper limit of fraction partitioned to
%shoot 
flv(1,1)=0.8; %Fraction partitioned to leaves.
%plntcntr=1;
%% Input-Temperature and humidity set-points
num = xlsread('Inputdata.xlsx');%File containing climate input parameters required 
% for running the simulation
rhnight = [0.6 0.8]; %Lower and upper limit of relative humidity to be 
%maintained in the greenhouse at night
rhday = [0.6 0.8]; %Lower and upper limit of relative humidity to be maintained 
%in the greenhouse during day 
rh = [rhnight rhday]; %Matrix containing relative humidity setpoints
Tgw=3;%Temperature of ground water(its value is constant irrespective of
%outside temperature. Taken to be at a level of 20 m )(degree Celsius)
%% Input-Thermal properties and infiltration condition of greenhouse
achinf=1; %Air changes per hour caused due to infiltration in the greenhouse
kr=1.05; %Thermal conductivity of greenhouse roof (W/m-K)
Ur = 1.13; %Overall heat transfer coefficient of greenhouse roof (Btu/hr-ft2-F)
transmittance_roof=0; %Longwave transmittance through the roof
transmittance_wall=0; %Longwave transmittance through the wall
Uglass=1.13; %Overall heat transfer coefficient of greenhouse wall (Btu/hr-ft2-F)
Ec_ITO=0.09; %Emissivity of organic solar cells
Ec_glass=0.93; %Emissivity of glass
Ec = (Ec_ITO*pcov)+((1-pcov)*Ec_glass); %Emissivity of total greenhouse roof 
%area account of fraction of OSC coverage
kg=1.26; %Thermal conductivity of ground (W/m-K)
Cg=1255200; %Volumetric heat capacity of ground (J/m3-K)
Fp=0.85; %Perimeter heat loss factor (W/m-K)
%% Input-Property of shade cloth
tnsmvty=0.5; %Transmittance of shade cloth
shade_rolltime=600; %Time taken for shade cloth to roll out (s)
%% Input-Environmental parameters
Tao=num(:,2); %Hourly temperature of air outside the greenhouse (degree Celsius)
rhao=num(:,3); %Relative humidity of air outside the greenhouse (%)
uout=num(:,4); %Wind velocity outside the greenhouse (m/s)
TaoFaht = (Tao*9/5)+32; %Matrix consisting temperature of air outside the greenhouse
% (degree Fahrenheit)
TaominFaht = min(TaoFaht(:,1)); %Minimum outside air temperature (degree Fahrenheit).
Totaltemp=Tao; %Assigning Tao to Totaltemp
Totalrhao=rhao; %Assigning rhao to Totalrhao
Twb=(Totaltemp.*atan(0.151977*(rhao+8.313659).^0.5))+atan(Totaltemp+rhao)-...
    atan(rhao-1.676331)+(0.00391838*((rhao).^(1.5)).*atan(0.023101*rhao))...
    -4.686035; %Wet-bulb temperature (degree Celsius)
%% Input-Ventilation fan pad cooling system specifications
efficiencyevap=0.8; %Efficiency of evaporative cooling pad
Voltage=115; %Voltage of fans (V)
Current=15.2; %Amperage of fans
phasefactor=0.8; %Phase factor for three-phase connection
RMSvalue=0.8; %RMS value
%% Input-Solar parameters
diffr=num(:,21); %Diffuse radiation on a horizontal surface (kWh/m2-year)
totr=num(:,22); %Total radiation on a horizontal surface (kWh/m2-year)
time=num(:,1); %Time at which environmental parameters are measured  
Fractionoflightineachwavelength = num(:,23);%Fraction of total light (AM 1.5) in a 
%particular wavelength (nm)
Fractionoflightineachwavelength(isnan(Fractionoflightineachwavelength)) = [];
latt=61.21;%latitude (degrees)
latt_r=latt*pi()/180; %latitude (radians)
long=149.9003;%longitude (degrees)
long_r=long*pi()/180; %longitude (radians)
sttmd=135;%Standard time meridian (degrees)
sttmd_rad=sttmd*pi()/180; %Standard time meridian (radians)
wall_tilt=90*pi()/180; %Tilt angle of the walls of the greenhouse (radians)
roof_tilt=TA*pi()/180; %Tilt angle of the roof of the greenhouse (radians)
Esc=1367; %Solar constant (W/m2)
rho_r=0.2; %Reflectance of solar radiation from ground
%% Geometric properties of the greenhouse
Av = 2*length*width; %Area of vegetation in greenhouse (m2)
Aground=Av/2; %Area of ground of greenhouse (m2)
Avft = Av*3.28*3.28; %Area of vegetation in greenhouse (ft2)
V = ((length*width/span*wall)+...
(0.5*(width/span)*(tan(TA*pi()/180)*((width/span)/2))*length))*span; %Volume of greenhouse
%m3
roof_slope = span*(sqrt((tan(TA*pi()/180)*((width/span)/2))^2+...
(((width/span)/2)^2))); %Total length of slope of greenhouse roof (m)
P_ground=2*((roof_slope/span)+length); %Perimeter of greenhouse (m)
Ac = roof_slope*length; %Area of half roof of the greenhouse (m2) 
Ac=2*Ac; %Total area of the roof of the greenhouse (m2)
Fvcplant=1/((1/Ev)+((Aground/Ac)*((1/Ec)-1))); %View factor from vegetation to roof of 
%greenhouse
Asw = (((width/span)*wall)*span)+((0.5*(width/span)*tan(TA*pi()/180)*...
    (width/(2*span)))*span); %Area of south facing wall (m2)
Anw = (((width/span)*wall)*span)+((0.5*(width/span)*tan(TA*pi()/180)*...
    (width/(2*span)))*span); %Area of north facing wall (m2)
Aew = length*wall; %Area of east facing wall (m2)
Aww = length*wall; %Area of west facing wall (m2)
Acft = Ac*3.28*3.28; %Total Area of roof of the greenhouse (ft2)
Aew_insulation=0; %Area of opaque portion of east facing wall (m2)
Aww_insulation=0; %Area of opaque portion of west facing wall (m2)
Anw_insulation=Anw; %Area of opaque portion of north facing wall (m2)
Asw_insulation=0; %Area of opaque portion of south facing wall (m2)
Aew_transparent=Aew-Aew_insulation; %Area of transparent portion of east facing wall (m2)
Aww_transparent=Aww-Aww_insulation; %Area of transparent portion of west facing wall (m2)
Anw_transparent=Anw-Anw_insulation; %Area of transparent portion of north facing wall (m2)
Asw_transparent=Asw-Asw_insulation; %Area of transparent portion of south facing wall (m2)
Ainsulation=(Anw_insulation)+(Aew_insulation+Aww_insulation)+(Asw_insulation); 
%Total area of insulation in walls and roof of greenhouse (m2)
if(Anwins_cond==1)
    Netwallsurfacearea=Aew+Aww+Asw; %Total surface area of all the walls of the 
    %greenhouse (m2)
    Awall=Aew+Aww+Asw+Ac; %Area of wall under shades
else
    Netwallsurfacearea=Aew+Aww+Asw+Anw; %Total surface area of all the walls of the 
    %greenhouse if north wall is not opaque (m2)
    Awall=Aew+Aww+Asw+Anw+Ac; %Area of wall under shades
end

Netwallsurfaceareaft=Netwallsurfacearea*3.28*3.28; %Total surface area of all the walls 
%of the greenhouse (ft2)
Atransparent=Netwallsurfacearea-Ainsulation; %Total transparent surface area of all 
%the walls of the greenhouse (m2)
h1=wall; %Height of greenhouse beneath shade (m)
endwall_shade=2*width*h1; %Area of endwalls beneath shade (m2)
sidewall_shade=2*length*wall; %Area of sidewalls beneath shade (m2)
Netsurfacearea_shade = endwall_shade+sidewall_shade; %Net surface area of wall beneath 
%shade (m2)
Netsurfacearea_up=Netwallsurfacearea-Netsurfacearea_shade; %Net surface area of 
%greenhouse above shade (m2)
V1 = length*width*h1; %Volume of greenhouse beneath shade (m3)
V1ft=V1*3.28*3.28*3.28; %Volume of greenhouse beneath shade (ft3)
fraction=V1/V; %Fraction of greenhouse volume beneath shade
theohtup=(V-V1)/(length*width); %Average height of greenhouse above shade (m)

%% Computing flowrate of air inside the greenhouse from the ventilation fans
nshade=0; %Represents ventilation for humidity control. Initally zero, 
%this value changes to nsat/30 when in need for humidity control by
%additional ventilation
nmin = 0; %Represents condition when fans are inactive
Vft=V*3.28*3.28*3.28; %Volume of greenhouse (ft3)
nsat=Vft*2/Avft; %Maximum flow rate in the greenhouse from the fans (cfm/ft2-min)


%% Heat transfer coefficient calculation
Lc=(Ac/(2*P_ground*span)); %Characteristic length of roof of greenhouse (m)
Re=dena*uout*Lc/mu; %Reynolds number
Pr=mu*cpa/ka; %Prandtl number
ho=zeros(8760,1); %Outside heat transfer coefficient (W/m2-K)
for i=1:8760
    if(Re(i,1)<=5e5)
        ho(i,1)=0.664*(Re(i,1)^0.5)*(Pr^0.33)*ka/Lc;
    else
        ho(i,1)=0.037*(Re(i,1)^0.8)*(Pr^0.33)*ka/Lc;
    end
end
Totalho=ho; %Assigning ho to Totalho
%% Solarcell properties
Voc=0.68;       %Open circuit voltage 
FF=0.77;         %Fill factor                                    
stepDiff = 2E-10; %Stepsize in (m) for measuring absorptance of layer in OSC stack (m)
clear i;
n_exp2 = transpose(num(:,7));     
n_exp2(isnan(n_exp2)) = [];

k_exp2 = transpose(num(:,8)); 
k_exp2(isnan(k_exp2)) = [];

nglass = n_exp2 + i*k_exp2; %Refractive index of glass (1st layer of OSC stack)

n_exp3 = transpose(num(:,9));
n_exp3(isnan(n_exp3)) = [];

k_exp3 = transpose(num(:,10));
k_exp3(isnan(k_exp3)) = [];

nITO = n_exp3 + i*k_exp3; %Refractive index of 1st electrode (2nd layer of OSC stack)

n_exp4 = transpose(num(:,11));
n_exp4(isnan(n_exp4)) = [];

k_exp4 = transpose(num(:,12));
k_exp4(isnan(k_exp4)) = [];

nETL = n_exp4 + i*k_exp4; %Refractive index of electron transport layer 
%(3rd layer of OSC stack)

n_exp5 = transpose(num(:,13));
n_exp5(isnan(n_exp5)) = [];

k_exp5 = transpose(num(:,14));
k_exp5(isnan(k_exp5)) = [];

nactivelayer = n_exp5 + i*k_exp5; %Refractive index of active layer 
%(4th layer of OSC stack)

n_exp6 = transpose(num(:,15));
n_exp6(isnan(n_exp6)) = [];

k_exp6 = transpose(num(:,16));
k_exp6(isnan(k_exp6)) = [];

nHTL = n_exp6 + i*k_exp6; %Refractive index of hole transport layer
%(5th layer of OSC stack)

n_exp8 = transpose(num(:,9)); %Again ITO. spreadsheet will contain LiF and MoO3
n_exp8(isnan(n_exp8)) = [];

k_exp8 = transpose(num(:,10));
k_exp8(isnan(k_exp8)) = [];

nAl = n_exp8 + i*k_exp8; %Refractive index of 2nd electrode (7th layer of OPV stack)
%Here this is again ITO.


nglass2 = nglass; %Refractive index of glass (8th layer of OPV stack)

clear t;

%Thickness of each layer of OPV stack (m)                   
t(1) = 2E-3;         % glass
t(2) = 100E-9;       % electrode
t(3) = 35E-9;        % ETL
t(4) = 126E-9;       % Active layer
t(5) = 5E-9;         % HTL
t(6) = 100E-9;       % electrode
t(7) = 2E-3;        % glass
t(8) = 10E-9;       % air

TotalNumberLayers=size(t); %Total number of layers of OPV stack
TotalNumberLayers=TotalNumberLayers(1,2); %Total number of layers of OPV stack
ActiveLayer1 = 4; %Index of active layer

%Refractive index data
n0 = 1;                 % air
n(1) = nglass(1);       % glass      
n(2) = nITO(1);         % electrode
n(3) = nETL(1);         % Electron Transport Layer
n(4) = nactivelayer(1); % Active layer
n(5) = nHTL(1);         % Hole Transport Layer
n(6) = nAl(1);        % electrode
n(7) = nglass2(1);     % glass
n(8)=1;                % air
n(9)=1;                % air

tglass=0; %Thickness of glass layer on roof of the greenhouse (m)
 c=1; 
for g=1:TotalNumberLayers
 if(n(g)==nglass(1))
     tglass = tglass+t(g); %Computing thickness of glass layer of roof of the 
     %greenhouse (m)
     a(c)=g; %Matrix holding index of glass layer
     c=c+1;
 end
end
 
final=c-1;  %Contains the index of final layer of glass.


t1(1) = 4E-3;         % Thickness of glass on the walls of a greenhouse
t1(2) = 10E-9;        % Air
t1(3) = 10E-9;        % Air
TotalNumberLayers_glass=size(t1); %Total number of layers of the material on the 
%wall of the greenhouse
TotalNumberLayers_glass=TotalNumberLayers_glass(1,2); %Total number of layers of the 
% material on the wall of the greenhouse
tc=tglass; %Thickness of greenhouse roof (m)



%% Calculating incident solar insolation on all surface of the greenhouse
%Geometric angles of sun annualy for every hour is calculated now
day_y=1:1:365; %Matrix holding each day of the year
day_y=day_y';
day_h=zeros(8760,1); %%For hourly calculation, we need 365*24=8760 datapoints. 
%Every hour within a segement of 24 hours in terms of day is taken as a single value. 
%For example on Jan 1st, hours 1 to 24 is categorized as day 1.
%Hours 25 to 48 is taken as day 2 which corresponds to January 2 and so
%the process continues. This day corresponding to hour is given by day_h.
Kt=zeros(8760,1); %Daily average clearness index
for i=1:365
    for j=(i*24)-23:(i*24)
        day_h(j,1)=day_y(i,1);
    end
end

%Hourly calculation starts
decl=zeros(8760,1); %Declination of sun (degrees)
st=zeros(8760,1); %Solar time (mins)
st_hr=zeros(8760,1); %Solar time (hrs) 
Ibr=zeros(8760,1);  %Beam radiation incident on a horizontal surface (W/m2)
Idr=zeros(8760,1); %Diffuse radiation incident on a horizontal surface (W/m2)

al_sr=zeros(8760,1); %Solar altitude on a hourly basis (radians)
az_sr=zeros(8760,1); %Solar azimuth angle (radians)
ltsr=zeros(8760,1);  %Local time for sunrise (hrs)
ltss=zeros(8760,1);  %Local time for sunset (hrs)
for i=1:8760
decl=23.45*sin(((360/365)*(284+day_h(i,1)))*pi()/180);
decl_r=decl*pi()/180; %Declination of sun (radians)
b=(360/364)*(day_h(i,1)-81); %Angle to calculate equation of time (degrees)
b_r=b*pi()/180; %Angle to calculate equation of time (radians)
et=(9.87*sin(2*b_r))-(7.53*cos(b_r))-(1.5*sin(b_r)); %When earth rotates around the sun, 
%a correction factor that accounts for the irregularity of the speed of the earth's 
%motion around the sun is considered . This is called equation of time (et)  
st(i,1)=et+time(i,1)+((sttmd-long)*4); 
st_hr(i,1)=st(i,1)/60; 
ha=(st_hr(i,1)-12)*15; %Hour angle (degrees)
ha_r=ha*pi()/180; %Hour angle (radians)
sinal_s=(cos(decl_r)*cos(latt_r)*cos(ha_r))+(sin(decl_r)*sin(latt_r)); 
%Sine of solar altitude of the sun
al_sr(i,1)=asin(sinal_s); %Solar altitude on a hourly basis (radians)
al_s=al_sr(i,1)*180/pi(); %Solar altitude on a hourly basis (degrees)
sinaz_s=cos(decl_r)*sin(ha_r)/cos(al_sr(i,1)); %Sine of solar azimuth angle (degrees)
az_sr(i,1)=asin(sinaz_s); 
az_s=az_sr*180/pi(); %Solar azimuth angle (degrees)
ha_srr=-acos(-tan(latt_r)*tan(decl_r)); %Hour angle at sunrise (radians) 
ha_sr=ha_srr*180/pi(); %Hour angle at sunrise (degrees)
ha_ssr=acos(-tan(latt_r)*tan(decl_r)); %Hour angle at sunset (radians) 
ha_ss=ha_ssr*180/pi(); %Hour angle at sunrise (degrees) 
stsr=12+(ha_sr/15); %Solar time for sunrise (hrs)
stss=12+(ha_ss/15); %Solar time for sunset (hrs)
%Based on the coordinates, the local time for sunrise and
%sunset is given by:
ltsr(i,1)=stsr-(et/60)-((sttmd-long)/15); %Local time for sunrise (hrs)
corr=ltsr-stsr; %Correction to obtain local time from solar time (hrs)
ltss(i,1)=corr(i,1)+stss; %Local time for sunset (hrs)
rd=((pi()/24)*(cos(ha_r)-cos(ha_ssr)))/(sin(ha_ssr)-(pi()/180)*ha_ss*...
    cos(ha_ssr)); %Ratio of hourly diffuse to long-term average daily diffuse
%irradiation on a horizontal surface
if(rd<0)
    rd=0;
end
DODsqangle_r=(360/365)*(day_h(i,1)-1)*pi()/180; %Angle to determine the 
%current distance between earth andsun (radians)
D0Dsq=1.00011+(0.034221*cos(DODsqangle_r))+(0.00128*sin(DODsqangle_r))...
    +(0.000719*cos(2*DODsqangle_r))+(0.000077*sin(2*DODsqangle_r)); 
%Square of ratio of D0/D. D - Distance between the sun and earth (m). 
%D0 is the yearly mean earth-sun distance (m). 
q=cos(latt_r)*cos(decl_r); %Product of cos(latt_r) and cos(decl_r)
A_hss=sin(ha_ssr)-(ha_ssr*cos(ha_ssr)); 
sin_h0=q*A_hss/ha_ssr; 
H0=(24/pi())*ha_ssr*D0Dsq*Esc*sin_h0/1000; 
%Daily extra terrestrial irradiation on a horizontal surface (W/m2)
S0=(24/pi())*ha_ssr; %Daylength (hours)
Kt(i,1)=totr(i,1)/H0; 
a1=(0.41341*(Kt(i,1)))+(0.61197*(Kt(i,1))^2)-...
    (0.01886*Kt(i,1)*S0)+(0.00759*S0); 
%a1 - (a2/a1) represents the atmospheric extinction coefficient. a1 and a2
%are obtained from a multiple least squares fit
a2=max(0.054,0.28116+(2.2475*Kt(i,1))-(1.7611*(Kt(i,1))^2)-...
    (1.84535*sin_h0)+(1.681*(sin_h0^3))); %a2 mentioned above
B_hss=(ha_ssr*(0.5+(cos(ha_ssr)*cos(ha_ssr))))-(0.75*sin(2*ha_ssr)); 
%Parameter to calculate rt
rt=rd*((1+(q*(a2/a1)*A_hss*rd*(24/pi())))...
    /(1+(q*(a2/a1)*B_hss/A_hss))); 
%Ratio of the horizontal hourly radiation to the total horizontal daily
%radiation 
Ibr(i,1)=((rt*totr(i,1))-(diffr(i,1)*rd))*1000;
Idr(i,1)=diffr(i,1)*rd*1000;
end
Ioutside=Ibr+Idr+((Ibr+Idr)*rho_r);
Ioutside_par=Ioutside*0.432*4.54;
DLI_outside=zeros(365,1);
for i=1:365
    DLI_outside(i,1)=sum(Ioutside_par((i*24)-23:(i*24)))*1e-6*3600;
end

surface_azimuth=zeros(8760,6); 
%Azimuth angle of all the surface of the greenhouse (radians)
for i=1:8760
    surface_azimuth(i,1)=-90*pi()/180;
    surface_azimuth(i,2)=90*pi()/180;
    surface_azimuth(i,3)=180*pi()/180;
    surface_azimuth(i,4)=0*pi()/180;
    surface_azimuth(i,5)=-90*pi()/180;
    surface_azimuth(i,6)=90*pi()/180;
end
cosi=zeros(8760,6); %cosine of angle of incidence of sun on all the surfaces 
incident_angle=zeros(8760,1); %Angle of incidence of sun on all the surfaces (radians)
for i=1:8760
    cosi(i,1)=((cos(al_sr(i,1))*cos(az_sr(i,1)-surface_azimuth(i,1))*sin(wall_tilt))+...
        (sin(al_sr(i,1))*cos(wall_tilt)));
    incident_angle(i,1)=real(acos(cosi(i,1)))*180/pi();
    cosi(i,2)=((cos(al_sr(i,1))*cos(az_sr(i,1)-surface_azimuth(i,2))*sin(wall_tilt))+...
        (sin(al_sr(i,1))*cos(wall_tilt)));
    incident_angle(i,2)=real(acos(cosi(i,2)))*180/pi();
    cosi(i,3)=((cos(al_sr(i,1))*cos(az_sr(i,1)-surface_azimuth(i,3))*sin(wall_tilt))+...
        (sin(al_sr(i,1))*cos(wall_tilt)));
    incident_angle(i,3)=real(acos(cosi(i,3)))*180/pi();
    cosi(i,4)=((cos(al_sr(i,1))*cos(az_sr(i,1)-surface_azimuth(i,4))*sin(wall_tilt))+...
        (sin(al_sr(i,1))*cos(wall_tilt)));
    incident_angle(i,4)=real(acos(cosi(i,4)))*180/pi();

    cosi(i,5)=((cos(al_sr(i,1))*cos(az_sr(i,1)-surface_azimuth(i,5))*sin(roof_tilt))+...
        (sin(al_sr(i,1))*cos(roof_tilt)));
    incident_angle(i,5)=real(acos(cosi(i,5)))*180/pi();
    cosi(i,6)=((cos(al_sr(i,1))*cos(az_sr(i,1)-surface_azimuth(i,6))*sin(roof_tilt))+...
        (sin(al_sr(i,1))*cos(roof_tilt)));
    incident_angle(i,6)=real(acos(cosi(i,6)))*180/pi();
end
Ibr_surface=zeros(8760,6); %Beam radiation on the surface of the greenhouse (W/m2)
Idr_surface=zeros(8760,6); %Diffuse radiation incident on the surface of the greenhouse 
%(W/m2) 
Iref_surface=zeros(8760,6); %Reflected radiation incident on the surface of the greenhouse 
%(W/m2) 

for i=1:8760
    Ibr_surface(i,1)=Ibr(i,1)*cosi(i,1)/sin(al_sr(i,1));
    if(Ibr_surface(i,1)<=0)
        Ibr_surface(i,1)=0;
        incident_angle(i,1)=90;
    end
    Ibr_surface(i,2)=Ibr(i,1)*cosi(i,2)/sin(al_sr(i,1));
    if(Ibr_surface(i,2)<=0)
        Ibr_surface(i,2)=0;
        incident_angle(i,2)=90;
    end
    Ibr_surface(i,3)=Ibr(i,1)*cosi(i,3)/sin(al_sr(i,1));
    if(Ibr_surface(i,3)<=0)
        Ibr_surface(i,3)=0;
        incident_angle(i,3)=90;
    end
    Ibr_surface(i,4)=Ibr(i,1)*cosi(i,4)/sin(al_sr(i,1));
    if(Ibr_surface(i,4)<=0)
        Ibr_surface(i,4)=0;
        incident_angle(i,4)=90;
    end
    Ibr_surface(i,5)=Ibr(i,1)*cosi(i,5)/sin(al_sr(i,1));
    if(Ibr_surface(i,5)<=0)
        Ibr_surface(i,5)=0;
        incident_angle(i,5)=90;
    end
    Ibr_surface(i,6)=Ibr(i,1)*cosi(i,6)/sin(al_sr(i,1));
    if(Ibr_surface(i,6)<=0)
        Ibr_surface(i,6)=0;
        incident_angle(i,6)=90;
    end
     Idr_surface(i,1)=Idr(i,1)*((cos(wall_tilt/2))^2);
     Idr_surface(i,2)=Idr(i,1)*((cos(wall_tilt/2))^2);
     Idr_surface(i,3)=Idr(i,1)*((cos(wall_tilt/2))^2);
     Idr_surface(i,4)=Idr(i,1)*((cos(wall_tilt/2))^2);
     Idr_surface(i,5)=Idr(i,1)*((cos(roof_tilt/2))^2);
     Idr_surface(i,6)=Idr(i,1)*((cos(roof_tilt/2))^2);
     Iref_surface(i,1)=(Ibr(i,1)+Idr(i,1))*rho_r*((1-cos(wall_tilt))/2);
     Iref_surface(i,2)=(Ibr(i,1)+Idr(i,1))*rho_r*((1-cos(wall_tilt))/2);
     Iref_surface(i,3)=(Ibr(i,1)+Idr(i,1))*rho_r*((1-cos(wall_tilt))/2);
     Iref_surface(i,4)=(Ibr(i,1)+Idr(i,1))*rho_r*((1-cos(wall_tilt))/2);
     Iref_surface(i,5)=(Ibr(i,1)+Idr(i,1))*rho_r*((1-cos(roof_tilt))/2);
     Iref_surface(i,6)=(Ibr(i,1)+Idr(i,1))*rho_r*((1-cos(roof_tilt))/2);
end
Itotal_surface=Ibr_surface+Idr_surface+Iref_surface; %Sum of beam, diffuse and 
%reflected solar insolation on all surface of the greenhouse (W/m2)
daylength=zeros(365,1);
for i=1:365
    for j=(i*24)-23:(i*24)
        if(Itotal_surface(j,1)>0)
            daylength(i,1)=daylength(i,1)+1;
        end
    end
end
cgrmax=5e-6*3600*daylength; %Saturated growth rate of lettuce (day-1)

        
    
%% Calculating sky temperature and emissivity
cf=1-Kt; %Cloud cover factor
Tsky=zeros(8760,1); %Temperature of sky (C)
eclear=zeros(8760,1); %Emissivity of clear sky
esky=zeros(8760,1); %Actual emissivity of sky
for i=1:8760
    eclear(i,1)=0.787+(0.7641*log((Twb(i,1)+273)/273));
    esky(i,1)=(1+0.0224*cf(i,1)-0.0035*(cf(i,1)^2)+...
    (0.00028*(cf(i,1)^3)))*eclear(i,1);
    Tsky(i,1)=(Tao(i,1)+273.5)*(esky(i,1)^0.25);
end


%% Section to calculate transmittance, absorptance through OPV along with light
% entering the greenhouse and power generation by solar cell

lambda_sm=transpose(num(:,6)); %Wavelength (nm)
lambda_sm(isnan(lambda_sm))=[];
lambda_sm=lambda_sm*1e-9; %Wavelength (m)
fprintf('Transfer matrix modelling calculation in progress\n');
[R,T] = optics(nglass,nITO,nETL,nactivelayer,nHTL,nAl,nglass2,a,final,...
    TotalNumberLayers,M,t); %For transmittance and reflectance through OSCs as a function of wavelength (rows) and
% angle of incidence (columns)
[R_glass,T_glass] = optics_glass(nglass,TotalNumberLayers_glass,...
    M_glass,t1); %For transmittance and reflectance through glass walls as a function of wavelength (rows) and
% angle of incidence (columns)
[Abstotal_check] = absorptance(nglass,nITO,nETL,nactivelayer,nHTL,nAl,TotalNumberLayers,M,t,ActiveLayer1,stepDiff);
fprintf('Transfer matrix modelling calculation complete\n');
T(:,91)=0; %Transmittance of OSC stack at 90 degrees angle
T_glass(:,91)=0; %Transmittance of wall material at 90 degrees angle
R(:,91)=1; %Reflectance of OSC stack at 90 degrees angle
R_glass(:,91)=1; %Reflectance of wall material at 90 degrees angle
Abstotal_check(:,91)=0; %Absorptance of OPV material in the active layer
Eastroof = incident_angle(:,5); %Angle of incidence of east facing roof (degrees)
Westroof = incident_angle(:,6); %Angle of incidence of west facing roof (degrees)
Eastwall = incident_angle(:,1);  %Angle of incidence of east facing wall (degrees)
Westwall = incident_angle(:,2); %Angle of incidence of west facing wall (degrees)
Northwall = incident_angle(:,3); %Angle of incidence of north facing wall (degrees) 
Southwall = incident_angle(:,4); %Angle of incidence of south facing wall (degrees)
Suner = Ibr_surface(:,5);   %Direct light incident on the east facing roof (W/m2)
Sunwr = Ibr_surface(:,6);   %Direct light incident on the west facing roof (W/m2)
Sunerd = (Idr_surface(:,5)); %Diffuse light incident on the east facing roof (W/m2)
Sunerr = Iref_surface(:,5);  %Reflected light radiation on the east facing roof (W/m2)  
Sunwrd = (Idr_surface(:,6)); %Diffuse light incident on the west facing roof (W/m2)
Sunwrr = Iref_surface(:,6); %Reflected radiation on the west facing roof (W/m2)
Sunew = Ibr_surface(:,1); %Direct light incident on the east facing wall (W/m2)  
Sunww = Ibr_surface(:,2); %Direct light incident on the west facing wall (W/m2)  
Sunnw = Ibr_surface(:,3); %Direct light incident on the north facing wall (W/m2)
Sunsw = Ibr_surface(:,4); %Direct light incident on the south facing wall (W/m2)
Sunewd = (Idr_surface(:,1)+Iref_surface(:,1)); %Diffuse light incident on the 
%east facing wall (W/m2)  
Sunwwd = (Idr_surface(:,2)+Iref_surface(:,2)); %Diffuse light incident on the 
%west facing wall (W/m2)    
Sunnwd = (Idr_surface(:,3)+Iref_surface(:,3)); %Diffuse light incident 
%on the north facing wall (W/m2)     
Sunswd = (Idr_surface(:,4)+Iref_surface(:,4)); %Diffuse light incident 
%on the south facing wall (W/m2)    
fraclight=zeros(M,1); %Fraction of total light (AM 1.5) in a particular wavelength (nm)  
%(5 nm bandwidth)
for bb=1:M-1
    for j=(bb*5-4):(bb*5)
            fraclight(bb,1)=fraclight(bb,1) + Fractionoflightineachwavelength(j,1);     
    end
end %Assuming AM 1.5 spectrum here
fraclight(M,1)=Fractionoflightineachwavelength(j+1,1);
[Ter,Twr,Tew,Tww,Tnw,Tsw,Rer,Rwr,Rew,Rww,Rnw,Rsw,Per,Pwr,Pew,Pww,Pnw,Psw,...
 Perd,Pwrd,Pewd,Pwwd,Pnwd,Pswd,Peri,Perdi,Pwri,Pwrdi,Pewi,Pewdi,Pwwi,Pwwdi,Pnwi,...
 Pnwdi,Pswi,Pswdi,Pouter,Pouterd,Poutwr,Poutwrd,PCEer,PCEwr,PCEd,...
 PCEernet,PCEwrnet,Pernonactlr,Pwrnonactlr,Perdnonactlr,...
    Pwrdnonactlr,EAI_average,WallEAI_average]=powergen_roof2_126(R,T,Abstotal_check,...
 lambda_sm,R_glass,T_glass,Eastroof,Westroof,Eastwall,Westwall,Northwall,...
 Southwall,Suner,Sunerd,Sunwr,Sunwrd,Sunew,Sunewd,Sunww,Sunwwd,Sunnw,Sunnwd,...
 Sunsw,Sunswd,fraclight,Anwins_cond,C,h,qe,M,Voc,FF,TA,Sunerr,Sunwrr,pcov);
%% Light distribution inside greenhouse
[Netenergy,Netenergyroof_v,Netenergyroof_inf,Netenergyabser,Netenergyabswr,...
    Netenergypar,Netenergyroof_par]=...
    plantlight_roof2(Peri,...
    Perdi,Pwri,Pwrdi,Pewi,Pewdi,Pwwi,Pwwdi,Pnwi,Pnwdi,Pswi,Pswdi,Ac,Aew_transparent,...
    Anw_transparent,Asw_transparent,Anwins_cond,Pernonactlr,Pwrnonactlr,...
    Perdnonactlr,Pwrdnonactlr);
Netenergyroof=Netenergyroof_v+Netenergyroof_inf; %Total light intensity of 
%light entering through the roof (W)
Totalnetenergy=Netenergy; %Assigning 'Netenergy' to Totalnetenergy
Netenergywall=Totalnetenergy-Netenergyroof; %Total light intensity entering through 
% the walls of the greenhouse (W)
Netenergyroofabs=(Netenergyabser+Netenergyabswr)*(Ac/2)*2/Av; %Total light intensity 
%absorbed by the nonactive layers of the OSC stack (W/m2)
sumfracnetenergyroof1=sum(T(:,1).*fraclight(:,1));
sumfracnetenergyroof2=sum(T_glass(:,1).*fraclight(:,1));
sumfracnetenergyroof=(pcov*sumfracnetenergyroof1)+((1-pcov)*sumfracnetenergyroof2);
sumfracparnetenergyroof1=sum(T(21:81,1).*fraclight(21:81,1));
sumfracparnetenergyroof2=sum(T_glass(21:81,1).*fraclight(21:81,1));
sumfracparnetenergyroof=(pcov*sumfracparnetenergyroof1)+((1-pcov)*sumfracparnetenergyroof2);
fracPAR_osc=sumfracparnetenergyroof/sumfracnetenergyroof; %Fraction of PAR light in light transmitted through
%roof
lightinputyear_plants = (0.5*0.75*((Netenergyroof*fracPAR_osc)+...
    (Netenergywall*0.432))*4.54)/(length*width); %PAR light intensity incident on plants (mmoles m-2 s-1)

%% Temperature set-points
Tmax1=zeros(8760,1);
Tmin1=zeros(8760,1);
Tmid1=zeros(8760,1);
Tplants=zeros(8760,1);
for i=1:8760
    if(Netenergy(i,1)==0)
         Tmin1(i,1)=17;
         Tmax1(i,1)=22;
         Tmid1(i,1)=(Tmin1(i,1)+Tmax1(i,1))/2;
    else
        Tmin1(i,1)=24;
        Tmax1(i,1)=30;
        Tmid1(i,1)=(Tmin1(i,1)+Tmax1(i,1))/2;
    end
    Tplants(i,1)=15; %Minimum temperature for plants maintained through
    %root zone heating (degree Celsius)
end  
%% Supplemental lighting
light_lamp = 180; %Supplemental lighting intensity in PAR wavelength 
% (400-700 nm) region (micromoles m-2 s-1)
DLI_duration=20; %Maximum permissable photoperiod for plants (hours) 
area_eachlamp = 100*0.093; %Area of floor in a greenhouse that each lamp 
%illuminates (m2)
lamps_no = length*width/area_eachlamp; %Total number of lamps required in the 
%greenhouse
lamps_no = round(lamps_no);
power_totallamparea = 300*lamps_no/(length*width); %Total wattage of lamps (Watts/m2) 
%(300 W per lamp * no. of lamps/(length*width)) 
DLI_inside=zeros(365,1); %Daylight integral in the greenhouse (DLI)
sunrise=zeros(365,1); %Time of sunrise (hrs)
for i=1:365
    for j=(i*24)-23:(i*24)
        if(lightinputyear_plants(j,1)==0)
            sunrise(i,1)=sunrise(i,1)+1;
        else
            sunrise(i,1)=sunrise(i,1)+1;
            break;
        end
    end
end
sunset=daylength+sunrise-1; %Time of sunset (hours)
daylength_wsup=daylength;   %Total daylength (hours)
for i=1:365
    if((i>42&&i<180)||(i>222&&i<=365))
        DLI_min=22; %Minimum daylight integral required (moles m-2 day-1)
        
    else
        DLI_min=7; %Minimum daylight integral required (moles m-2 day-1)
    end  
    DLI_inside(i,1)=sum(lightinputyear_plants((i*24)-23:(i*24)))*3600*1e-6;
    %Daylight integral at plant level (moles m-2 day-1)
    if(DLI_inside(i,1)<DLI_min)
        counter=DLI_inside(i,1);
        reqdsupple=DLI_min-DLI_inside(i,1); %Determining the required amount
        %of supplemental lighting
        hoursneeded=reqdsupple*1e6/(3600*light_lamp); %hours needed to provide
        %supplemental lighting
        if(hoursneeded>DLI_duration)
            hoursneeded=DLI_duration;
        end
        supplestartloc=sunrise(i,1)-(hoursneeded/2); %Determining the starting
        %point of providing supplemental lights
        supplestartloc=round(supplestartloc);
        if(supplestartloc<=0)
            supplestartloc=1;
        end
        k=1;
        for j=(i*24)-23:(i*24)            
            if(lightinputyear_plants(j,1)==0)
                if(k>=supplestartloc)
                    if(counter<DLI_min)
                        lightinputyear_plants_wsup(j,1)=light_lamp; % Hourly
                        %PAR light intensity at plant level.
                        counter=counter+(light_lamp*1e-6*3600); %Counter keeps
                        %track of hourly light increase in moles m-2 hr-1
                        daylength_wsup(i,1)=daylength_wsup(i,1)+1; %Counter keeps
                        %track of increase in photoperiod caused due to
                        %supplemental lighting
                    else
                        lightinputyear_plants_wsup(j,1)=lightinputyear_plants(j,1);
                        
                    end
                else
                    lightinputyear_plants_wsup(j,1)=lightinputyear_plants(j,1);
                end
            else
                if(lightinputyear_plants(j,1)<150)
                    if(counter<DLI_min)
                    lightinputyear_plants_wsup(j,1)=light_lamp+lightinputyear_plants(j,1);
                    counter=counter+(light_lamp*1e-6*3600);
                    daylength_wsup(i,1)=daylength_wsup(i,1)+1;
                    else
                        lightinputyear_plants_wsup(j,1)=lightinputyear_plants(j,1);                        
                    end
                else
                    lightinputyear_plants_wsup(j,1)=lightinputyear_plants(j,1);
                end
            end
            k=k+1;
        end
        daylength_wsup(i,1)=daylength_wsup(i,1)-1;     
    DLI_inside(i,1)=sum(lightinputyear_plants_wsup((i*24)-23:(i*24)))*3600*1e-6;     
    else
        for j=(i*24)-23:(i*24)
            lightinputyear_plants_wsup(j,1)=lightinputyear_plants(j,1);
        end
    end    
end
light_supple=lightinputyear_plants_wsup-lightinputyear_plants; %PAR light provided by the
%supplemental lighting (micromoles m-2 s-1)
lightinputyear_plants1=lightinputyear_plants;
lightinputyear_plants=lightinputyear_plants_wsup;
lightinput_wm2=lightinputyear_plants/4.54; %PAR light provided by the
%supplemental lighting and natural lighting (W/m2)
daylength1=daylength; %photoperiod without supplemental lighting (hours)
daylength=daylength_wsup; %photoperiod with supplemental lighting (hours)
heat_totallamps=zeros(8760,1); %Total heat emitted by lamps (W/m2)
electricenergy_lamps=zeros(8760,1); %Electric energy consumed by lamps (W/m2)
for i=1:8760
  if(light_supple(i,1)>0)
      heat_totallamps(i,1)=0.40*power_totallamparea;
      electricenergy_lamps(i,1)=power_totallamparea/1000; %kWh/m2
  end
end
Annualelectricenergy_lamp = sum(electricenergy_lamps(:,1)); %Annual electric 
%energy consumed by supplemental lights (kWh/m2-year)
%Monthly electric energy consumed by supplemental lighting (kWh/m2-year)
monthlyelectricenergy_lamp(1,1)=sum(electricenergy_lamps(1:744,1));
monthlyelectricenergy_lamp(2,1)=sum(electricenergy_lamps(745:1416,1));
monthlyelectricenergy_lamp(3,1)=sum(electricenergy_lamps(1417:2160,1));
monthlyelectricenergy_lamp(4,1)=sum(electricenergy_lamps(2161:2880,1));
monthlyelectricenergy_lamp(5,1)=sum(electricenergy_lamps(2881:3624,1));
monthlyelectricenergy_lamp(6,1)=sum(electricenergy_lamps(3625:4344,1));
monthlyelectricenergy_lamp(7,1)=sum(electricenergy_lamps(4345:5088,1));
monthlyelectricenergy_lamp(8,1)=sum(electricenergy_lamps(5089:5832,1));
monthlyelectricenergy_lamp(9,1)=sum(electricenergy_lamps(5833:6552,1));
monthlyelectricenergy_lamp(10,1)=sum(electricenergy_lamps(6553:7296,1));
monthlyelectricenergy_lamp(11,1)=sum(electricenergy_lamps(7297:8016,1));
monthlyelectricenergy_lamp(12,1)=sum(electricenergy_lamps(8017:8760,1));
%% Plant parameters
sla_light=zeros(8760,1); %Specific leaf area of plants as a function of light 
%(m2-leaf/kg-dryweight)
for i=1:8760
if(lightinputyear_plants(i,1)>0)
if(lightinputyear_plants(i,1)>=100&&lightinputyear_plants(i,1)<=200)
    sla_light(i,1) = (((sla_200-sla_100)/(100))*(lightinputyear_plants(i,1)-100))+sla_100;
end

if(lightinputyear_plants(i,1)>200&&lightinputyear_plants(i,1)<=300)
    sla_light(i,1) = (((sla_300-sla_200)/(100))*(lightinputyear_plants(i,1)-200))+sla_200;
end

if(lightinputyear_plants(i,1)>300&&lightinputyear_plants(i,1)<=400)
    sla_light(i,1) = (((sla_400-sla_300)/(100))*(lightinputyear_plants(i,1)-300))+sla_300;
end

if(lightinputyear_plants(i,1)>400&&lightinputyear_plants(i,1)<=500)
    sla_light(i,1) = (((sla_500-sla_400)/(100))*(lightinputyear_plants(i,1)-400))+sla_400;
end

if(lightinputyear_plants(i,1)<100)
    sla_light(i,1)=sla_100;
end

if(lightinputyear_plants(i,1)>500)
    sla_light(i,1) = sla_500; %Specific leaf area (m2 leaf g-1 structural dry weight)
%Henten et al and Virsile et al.
end
end
end
sla_avg=zeros(365,1); %Daily average specific leaf area (m2-leaf/kg-dry weight of plant)
for j=1:365
    sumlighteachday=sum(lightinputyear_plants((j*24)-23:j*24,1));
    for k=(j*24)-23:j*24
    sla_avg(j,1)=sla_avg(j,1)+(sla_light(k,1));
    end
end
sla_avg=sla_avg./daylength;
[num,text,raw]=xlsread('sla_cope.xlsx','SLA_allcases_from20191219');
sla_temp1=num(:,2); %Specific leaf area as a fuction of spectra measured in 
%terms of percentage blue light
%Computing spectral impact on specific leaf area
for i=1:101
    sla_tempratio(i,1)=sla_temp1(i,1)/sla_temp1(34,1);
end
for i=1:365
sla_temp(:,i)=sla_tempratio*sla_avg(i,1); 
end
% This segment finds an hour where light intensity is non zero. This is
% then used to determine the spectral distribution of light entering the
% greenhouse
for i=1:24
    if(Netenergypar(i,1)>0)
        sumfraclight(2,1)=Netenergypar(i,1)/(length*width);
        break;
    end
end
% This segment finds an hour where light intensity is non zero. This is
% then used to determine the spectral distribution of light entering the
% greenhouse

%Fraction of light in each wavelength between 400-700 nm
inten_fraction(:,2)= ((((Peri(21:81,i)+Perdi(21:81,i)+Pwri(21:81,i)+...
    Pwrdi(21:81,i))*(Ac/2))+((Pewi(21:81,i)...
    +Pewdi(21:81,i)+Pwwi(21:81,i)+Pwwdi(21:81,i))*Aew_transparent)+((Pnwi(21:81,i)...
    +Pnwdi(21:81,i)+Pswi(21:81,i)+Pswdi(21:81,i))*Asw_transparent))/(length*width));
sumfraclight(2,1)=sum(inten_fraction(:,2)); %sum of light in wavelength region 
%between 400-700 nm (W/m2)
ratio_scale=sumfraclight(1,1)/sumfraclight(2,1); %In order to scale up
%all light treatents to same intensity, this variable is used.
%Scaling up the fraction of light in each wavelength to get equal intensity
inten_fraction(:,2)=inten_fraction(:,2).*ratio_scale;
sumfraclight(2,1)=sum(inten_fraction(:,2)); %Light intensity 
%of each light treatments (W/m2)
frac_lightabs(:,2)=abs_plntavg.*inten_fraction(:,2).*rqy_avg; %Fraction of light absorbed 
%in wavelengths between 400-700 nm
amax_spec(2,1)=sum(frac_lightabs(:,2)); %Converting light absorbed to net
%CO2 consumed (mmol CO2/J-light)
%Computing relative change in assimilation rate as a function of spectra
temp1=amax_spec(2,1)-amax_spec(1,1);
temp2=temp1/amax_spec(1,1);
temp3=1+temp2; 
%Computing relative change in assimilation rate as a function of spectra
Amax_final(2,1)=amx*temp3; %Maximum assimilation rate of CO2 (g CO2 m-2 s-1)
eff(2,1)=eff(1,1)*temp3; %CO2 uptake per joule of light (g CO2/J)
eff_spectra(:,2)=eff(2,1).*inten_fraction(:,2).*...
1./sum(inten_fraction(:,2)); %Carbondioxide uptake per Joule of 
%light (g CO2/J light-wavelength)
blueamt(2,1)=sum(inten_fraction(1:21,2))/sum(inten_fraction(:,2));
%Fraction of blue light in each light treatment
blueamt(2,1)=blueamt(2,1)*100; %Percentage of blue light in each light
%treatment
blueamt(2,1)=round(blueamt(2,1)); %Rounding up the percentage of blue 
%light
a=blueamt(2,1); %Temporary variable holding percentage blue light
dvrvt_spec(1,1)=1/(bolting_temp(blueamt(1,1)+1,1)); %Rate of growth of plant (day-1) 
dvrvt_spec(2,1)=1/(bolting_temp(blueamt(2,1)+1,1)); %Rate of growth of plant(day-1) 
if(blueamt(2,1)>=blueamt(1,1))
                frt(2,1)=frt(1,1)+(((frt_up-frt(1,1))/(100-blueamt(1,1)))...
                    *(blueamt(2,1)-blueamt(1,1)));
            %Lower limit of fraction partitioned to
            %root 
            else
                    if(blueamt(2,1)<blueamt(1,1))
                        frt(2,1)=frt_low+(((blueamt(2,1)-0)/(blueamt(1,1)-0))...
                            *(frt(1,1)-frt_low));
                    %Lower limit of fraction partitioned to
                %root %Johkan et al
                    end
end
                fsh(2,1)=1-frt(2,1); %Fraction partitioned to shoot
                flv(2,1)=0.8; %Fraction partitioned to leaves
                
                sla_year(1,:)=sla_temp(blueamt(2,1)+1,:); 
                %Specific leaf area of plant-temporary variable (m2-leaf/kg
                %dry weight)
                sla_year=sla_year*1e-3; %Specific leaf area (m2-leaf/g-dry weight)
                  fst(2,1)=1-flv(2,1); %Fraction partitioned by stems
                  fso(2,1)=1-flv(2,1)-fst(2,1); %Fraction partitioned by storage

    for i=1:365
lightinput_wm2daily(i,1)=sum(lightinput_wm2(i*24-23:i*24,1))/daylength(i,1);
%Daily average PAR light intensity (W/m2)   
    end
inten_lightinputwm2=zeros(61,365); %Daily spectral PAR light intensity (W/m2-nm)
sumintenfrac=sum(inten_fraction(:,2)); %Daily average PAR light intensity (W/m2)
for i=1:365
    inten_lightinputwm2(:,i)=lightinput_wm2daily(i,1).*inten_fraction(:,2)/...
        (sum(inten_fraction(:,2))); %Fraction of light in each wavelength (W/m2-nm)
end
  

%% Computing actual wet-bulb temperature as air flows over the evaporative cooling pad
Twb=(efficiencyevap*Twb)+(Tao.*(1-efficiencyevap)); %Actual wet-bulb temperature as 
%it enters the greenhouse (C)
%% Initial conditions
%1-Top surface of ground
%2-Vegetation
%3-Air beneath the shades inside the greenhouse
%4-Area of walls and greenhouse roof (inner surface)
%5-Inner surface of ground
%6-Area of walls and greenhouse roof (outer surface)
%7-Air above the shades inside the greenhouse
const_temp = Tmin1(1)+(Tmax1(1)-Tmin1(1))/2; %Initial value of temperature for all 
%components of a greenhouse (C)
const_temp = const_temp.*ones(1,7); 
const_temp(1,5)=Tgw;
counttemp=size(const_temp);
counttemp=counttemp(1,2);
Totalrhin=(rhnight(1)+rhday(2))/2; %Initial value of relative humidity of air inside the
%greenhouse
Totalconsttemp(1,:)=const_temp; %Same as const_temp
%% Declaring variables
TotalTmin=zeros(8760,1); %Assigns the minimum set-point temperature for every hour 
%(degrees C)
TotalTmax=zeros(8760,1); %Assigns maximum set-point temperature for every hour 
%(degrees C)
TotalTmid=zeros(8760,1); %Assigns the mid-point temperature for every hour 
%(degrees C)
po=zeros(1,counttemp); %Variable that holds the temperature values from the previous 
%iteration.
Told=zeros(1,counttemp); %Temperature obtained in the previous iteration 
%(degrees C)
Qsumheat=zeros(8760,1); %Hourly heating demand for space heating (J/m2-hr)
Qsumplantheat=zeros(8760,1); %Hourly heating demand for plant heating (J/m2-hr)
th=zeros(8760,counttemp); %Temperature matrix consisting of all the variables for which 
%temperature changes are tabulated inside the greenhouse (degrees C)
nh=zeros(8760,1);%Matrix that holds air changes per hour
hum_mat=zeros(8760,1); %Keeps track of hourly humidification energy needed for the
%greenhouse to maintain the set-relative humidity (J/m2-hr)
dehum_mat=zeros(8760,1); %Keeps track of hourly dehumidification energy needed for the
%greenhouse to maintain the set-relative humidity (J/m2-hr)
Qheatremoved_mat=zeros(8760,1); %Hourly load removed from the greenhouse due to fan
%ventilation (J/m2-hr)
Qheatadded_mat=zeros(8760,1); %Hourly load added to the greenhouse due to fan
%ventilation (J/m2-hr)
trans_year=zeros(8760,1); %Hourly transpiration energy added to greenhouse over the
%entire year (J/m2-hr)
trans_year_mass=zeros(8760,1); %Mass of water added to greenhouse air via transpiration
%(kg/m2-year)
vent_year=zeros(8760,1); %Hourly energy transferred due to humidity exchanged 
%between ambient air and greenhouse environment through ventilation (W/m2)
inf_year=zeros(8760,1); %Hourly energy transferred due to humidity exchanged 
%between ambient air and greenhouse environment through infiltration (W/m2)
rhinhour=zeros(8760,1); %Hourly relative humidity of air beneath the shades 
%inside the greenhouse
humw_matrix=zeros(8760,1); %Amount of water added to air inside the greenhouse 
%per second to humidify the greenhouse when the relative humidity drops below set-point
%(kg/m2). This stores value for every second for which the code is run in
%an hour
signalvent=0; %Signal triggering ventilation. Value of 1 indicates that
%ventilation fan is on. Value of 0 indicates that the fan is 0.
Qbenchheat=0; %Heat per second added for maintaining the temperature of
%vegetation (W/m2)
signalplantheat=0; %Signal triggering rootzone heating (plant heating).
%Value of 1 indicates that heating is active. Value of 0 indicates that 
%the heating is inactive.
nhum_m=zeros(8760,1); %Ventilation air changes per hour added to greenhouse for
%dehumidification
rhinhourtop=zeros(8760,1); %Hourly relative humidity of air inside the greenhouse 
%above the shade
Qsl=zeros(8760,1); %Heating that accounts for transition period when the shades are
%rolling in or out (J/m2-hr) 
nh_sl=zeros(8760,1); %Air changes per hour that accounts for transition period 
%when the shades are rolling in or out (J/m2-hr) 
ventilation_powerhour=zeros(8760,1); %Power consumed by ventilation (kWh)
watercons_evaphour=zeros(8760,1); %Water consumption from evaporative fan pad cooling
%(m3/hr)
for i=1:8760
        TotalTmin(i,1)=Tmin1(i,1);
        TotalTmax(i,1)=Tmax1(i,1);
        TotalTmid(i,1)=(TotalTmin(i,1)+TotalTmax(i,1))/2;
        
end

%% Sizing heating system
U_roof_cond=1/((tc/kr)); %Conductance through the roof of the greenhouse (W/m2-K)
Qlossmax = (Ur*Acft*(((TotalTmax*1.8)+32)-((Tao*1.8)+32)))+...
(Uglass*Netwallsurfaceareaft*(((TotalTmax*1.8)+32)-((Tao*1.8)+32))); %Maximum heat loss
%possible from greenhouse. This is used for sizing the greenhouse (Btu/hr)
Qlossmaxwatts = (Qlossmax*1055.06)/3600; %Convert Qlossmax to W
Qinf=dena*cpa*(V/3600)*(TotalTmax-Tao); %Heat loss/gain due to infiltration (W)
qcs=(kg*(length*width)*(TotalTmax-Tgw))/(ts1+ts2); %Heat loss to the ground (W)
qp=Fp*P_ground*(TotalTmax-Tao); %Perimeter heat loss (W)
Qlosstotal=Qlossmaxwatts+Qinf+qcs+qp; %Total heat exchange (W) 
Qlossmaxwattsarea = (Qlosstotal*LAI)/Av; %Total heat exchange per unit area (W/m2)
Qlossmaxwattsarea=max(Qlossmaxwattsarea); %Total heat exchange per unit area (W/m2)

%% Timestep

% Timestep is changed and can be varied as desired throughout the energy
% balance process
ts_reduced=2; 
ts_daynight=2;
% Timestep is changed and can be varied as desired throughout the energy
% balance process
%% Heating, cooling load and greenhouse temperature and energy tabulation 
% Intermittent spot to save files as needed
matFileName = fullfile(pwd, sprintf('temp_100nm_%d.mat',pcov*100));
save(matFileName);

 plntcounter = 1;
 
options = optimset('Display','off');

tic
%Start loop for energy load calculations.
%Total loop is for 8760 hours
% These steps highlight the control process involved in determining when shade cloth are deployed.
% When heating and ventilation systems are activated as well as the evaporative cooling process. 
fprintf('Energy model calculation in progress\n');
for i=1:1 %For 1st hour, we have
        ct_sec=1; %Parameter that increments according to step size.
         trigger=0; %This is a variable that keeps track of heat 
         %is spent to raise the greenhouse air from one set-point to another.
         trigger_cool=0;%This keeps track of air changes needed
         %to reduce set-point temperature to lower value.
         x=zeros(3600,counttemp);%Temperature matrix consisting of the temperature 
         %values of the components in a greenhouse-outer surface of ground, 
         %plants, air below shade, inside part of roof, inner surface of ground, 
         %outside part of roof,air above the shade
         x(1,:)=Totalconsttemp(1,:); %Assign initial temp.
         rhpsec=Totalrhin(1,1); %Assign initial relative humidity
         %for air beneath the greenhouse
         rhpsec_top=Totalrhin(1,1); %Assign initial relative humidity
         %for air above the greenhouse
         fp=0; %evaporative cooling signal
         signalcool=0;%Trigger for cooling
         signalheat=0;%Trigger for heating
         signalvent=0;%Trigger for ventilation humidity control
         Ts=Tsky(i,1);%Sky temperature (Kelvin)
         Rs=(sig*(Ts)^4); %Radiation from the sky (W/m2)
         j=1; %counter that increments by 1 at every timestep
         Q=zeros(3600,1); %Space heating at every timestep is stored here (W/m2)
         ns=zeros(3600,1); %air changes per timestep 
         hum=zeros(3600,1); %Humidification energy per timestep (W/m2)
         dehum=zeros(3600,1); %Dehumidification energy per timestep (W/m2)
         trans_mat=zeros(3600,1); %Transpiration energy per timestep (W/m2)
         vent_mat=zeros(3600,1); %Ventilation energy per timestep (W/m2)
         inf_mat=zeros(3600,1); %Infiltration energy per timestep (W/m2)
         Qheatremoved=zeros(3600,1); %Heat removed by ventilation per timestep (W/m2)
         Qheatadded=zeros(3600,1); %Heat added by ventilation per timestep (W/m2)
         humw=zeros(3600,1); %Water content added during humidification per timestep (kg/m2-s)
         Q_shts=zeros(3600,1); %Space heating after accounting for timestep (W/m2)
         Qplantheat=zeros(3600,1); %Plant heating at every timestep  (W/m2)
         nhum=zeros(3600,1); %Air changes for humidity control per timestep 
         ventilation_powersec=zeros(3600,1); %Electric power consumed by ventilation per timestep
         %(W)
         watercons_evapsec=zeros(3600,1); %Water consumption in evaporative fan pad cooling
         %(m3/s)
         while(ct_sec<3600) %Loop that keeps counts of the hour
          
            if(j==1) %For the first second, we start with basic timestep;
                timestep=1; %Timestep is one
            else 
                if(x(j,3)>=TotalTmax(i,1)) %If current temperature of air beneath shade 
                    %was greater than maximum temperature set-point
                    signalcool=1; %Control that triggers ventilation activates
                end
                if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0) %If temperature 
                    %of air beneath the shade is lower than the maximum temperature
                  %set-point but higher than the mid-point temperature,
                  %then control that triggers heating is turned off.
                    signalheat=0; %Control that triggers heating is deactivated.
                end
                if(x(j,3)<TotalTmid(i,1)&&x(j,3)-TotalTmin(i,1)>=0) %If temperature 
                  %of air beneath the shade is lower than the midpoint temperature
                  %set-point but higher than the lower temperature
                   signalcool=0;  %then control that triggers cooling for temperature 
                   %control is turned off.
               end
               if(x(j,3)<TotalTmin(i,1)) %If temperature of air beneath the shade is 
                   %lower than the minimium temperature set-point
                   signalheat=1; %Control that triggers space heating is activated.
               end
               if(signalheat==1&&signalplantheat==1) %If plant heating control and space 
                   %heating control are activated.Generally, timestep is kept low when 
                   %temperature of a layer, is close to set-point temperature. This was 
                   %done so that the higher timestep doesn't lead to temperature of the 
                   %layer exceeding the set-point temperature by a large value. 
                   %That would lead to higher heating load or ventilation air changes. 
                   %However, plants are heated by a low radiation source, 
                   %chances of their temperature going well beyond the set-point is less. 
                   %So we gradually raise the timestep as shown below. However,
                   %space heating is heated by a much larger heat source and
                   %hence, we have a lower timestep.
                     timestep=ts_reduced; %Time step is the reduced timestep.
                 else
                     if(signalheat==0&&signalplantheat==1) %If only plant heating 
                     %control is active
                         timestep=timestep+2; %Keep increasing timestep by 2
                     else 
                        if(signalheat==0&&signalplantheat==0) %if both controls are off
                            if(signalvent==1) %If ventilation for humidity control is 
                                %active
                                if(x(j,3)>x(j-1,3)) %if temperature of air beneath 
                                    %shade is higher than the previous step
                                    timestep=timestep+2; %Timestep increases by two.
                                else
                                    if(x(j-1,3)-x(j,3)<0.1) %If temperature of air 
                                    %decrease with ventilation but the reduction is 
                                    %very small
                                        timestep=timestep+2; %timestep increases
                                    else
                                        timestep=ts_reduced; %Timestep is back to 
                                        %reduced value.
                                    end
                                end
                            else
                                if(signalcool==1) %Ventilation for temperature control 
                                    %is active
                                    if(x(j,3)>x(j-1,3)) %Sometimes the temperature of 
                                    %air at the current timestep is higher than the 
                                    %previous time step even after ventilation is 
                                    %activated.This usually happens in summer. 
                                    In such a case:
                                        if(x(j-1,3)<=TotalTmax(i,1)) %If the temperature 
                                        %of air in the previous timestep is less than the 
                                        %upper limit of set-point temperature, then
                                            timestep=ts_reduced; %We keep the lower 
                                            %timestep in that case, since we are close 
                                            %to the temperature limit
                                        else
                                            timestep=timestep+2; %If the previous 
                                            %timestep already exceeded the temperature 
                                            %set-point, then we keep increasing the 
                                            %timestep, without increasing the chances 
                                            %of encountering an error.
                                        end
                                
                              
                                    else
                                
                             
                                        if(x(j-1,3)-x(j,3)<0.1) %If the temperature of air is 
                                        %reducing in the current timestep when compared to 
                                        %the previous timestep, but if the reduction is low
                                            timestep=timestep+2; %Then we keep increasing the 
                                        %timestep
                                        else
                                    
                                            timestep=ts_reduced; %If the temperature 
                                            %drop of air in the current timestep is 
                                            %lower than previous timestep and this drop 
                                            %is greater than 0.1, then we keep the 
                                            %timestep low.
                                        end
                                
                                    end
                            
                                else
                             
                                    timestep=timestep+2;  %If signalcool isn't active, 
                                    %then timestep is increased
                                end
                         
                            end 
               
                        else
                         
                            if(signalheat==1&&signalplantheat==0) %If only space heating 
                                %is active
                                timestep=ts_reduced; %Timestep is reduced to lower value
                            end
                       
                        end
                     
                     end
                 
                 end
             
            end
            ct_sec1=ct_sec+timestep; %Depending on the timestep, this counter is 
            %changed.
            if(ct_sec1>3600) %If because of the timestep, the counter exceeds 3600, 
            %then the timestep is lowered until the counter gets to 3600.          
              while(ct_sec1>3600)
                    timestep=timestep-1;
                    ct_sec1=ct_sec+timestep;
              end
             
            end
          
            if(ct_sec1<=3600)
              ct_sec=ct_sec1;
            end
          
      
      
            if(j==1)%For the first second of the first hour, since we need a 
            %starting point, it is assumed that the initial temperature is in between 
            %the setpoint temperature range.
                po=x(j,:); %Assign the current value of temperature of all components to po
                Told=po; %Assign the value in po to Told 
                if(x(1,3)>TotalTmin(i,1)&&x(1,3)<TotalTmax(i,1)) %If the initial 
                %temperature is in between the minimum and maximum temperature 
                %set-point.
                    Q(j,1)=0;%Assign heating value at this instant as 0.  
                    if(signalvent==1) %signalvent==1 denotes need for dehumidification
                        nshade=nsat/30;%If the condition is true, then ventilation is 
                        %started. nshade denotes ventilation in cfm/ft2-min
                        nhum(j,1)=((nshade*Avft)/(LAI*60*V1ft));%Since this is used for 
                        %humidity control, it is assigned to nhum.
                        nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                        %to nhum.                                        
                    end
              
                    if(signalvent==0)
                        nshade=0; %If humidity is within set-point, then ventilation is 
                        %not needed
                        nhum(j,1)=0;
                    end
                    nmax = ((nshade*Avft)/(LAI*60*V1ft)); %Air changes per second
                    vmax = nmax*V1; %Volume change per second (m3/s)
                    v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                    TotalTmin(i,1))/2)+(pi()/2)); 
                    %Volume flow rate depending on the temperature obtained in the 
                    %previous iteration.From kimball et al.
                    nnew = v/V1; %Updated air change rate
                    ns(j,1)=timestep*nnew; %Assign air change rate for every second 
                    %to ns.
                    fp = 0; %Fraction of air flowing through the pad system
                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                    timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                    transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                    Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                    dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                    fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                    tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options); %Solve for the 
                    %temperature of each component for the next step
                    %using parameters mentioned in the first step.
                    %hvac_fnroofshade2 - denotes the case where shades are rolled
                    %inside the greenhouse.
                end
            
            end
      
            if(j>1) %For subsequent steps where index of j is greater than 1
                po=x(j,:); %Assign the current value of temperature of all components 
                %to po
                Told=po; %Assign the value in po to Told 
                if(x(j,3)>=TotalTmax(i,1)) %If air temperature inside the greenhouse 
                %below the shade is greater than the maximum set-point temperature.
                    nhum(j,1)=0;
                    signalcool=1; %Trigger for denoting the need to start ventilation 
                    %for temperature control
                    Q(j,1)=0; %Assign heating value at this instant as 0. 
                    if(Totaltemp(i,1)>TotalTmax(i,1)) %If ambient air temperature is 
                    %greater than the maximum set-point temperature

                        fp = 1; %Fraction of air flowing through the pad system
                        
                            
                        nmax = ((nsat*Avft)/(LAI*60*V1ft)); %Air changes per second
                        nnew = nmax; %Updated air change rate
                        vmax = nmax*V1;  %Volume change per second (m3/s)
                        v = vmax; %Volume flow rate (m3/s)
                        ns(j,1)=timestep*nmax; %Assign air change rate for every second to ns.
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                        timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                        transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,...
                        Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,...
                        rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                        tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
                    else%If ambient air temperature is lower than the maximum
                        %set-point temperature
                        if(j>1)
                            if(x(j-1,3)>=TotalTmax(i,1)&&x(j-1,3)<x(j,3))
                                fp=1;
                                coolfast=1;
                            else
                                fp=0;
                            end
                        else  
                        fp = 0; %Fraction of air flowing through the pad system
                        end
                        nmax = ((nsat*Avft)/(LAI*60*V1ft));  %Air changes per second
                        nnew = nmax; %Updated air change rate
                        vmax = nmax*V1; %Volume change per second (m3/s)
                        v = vmax; %Volume flow rate (m3/s)
                        ns(j,1)=timestep*nmax; %Assign air change rate for every second to ns.
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                        tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                        Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                        dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                        tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
                    end
                    
        
                    if(i>1)
                %For second hour or greater
                %When there is a switch in temperature from a higher 
                %setpoint (usually during the day) to a lower stepoint 
                %(usually at night), 
                %the air has to be initially
                %cooled. This is the variable that keeps a note that.
                        if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0) 
                            %At the time of 
                        %change in temperature set-point
                            nh_sl(i,1)=nh_sl(i,1)+ns(j,1); %The air change per hour 
                            %needed to bring down the temperature of air inside the 
                            %greenhouse beneath the shade from within a higher and lower temperature 
                            %set-point to within a changed higher and lower temperature
                            %set-point
                        end
                    
        
                    end
                
        
                end
                
                
        
                if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0)  %If air temperature inside 
            %the greenhouse below the shade is above the mid-point temperature and 
            %maximum temperature set-point
            
                    if(i>1)
              %Similar to providing cooling to bring air temperature inside the 
              %greenhouse below the shade from within a higher set-point temperature 
              %value to within a changed higher set-point temperature value, there is 
              %also a case for heating to reach within a changed higher value of 
              %temperature set-point. When the air exceeds the changed min. temperture 
              %set-point and crosses the heating cut-off point for the first time, 
              %the total heating required for this process is tabulated. This is the 
              %heating spent for transitioning from one set-point to the other
                        if(TotalTmin(i-1,1)~=TotalTmin(i,1))
                            trigger=1; %Marks the point till where, the heating incurred 
                    %should be considered as the transition heating.
                        end
                
                    end 
            
                    signalheat=0; %Trigger indicating heating requirement is not needed
                    if(signalcool==1) %Trigger for denoting the need to start ventilation 
            %for temperature control
                        Q(j,1)=0; %Assign heating value at this instant as 0.
                        nhum(j,1)=0;
                        if(Totaltemp(i,1)<=TotalTmax(i,1)) %If air temperature inside the 
                        %greenhouse below the shade is lower than the maximum set-point 
                        %temperature.
                            if(coolfast==1)
                                fp=1;
                            else
                                fp =0; %Fraction of air flowing through the pad system
                            end
                            nmax = ((nsat*Avft)/(LAI*60*V1ft)); %Air changes per second
                            vmax = nmax*V1; %Volume change per second (m3/s)
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));
                            %Volume flow rate (m3/s)
                            nnew = v/V1; %Updated air change rate
                            ns(j,1)=timestep*nnew; %Assign air change rate for every second to ns.
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                            timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                            transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,...
                            Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                            dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                            fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                            tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                            %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
                        else
                        
                            fp = 1; %Fraction of air flowing through the pad system    
                            nmax = ((nsat*Avft)/(LAI*60*V1ft)); %Air changes per second
                            vmax = nmax*V1; %Volume change per second (m3/s)
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));%Volume flow rate (m3/s)
                            nnew = v/V1; %Updated air change rate
                            ns(j,1)=timestep*nnew; %Assign air change rate for every second to 
                            %ns.
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...                                                                                                                                                                                                                                                                                                                                                                                                                                                                       timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                            transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                            Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                            dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                            fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                            tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                            %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
                        end
                
                    else%If signalcool is 0 then ventilation for temperature control 
                        %is not needed        
                        if(signalvent==1) %signalvent==1 denotes need for dehumidification
                            nshade=nsat/30; %If the condition is true, then ventilation is 
                            %started. nshade denotes ventilation in cfm/ft2-min
                            nhum(j,1)=((nshade*Avft)/(LAI*60*V1ft));%Since this is used for 
                            %humidity control, it is assigned to nhum.
                            nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                            %to nhum.     
                        end
                
         
                        if(signalvent==0)
                            nshade=0; %If humidity is within set-point, then ventilation is not 
                            %needed
                            nhum(j,1)=0;
                        end
                        Q(j,1)=0; %Assign heating value at this instant as 0.
                        fp = 0;  %Fraction of air flowing through the pad system  
                        nmax = ((nshade*Avft)/(LAI*60*V1ft)); %Air changes per second
                        vmax = nmax*V1; %Volume change per second (m3/s)
                        v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+TotalTmin(i,1))/2)+...
                        (pi()/2));%Volume flow rate (m3/s)
                        nnew = v/V1; %Updated air change rate
                        ns(j,1)=timestep*nnew; %Assign air change rate for every second to ns.
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                        timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                        transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                        Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                        dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                        tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
                    end
                    if(i>1) %if the current hour is not the first hour of the 
                            %simulation
                        if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0) 
                        %At the time of change in temperature set-point the air change 
                        %per hour needed to bring down the temperature of air inside the 
                        %greenhouse beneath the shade from within a higher and lower 
                        %temperature set-point to within a changed higher and lower 
                        %temperature set-point is given here
                            nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                        end
                
        
                    end
            
        
                end
        
        
                if(x(j,3)<=TotalTmin(i,1)) %If air temperature inside the greenhouse 
                %below the shade is less than the minimum temperature set-point
                    nhum(j,1)=0; %Ventilation for humidity control = 0
                    nshade=0; %Volume changes in cfm/ft2 provided through ventilation
                    signalheat=1; %Trigger indicating need for heating
                    signalcool=0; %Cooling is switched off
                    Q(j,1)=Qlossmaxwattsarea; %The amount of heat supplied to the 
                    %greenhouse is stored in Q
                    if(i>1) %For hours other than the fisrt hour of the simulation
                        if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) %Condition for 
                        %heating to account for change in set-point temperature
                            if(TotalTmin(i,1)-x(j,3)>0) %If temperature of air inside the 
                            %greenhouse beneath  the shade is lower than the updated 
                            %minimum set-point temperature 
                                Qsl(i,1)=Qsl(i,1)+Q(j,1); %Heat added to the greenhouse 
                                %is accounted as transition heating 
                            end
                        
                
                        end
                    
                
                    end                         
                    fp = 0; %Fraction of air flowing through the pad system
                    nmax = ((nshade*Avft)/(LAI*60*V1ft)); %Air changes per second
                    nnew = nmax; %Updated air change rate
                    vmax = nmax*V1; %Volume change per second (m3/s)
                    v = vmax; %Updated air change rate
                    ns(j,1)=timestep*nmax;  %Assign air change rate for every second to 
                    %ns.
                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                    timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                    transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),...
                    Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,...
                    Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                    tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                    %Solve for the temperature of each component for the next step
                    %using parameters mentioned in the first step.
                    %hvac_fnroofshade2 - denotes the case where shades are rolled
                    %inside the greenhouse.
                end 
                if(x(j,3)>TotalTmin(i,1)&&x(j,3)-TotalTmid(i,1)<=0) %If air temperature 
                %inside the greenhouse below the shade is between the minimum temperature setpoint
                %and mid-point temperature
                    signalcool=0; %Trigger indicates that ventilation for temperature 
                    %control is turned off  
                    coolfast=0;
                    if(signalheat==1) %Trigger that indicates heating requirement
                        nhum(j,1)=0; 
                        Q(j,1)=Qlossmaxwattsarea; %The amount of heat supplied to the 
                        %greenhouse is stored in Q
                        if(i>1) %if the current hour is not the first hour of the 
                            %simulation
                            if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                                %Condition for heating to account for change in 
                                %set-point temperature
                                if(TotalTmid(i,1)-x(j,3)>0) %If air temperature beneath 
                                %the shade inside the greenhouse is lower than the 
                                %mid-point temperature
                                    Qsl(i,1)=Qsl(i,1)+Q(j,1); %Heat added to the 
                                    %greenhouse is accounted as transition heating 
                                end
                        
          
                            end
                    
          
          
                        end
                
          
                        if(i>1)%if the current hour is not the first hour of the 
                            %simulation
                            if(TotalTmax(i-1,1)~=TotalTmax(i,1)) %At the time of change 
                            %in temperature set-point the air change per hour needed to 
                            %bring down the temperature of air inside the greenhouse 
                            %beneath the shade from within a higher and lower temperature 
                            %set-point to within a changed higher and lower temperature 
                            %set-point is given. Here, when the air temperature beneath 
                            %shade goes below the mid-point temperature the cooling for 
                            %transitioning between set-point is complete. 
                
                                trigger_cool=1; %Trigger_cool indicates the same
                            end
                
         
                        end
             
         
                        fp = 0; %Fraction of air flowing through the pad system
                        nmax = ((nshade*Avft)/(LAI*60*V1ft)); %Air changes per second
                        vmax = nmax*V1; %Volume change per second (m3/s)
                        v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));%Updated air change rate
                        nnew = v/V1; %Updated air change rate
                        ns(j,1)=timestep*nnew;%Assign air change rate for every second 
                        %to ns.  
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                        Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,tc,...
                        transmittance_roof,transmittance_wall,Rs,ts1,...
                        ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                        Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                        Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
                    else %If signalheat is zero      
                        if(signalvent==1) %signalvent==1 denotes need for 
                        %dehumidification
                            nshade=nsat/30; %If the condition is true, then ventilation 
                            %is started.nshade denotes ventilation in cfm/ft2-min
                            nhum(j,1)=((nshade*Avft)/(LAI*60*V1ft));%Since this is used for 
                            %humidity control, it is assigned to nhum.
                            nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                            %to nhum.     
                        end
                
                        if(signalvent==0) %Humidity is within set-point 
                            nshade=0; %Ventilation is turned off.
                            nhum(j,1)=0;
                        end
                
                        Q(j,1)=0; %The amount of heat supplied to the greenhouse is 
                        %stored in Q
                        fp = 0;  %Fraction of air flowing through the pad system  
                        nmax = ((nshade*Avft)/(LAI*60*V1ft)); %Air changes per second
                        vmax = nmax*V1; %Volume change per second (m3/s)
                        v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                        TotalTmin(i,1))/2)+(pi()/2)); %Updated air change rate
                        nnew = v/V1; %Updated air change rate
                        ns(j,1)=timestep*nnew; %Assign air change rate for every second 
                        %to ns.
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                        timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                        transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),...
                        Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,...
                        Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                        tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
                    end
            
            
                end
        
        
            end

          %Plants can lose temperature due to long wave radiation.
          %In greenhouses, there is loop providing heat at the roof of 
          %the plant. This is bench heating system. Roughly a greenhouse
          %employs 50-85 W/m2 of heat to the plants. from the bench heating
          %system. Anything more than this can damage plants.
          if(x(j+1,2)<Tplants(i,1)) %If plant temperature is lower than minimum set-point 
              %temperature
              signalplantheat=1; %Trigger denoting plant needs heating
              Qbenchheat=50; %Heating value is assigned to Qbenchheat
              Qplantheat(j+1,1)=timestep*Qbenchheat; %This heating value per second is 
              %assigned to Qplantheat
          end
          if(x(j+1,2)>=Tplants(i,1)&&x(j+1,2)<=Tplants(i,1)+0.5) %If plant temperature is between 
              %the minimum set-point temperature and mid-point temperature
              if(signalplantheat==1) %If trigger indicates plant heating
                 Qbenchheat=50; %Heating value is assigned to Qbenchheat (W/m2)
                 Qplantheat(j+1,1)=timestep*Qbenchheat; %This heating value per second 
                 %is assigned to Qplantheat
              else %If trigger is 0, then heat to plants become zero.
                  Qbenchheat=0; %Heating value is assigned to Qbenchheat
                 Qplantheat(j+1,1)=Qbenchheat; %This heating value per second is 
                 %assigned to Qplantheat
              end
          end
      
          if(x(j+1,2)>Tplants(i,1)+0.5) %If plant temperature is greater than mid-point 
              %temperature
              signalplantheat=0; %Trigger for plant heating becomes 0.
              Qbenchheat=0; %Heating value is assigned to Qbenchheat
              Qplantheat(j+1,1)=Qbenchheat; %This heating value per second is assigned 
              %to Qplantheat
          end
    
          [trans,vent,infiltration,rhsec,mhum]=humidity(efficiencyevap,Aground,achinf,timestep,dena,cpa,fp,rhpsec,Tao(i,1),...
          rhao(i,1),ns(j,1),V1,P,L,LAI,Netenergy(i,1),c1,c2,c3,c4,c5,c6,Told);  
          %Function file for humidity calculator-below shade
          Vtop=V-V1; %Vtop denotes volume above the shade
          rhsectop=humidityup(Aground,achinf,timestep,dena,cpa,rhpsec_top,Tao(i,1),...
          rhao(i,1),Vtop,P,L,Told); %Function file for humidity calculator-above shades         
          rhpsec=rhsec; %Assigning the new relative humidity in the region beneath the 
          %shade for air to the variable holding the previous step's relative humidity
          rhpsec_top=rhsectop; %Assigning the new relative humidity in the region above 
          %the shade for air to the variable holding the previous step's relative humidity
          trans_mat(j,1)=trans; %Notes latent heat flux lost due to transpiration 
          %per second (W/m2)
          vent_mat(j,1)=vent; %Notes latent heat flux lost due to ventilation per second (W/m2)
          inf_mat(j,1)=infiltration; %Notes latent heat flux lost due to infiltration (W/m2)
          %per second
          diff=trans-vent-infiltration; %Computes net variation in latent load (W/m2)
          if(diff>0) %If variation in latent load is positive
            dehum(j,1)=diff; %diff becomes net dehumidification load (W/m2)
            hum(j,1)=0;
    
          else
            hum(j,1)=-diff; %-diff becomes humidification load (W/m2)
            dehum(j,1)=0;
          end
        
          humw(j,1)=mhum; %Amount of water sprayed inside the greenhouse to the air 
          %beneath the greenhouse to keep relative humidity at the lower set-point if 
          %it goes below set-point
          if(x(j,3)>Tao(i,1)) %If temperature of air beneath the shade is greater than the outside
          %air temperature.
            Qheatremoved(j,1)=dena*cpa*ns(j,1)*(V1/(length*width))*(x(j,3)-Tao(i,1)); 
            Qheatadded(j,1)=0;
            %heat removed due to ventilation
          else
            Qheatadded(j,1)=dena*cpa*ns(j,1)*(V1/(length*width))*(x(j,3)-Tao(i,1));
            Qheatremoved(j,1)=0;
            %heat added due to ventilation
          end

            %Relative humidity check with assigned value.
            if(Totalnetenergy(i,1)==0) %For night time conditions
                if(rhsec>rhnight(2)) %If relative humidity is greater than the 
                    %maximum relative humidity set-point
                    signalvent=1; %Trigger ventilation for humidity control
                end

                if(rhsec<=rhnight(1)) %If relative humidity is lower than the mid point 
                    %relative humidity set-point
                    signalvent=0; %Ventilation is turned off
                end

            else %For daytime conditions
                if(rhsec>rhday(2)) %If relative humidity is greater than the maximum 
                    %relative humidity set-point
                    signalvent=1;  %Trigger ventilation for humidity control
                end
                if(rhsec<=rhday(1)) %If relative humidity is lower than the mid-point 
                    %relative humidity set-point
                    signalvent=0; %Ventilation is turned off
                end
            
            end
        
            Q_shts(j,1)=timestep*Q(j,1); %Space heating after accounting for timestep (W/m2)
            maxach=nsat*Avft*60/(LAI*V1ft); %Maximum air changes per hour
            maxacheachfan=maxach/2; %Maximum air changes per fan (assuming 2 fans)
            nheachfan=ns(j,1)/2; %air changes per fan
            timeperhour=nheachfan/maxacheachfan; %Time each fans runs
            ventilation_powersec(j,1)=Voltage*Current*phasefactor*RMSvalue*...
            timeperhour*2/1000; %Electric power consumed by 2 fans (kWh) 
            if(fp==1)
                [watercons_evap]=evapcooling_water(dena,V1,ns(j,1),Aground,Totaltemp(i,1),...
                Totalrhao(i,1),efficiencyevap); %Function that computes amount of water consumed
                %from evaporative fan pad cooling (kg/m2-s)
                watercons_evapsec(j,1)=watercons_evap; 
            else
                watercons_evapsec(j,1)=0;
            end
            j=j+1;

         end
       
        humw_matrix(i,1)=sum(humw(1:j-1,1));%Total water per unit ground area added 
        %to the greenhouse in a hour (kg/m2-hour)
        rhinhour(i,1)=rhsec; %Assign relative humidity of air beneath shade inside 
        %the greenhouse at the end of an hour to rhinhour
        rhinhourtop(i,1)=rhsectop; %Assign relative humidity of air above shade inside 
        %the greenhouse at the end of an hour to rhinhourtop
        trans_year(i,1)=sum(trans_mat(1:j-1,1)); %Assign hourly heat flux loss due to 
        %transpiration (W/m2)
        trans_year_mass(i,1)=trans_year(i,1)/L; %Assign hourly water addtion per unit 
        %area to greenhouse air beneath shade due to transpiration (kg/m2)
        vent_year(i,1)=sum(vent_mat(1:j-1,1)); %Hourly latent flux addition or removal 
        %in the region beneath the shade due to ventilation (W/m2)
        inf_year(i,1)=sum(inf_mat(1:j-1,1)); %Hourly latent flux addition or removal in 
        %the region beneath the shade due to infiltration (W/m2)
        Qheatremoved_mat(i,1)=sum(Qheatremoved(1:j-1,1)); %Hourly heat flux removed due 
        %to ventilation (W/m2)
        Qheatadded_mat(i,1)=sum(Qheatadded(1:j-1,1)); %Hourly heat flux added due to 
        %ventilation (W/m2)
        hum_mat(i,1)=sum(hum(1:j-1,1)); %Total humidification load per unit ground area (W/m2)
        dehum_mat(i,1)=sum(dehum(1:j-1,1)); %Total dehumidification load per unit ground 
        %area (W/m2)
        Qsumheat(i,1)=sum(Q_shts(1:j-1,1)); %Total heating per unit area supplied to air 
        %beneath the shade per hour (W/m2)
        Qsumplantheat(i,1)=sum(Qplantheat(1:j-1,1)); %Total heating per unit area 
        %supplied to plants per hour (W/m2)
        nh(i,1)=sum(ns(1:j-1,1)); %Hourly air changes due to ventilation 
        th(i,:)=x(j,:); %Temperature of all components of the greenhouse at the end of an hour (degree celsius)
        ventilation_powerhour(i,1)=sum(ventilation_powersec(1:j-1,1));      
        watercons_evaphour(i,1)=sum(watercons_evapsec(1:j-1,1));
        nhum_m(i,1)=sum(nhum(1:j-1,1)); %air changes in an hour for 
        %humidity control

end

a=1;

%Starting condition for other hours
for i=2:8760
         it=i
         ct_sec=1; %Parameter that increments according to step size.
         trigger=0; %This is a variable that keeps track of heat 
         %is spent to raise the greenhouse air from one set-point to another.
         trigger_cool=0; %This keeps track of air changes needed
         %to reduce set-point temperature to lower value.
         x=zeros(3600,counttemp); %Temperature matrix consisting of the temperature 
         %values of the components in a greenhouse-outer surface of ground, 
         %plants, air below shade, inside part of roof, inner surface of ground, 
         %outside part of roof,air above the shade
         x(1,:)=th(i-1,:);%Temperature from previous hour is
         %assigned the initial value
         rhpsec=rhinhour(i-1,:); %Relative humidity beneath the shade for air from the previous
         %hour is assigned the initial value
         rhpsec_top=rhinhourtop(i-1,:); %Relative humidity above the shade for air from the previous
         %hour is assigned the initial value
         fp=0; %evaporative cooling signal
         Ts=Tsky(i,1); %Sky temperature (Kelvin)
         Rs=(sig*(Ts)^4); %Radiation from the sky (W/m2)
         j=1; %counter that increments by 1 at every timestep
         Q=zeros(3600,1); %Space heating at every timestep is stored here (W/m2)
         ns=zeros(3600,1); %air changes per timestep
         hum=zeros(3600,1); %Humidification energy per timestep (W/m2)
         dehum=zeros(3600,1); %Dehumidification energy per timestep (W/m2)
         trans_mat=zeros(3600,1); %Transpiration energy per timestep (W/m2)
         vent_mat=zeros(3600,1); %Ventilation energy per timestep (W/m2)
         inf_mat=zeros(3600,1); %Infiltration energy per timestep (W/m2)
         Qheatremoved=zeros(3600,1); %Heat removed by ventilation per timestep (W/m2)
         Qheatadded=zeros(3600,1); %Heat added by ventilation per timestep (W/m2)
         humw=zeros(3600,1); %Water content added during humidification per timestep (W/m2)
         Q_shts=zeros(3600,1); %Space heating after accounting for timestep (W/m2)
         Qplantheat=zeros(3600,1);  %Plant heating at every timestep (W/m2)
         nhum=zeros(3600,1); %Ventilation for humidity control per timestep 
         ventilation_powersec=zeros(3600,1); %Power consumed by ventilation per timestep
         %(W)
         watercons_evapsec=zeros(3600,1); %Water consumption in evaporative fan pad cooling
         %(m3/s)
         if(Totalnetenergy(i,1)==0)%Night time conditions
        
            if(Totalnetenergy(i-1,1)>0)%If this is true, then it indicates night time 
                %condition for the current hour and daytime conditions during the 
                %previous hour. If that is the case then it indicates that the previous 
                %hour did not have shade and the current has shade. So the shade 
                %rolling out has to be modelled. This is during winter conditions 
            
                while (ct_sec<3600) %Modelling shade rolling in
                    if(ct_sec<=shade_rolltime)   %If counter is less than the time 
                    %needed for shades to roll out 
                        if(j==1) 
                            timestep=1; %Start with timestep is one
                        else
               
                            if(x(j,3)>=TotalTmax(i,1)) %If current temperature of air 
                            %beneath shade was greater than maximum temperature set-point
                                signalcool=1; %Control that triggers ventilation for 
                                %lowering temperature activates
                            end
             
                            if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0) 
                            %If temperature of air beneath the shade is lower than the 
                            %maximum temperature set-point but higher than the mid-point temperature,
                            %then control that triggers space heating is turned off
                                signalheat=0; %Control that triggers space heating is 
                            %deactivated.
                            end
                            if(x(j,3)<TotalTmid(i,1)&&x(j,3)-TotalTmin(i,1)>=0) 
                            %If temperature of air beneath the shade is lower than the 
                            %midpoint temperature set-point but higher than the lower 
                            %temperature,then control that triggers cooling is turned 
                            %off.
                                signalcool=0; %Control that triggers ventilation for 
                                %lowering temperature deactivates
                            end
               
                            if(x(j,3)<TotalTmin(i,1)) %If temperature of air beneath the shade is lower than the 
                            %minimium temperature set-point
                                signalheat=1; %Control that triggers space heating is 
                                %activated.
                            end   
                             %During the hour where the shade rolls out or in, 
                             %we have a reduced timestep to make sure the 
                             %conditions are modelled as accurately as possible. 
                             %This reduced timestep is given by ts_daynight. 
                             %Usually this shouldn't be higher than 3-4 seconds. 
                             %Conditions under which the timestep is defined is
                             %same as that explained in the first hour loop above. 
                          if(x(j,3)<TotalTmin(i,1)||signalheat==1) 
                                timestep=ts_daynight;
                          else
                               if((x(j,2)<TotalTmin(i,1)||signalplantheat==1))
                                    timestep=ts_daynight;
                               else
                     
                                    if(x(j,3)>TotalTmax(i,1)||signalcool==1||...
                                            signalvent==1)
                                        if(x(j,3)<x(j-1,3))
                                            timestep=ts_daynight;
                                        else
                         
                                            timestep=ts_daynight;
                                        end
                                    else
                                        timestep=ts_daynight;
                                    end
                               end
                          end
                        end
                       
                        ct_sec=ct_sec+timestep;
          
                        %As shade rolls in, transmittance starts reducing
                        %linearly 
                        tnsmvty_c=1-(tnsmvty*ct_sec/shade_rolltime); %Change in 
                        %transmittance as shade rolls in
                        width_c=(width*ct_sec)/shade_rolltime; %Shade rolls out 
                        %along the width of the greenhouse (m)
                        %Rate of shade rolling out affects the portion of width covered
                        %by the shade
                        Vup=length*width_c*theohtup;%Volume of greenhouse above shade (m3)
                        V1new=V-Vup;%New volume below shade (m3)
                        %Other factors remain the same.
                        V1newft=V1new*3.28*3.28*3.28; %Volume below shade (ft3)
                        V1change=V1new-V1; %Additional volume beneath the shade 
                        %because the shades has not completely rolled out
                        %(m3)
                        Paisat_top=exp((-5800.2206/(x(j,7)+273.15))+1.3914993-....
                        (0.04860239*(x(j,7)+273.15))+(0.41764768e-4*((x(j,7)+273.15)^2))...
                        -(0.14452093e-7*((x(j,7)+273.15)^3))+(6.5459673*log((x(j,7)+...
                        273.15)))); %Saturated air vapor pressure for air above shade (Pa)
                        Paisat=exp((-5800.2206/(x(j,3)+273.15))+1.3914993-...
                        (0.04860239*(x(j,3)+273.15))+(0.41764768e-4*((x(j,3)+...
                        273.15)^2))-(0.14452093e-7*((x(j,3)+273.15)^3))+(6.5459673*...
                        log((x(j,3)+273.15)))); %Saturated air vapor pressure for air 
                        %below shade (Pa)
                        Pai_top=rhpsec_top*Paisat_top; %air vapor pressure for air 
                        %above shade (Pa)
                        Pai=rhpsec*Paisat; %air vapor pressure for air below shade (Pa)
                        wpsec_top=0.622*Pai_top/(P-Pai_top); %humidity ratio of air 
                        %above shade   
                        wpsec=0.622*Pai/(P-Pai); %humidity ratio of air below shade
                        x(j,7)=((Vup*x(j,7))+(V1change*x(j,3)))/(Vup+V1change); %Mixing 
                        %of temperature of region above shade and temperature in the 
                        %region uncovered by shade as of now but supposed to be above 
                        %shade. This is represented by the temperature of the air 
                        %below the shade (degree Celsius)
                        wpsec_top=((Vup*wpsec_top)+(V1change*wpsec))/(Vup+V1change); 
                        %Mixing of humidity of region above shade and humidity 
                        %in the region uncovered by shade as of now but supposed to be 
                        %above shade. This is represented by the humidity of the air 
                        %below the shade.
                       Paisat_top=exp((-5800.2206/(x(j,7)+273.15))+1.3914993-...
                       (0.04860239*(x(j,7)+273.15))+(0.41764768e-4*((x(j,7)+273.15)^2))...
                       -(0.14452093e-7*((x(j,7)+273.15)^3))+(6.5459673*log((x(j,7)+...
                       273.15)))); %Saturated air vapor pressure for air above shade (Pa)
                       Pai_top=(P*wpsec_top)/(0.622+wpsec_top); %air vapor pressure 
                       %for air above shade (Pa)
                       rhpsec_top=Pai_top/Paisat_top; %Relative humidity of air above 
                       %the shade
                       %Calculation to obtain the temperature of all components in the 
                       %greenhouse for the current timestep is performed using the same 
                       %controls technique mentioned in the first hour interation above
                       po=x(j,:); 
                       Told=po;
                    if(x(j,3)>=TotalTmax(i,1)) %If air temperature inside the greenhouse 
                %below the shade is greater than the maximum set-point temperature. 
                        nhum(j,1)=0;
                        signalcool=1; %Trigger for denoting the need to start ventilation 
                    %for temperature control
                        Q(j,1)=0; %Assign heating value at this instant as 0. 
                        if(Totaltemp(i,1)>TotalTmax(i,1)) %If ambient air temperature is 
                    %greater than the maximum set-point temperature
                            fp = 1; %Fraction of air flowing through the pad system

                            nmax = ((nsat*Avft)/(LAI*60*V1newft)); %Air changes per second
                            nnew = nmax; %Updated air change rate
                            vmax = nmax*V1new; %Volume change per second (m3/s)
                            v = vmax; %Volume flow rate (m3/s)
                            ns(j,1)=timestep*nmax; %Assign air change rate for every second to ns. 
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                            tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                            Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                            dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                            fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                            Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                            %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
         
                        else %If ambient air temperature is lower than the maximum
                        %set-point temperature
            
                            if(j>1)
                            if(x(j-1,3)>=TotalTmax(i,1)&&x(j-1,3)<x(j,3))
                                fp=1;
                                coolfast=1;
                            else
                                fp=0;
                            end
                        else  
                        fp = 0; %Fraction of air flowing through the pad system
                        end
                            nmax = ((nsat*Avft)/(LAI*60*V1newft)); %Air changes per second
                            nnew = nmax; %Updated air change rate 
                            vmax = nmax*V1new; %Volume change per second (m3/s)
                            v = vmax; %Volume flow rate (m3/s)
                            ns(j,1)=timestep*nmax; %Assign air change rate for every second to ns.
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,tc,...
                            transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                            Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                            dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                            fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                            Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
        
                        end
        
                        if(i>1)
                        %For second hour or greater
                         %When there is a switch in temperature from a higher 
                        %setpoint (usually during the day) to a lower stepoint (usually at night), 
                        %the air has to be initially
                        %cooled. This is the variable that keeps a note that.
                            if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0)%At the time of change in 
                                %temperature set-point
                                nh_sl(i,1)=nh_sl(i,1)+ns(j,1); %The air change per hour 
                                %needed to bring down the temperature of air inside the 
                                %greenhouse beneath the shade from within a higher and 
                                %lower temperature set-point to within a changed higher 
                                %and lower temperature set-point
                            end
                        
        
                        end
                        
        
                    end
        
                   if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0) %If air temperature inside 
                    %the greenhouse below the shade is above the mid-point temperature and 
                    %maximum temperature set-point
                        if(i>1)
                      %Similar to providing cooling to bring air temperature inside the 
                      %greenhouse below the shade from within a higher set-point 
                      %temperature value to within a changed higher set-point 
                      %temperature value, there is also a case for heating to reach 
                      %within a changed higher value of temperature set-point. 
                      %When the air exceeds the changed min. temperture set-point and 
                      %crosses the heating cut-off point for the first time, the total 
                      %heating required for this process is tabulated. 
                      %This is the heating spent for transitioning from one set-point to 
                      %the other
                            if(TotalTmin(i-1,1)~=TotalTmin(i,1))
                                trigger=1; %Marks the point till where, the heating 
                                %incurred should be considered as the transition heating.
                            end
                        
         
                        end
          
                        signalheat=0; %Trigger indicating heating requirement is not needed 
                        if(signalcool==1) %Trigger for denoting the need to start ventilation 
            %for temperature control
                            Q(j,1)=0; %Assign heating value at this instant as 0.
                            nhum(j,1)=0;
                            if(Totaltemp(i,1)<=TotalTmax(i,1)) %If air temperature inside the 
                        %greenhouse below the shade is lower than the maximum set-point 
                        %temperature.
                                if(coolfast==1)
                                    fp=1;
                                else
                                    fp =0; %Fraction of air flowing through the pad system
                                end
                                nmax = ((nsat*Avft)/(LAI*60*V1newft)); %Air changes per second 
                                vmax = nmax*V1new; %Volume change per second (m3/s)
                                v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                    TotalTmin(i,1))/2)+(pi()/2)); %Volume flow rate (m3/s)
                                nnew = v/V1new; %Updated air change rate
                                ns(j,1)=timestep*nnew; %Assign air change rate for every second to ns.
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                                kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                                Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                                Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,...
                                Told,Ac,Ec,Tgw,fp,V,V1new,Totalho(i,1),LAI,TA,v,...
                                Twb(i,1),Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,...
                                c3,c4,c5,c6,Awall,z),po,options);
                             %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
        
                            else
              
                                fp = 1; %Fraction of air flowing through the pad system    
                                nmax = ((nsat*Avft)/(LAI*60*V1newft)); %Air changes per second
                                vmax = nmax*V1new; %Volume change per second (m3/s)
                                v = (vmax/pi())*(atan((1.5*po(1,3))-...
                                    (TotalTmax(i,1)+TotalTmin(i,1))/2)+(pi()/2));%Volume flow rate (m3/s)
                                nnew = v/V1new; %Updated air change rate
                                ns(j,1)=timestep*nnew; %Assign air change rate for every second to 
                            %ns.
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                                kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,...
                                ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                                Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,...
                                Ac,Ec,Tgw,fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),...
                                Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z)...
                                ,po,options);
                            %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
          
                            end
          
                        else%If signalcool is 0 then ventilation for temperature control 
                        %is not needed 
           
                            if(signalvent==1) %signalvent==1 denotes need for dehumidification 
                                nshade=nsat/30; %If the condition is true, then ventilation is 
                            %started. nshade denotes ventilation in cfm/ft2-min
                                nhum(j,1)=((nshade*Avft)/(LAI*60*V1newft));%Since this is used for 
                                %humidity control, it is assigned to nhum.
                                nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                        %to nhum.     
                            end
         
                            if(signalvent==0)
                                nshade=0; %If humidity is within set-point, then ventilation is not 
                            %needed
                                nhum(j,1)=0; 
                            end
              
                            Q(j,1)=0; %Assign heating value at this instant as 0.
                            fp = 0;  %Fraction of air flowing through the pad system
                            nmax = ((nshade*Avft)/(LAI*60*V1newft)); %Air changes per second
                            vmax = nmax*V1new; %Volume change per second (m3/s)
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                TotalTmin(i,1))/2)+(pi()/2)); %Volume flow rate (m3/s)            
                            nnew = v/V1new; %Updated air change rate 
                            ns(j,1)=timestep*nnew; %Assign air change rate for every second to ns.
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                            tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                            Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                            Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,...
                            Tgw,fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                            Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,...
                            options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
               
                        end
       
                        if(i>1) %if the current hour is not the first hour of the 
                                %simulation
                            if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0) %At the 
                            %time of change in temperature set-point the air change per 
                            %hour needed to bring down the temperature  of air inside the 
                            %greenhouse beneath the shade from within a higher and lower 
                            %temperature set-point to within a changed higher and lower 
                            %temperature set-point is given here
                                nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                            end
        
                        end  
                            
                   end
        
                  if(x(j,3)<=TotalTmin(i,1)) %If air temperature inside the greenhouse 
                %below the shade is less than the minimum temperature set-point
                    nhum(j,1)=0; %Ventilation for humidity control = 0
                    nshade=0; %Volume changes in cfm/ft2 provided through ventilation
                    signalheat=1; %Trigger indicating need for heating
                    signalcool=0; %Cooling is switched off
                    Q(j,1)=Qlossmaxwattsarea; %The amount of heat supplied to the 
                    %greenhouse is stored in Q
                    if(i>1) %For hours other than the fisrt hour of the simulation
                        if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) %Condition for 
                        %heating to account for change in set-point temperature
                            if(TotalTmin(i,1)-x(j,3)>0) %If temperature of air inside the 
                            %greenhouse beneath  the shade is lower than the updated 
                            %minimum set-point temperature 
                                Qsl(i,1)=Qsl(i,1)+Q(j,1); %Heat added to the greenhouse 
                                %is accounted as transition heating 
                            end
                
                        end
                
                    end                         
                    fp = 0; %Fraction of air flowing through the pad system
                    nmax = ((nshade*Avft)/(LAI*60*V1newft)); %Air changes per second
                    nnew = nmax; %Updated air change rate
                    vmax = nmax*V1new; %Volume change per second (m3/s)
                    v = vmax; %Updated air change rate
                    ns(j,1)=timestep*nmax; %Assign air change rate for every second to 
                    %ns.
                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                    timestep,Cg,Aground,Fp,P_ground,kr,...
                    tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                    Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                    dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                    fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                    tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                    %Solve for the temperature of each component for the next step
                    %using parameters mentioned in the first step.
                    %hvac_fnroofshade2 - denotes the case where shades are rolled
                    %inside the greenhouse.
     
                  end
         
                  if(x(j,3)>TotalTmin(i,1)&&x(j,3)-TotalTmid(i,1)<=0) %If air temperature 
                %inside the greenhouse below the shade is between the minimum temperature setpoint
                %and mid-point temperature  
                    signalcool=0; %Trigger indicates that ventilation for temperature 
                    %control is turned off 
                    coolfast=0; 
                    if(signalheat==1) %Trigger that indicates heating requirement 
                        nhum(j,1)=0;   
                        Q(j,1)=Qlossmaxwattsarea; %The amount of heat supplied to the 
                        %greenhouse is stored in Q (W/m2)
                        if(i>1) %if the current hour is not the first hour of the 
                            %simulation
                            if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                                %Condition for heating to account for change in 
                                %set-point temperature
                                if(TotalTmid(i,1)-x(j,3)>0) %If air temperature beneath 
                                %the shade inside the greenhouse is lower than the 
                                %mid-point temperature 
                                    Qsl(i,1)=Qsl(i,1)+Q(j,1); %Heat added to the 
                                    %greenhouse is accounted as transition heating  
                         
                                end
          
                            end
          
                        end
          
                        fp = 0; %Fraction of air flowing through the pad system 
                        nmax = ((nshade*Avft)/(LAI*60*V1newft)); %Air changes per second 
                        vmax = nmax*V1new; %Volume change per second (m3/s) 
                        v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                        TotalTmin(i,1))/2)+(pi()/2)); %Volume flow rate (m3/s)  
                        nnew = v/V1new; %Updated air change rate
                        ns(j,1)=timestep*nnew; %Assign air change rate for every second 
                        %to ns.  
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                        Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                        tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                        Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                        dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                        Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
                    else %If signalheat is zero
              
                        if(signalvent==1) %signalvent==1 denotes need for 
                        %dehumidification
                            nshade=nsat/30;  %If the condition is true, then ventilation 
                            %is started.nshade denotes ventilation in cfm/ft2-min 
                            nhum(j,1)=((nshade*Avft)/(LAI*60*V1newft));%Since this is used for 
                            %humidity control, it is assigned to nhum.
                            nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                            %to nhum.      
                        end
          
                        if(signalvent==0) %Humidity is within set-point 
                            nshade=0; %Ventilation is turned off.
                            nhum(j,1)=0; 
                        end
          
                        Q(j,1)=0; %The amount of heat supplied to the greenhouse is 
                        %stored in Q (W/m2)
                        fp = 0; %Fraction of air flowing through the pad system     
                        nmax = ((nshade*Avft)/(LAI*60*V1newft)); %Air changes per second
                        vmax = nmax*V1new; %Volume change per second (m3/s)
                        v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                        TotalTmin(i,1))/2)+(pi()/2)); %Updated air change rate
                        nnew = v/V1new; %Updated air change rate
                        ns(j,1)=timestep*nnew; %Assign air change rate for every second 
                        %to ns.
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                        Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                        tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                        Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                        dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                        tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
                    end
          
                    if(i>1) %if the current hour is not the first hour of the 
                            %simulation 
                        if(TotalTmax(i-1,1)~=TotalTmax(i,1)) %At the time of change 
                            %in temperature set-point the air change per hour needed to 
                            %bring down the temperature of air inside the greenhouse 
                            %beneath the shade from within a higher and lower temperature 
                            %set-point to within a changed higher and lower temperature 
                            %set-point is given. Here, when the air temperature beneath 
                            %shade goes below the mid-point temperature the cooling for 
                            %transitioning between set-point is complete. 
                            trigger_cool=1; %Trigger_cool indicates the same
                        end
         
                    end
         
                  end
                %Plants can lose temperature due to long wave radiation.
                %In greenhouses, there is loop providing heat at the roof of 
                %the plant. This is bench heating system. Roughly a greenhouse
                %employs 50-85 W/m2 of heat to the plants. from the bench heating
                %system. Anything more than this can damage plants.  
                  if(x(j+1,2)<Tplants(i,1)) %If plant temperature is lower than minimum set-point 
              %temperature
                        signalplantheat=1; %Trigger denoting plant needs heating 
                        Qbenchheat=50;  %Heating value is assigned to Qbenchheat
                        Qplantheat(j+1,1)=timestep*Qbenchheat; %This heating value per second is 
              %assigned to Qplantheat  
                  end
      
                  if(x(j+1,2)>=Tplants(i,1)&&x(j+1,2)<=Tplants(i,1)+0.5) %If plant temperature is between 
              %the minimum set-point temperature and mid-point temperature 
                        if(signalplantheat==1) %If trigger indicates plant heating
                            Qbenchheat=50;  %Heating value is assigned to Qbenchheat (W/m2)
                            Qplantheat(j+1,1)=timestep*Qbenchheat; %This heating value per second 
                 %is assigned to Qplantheat
                        else %If trigger is 0, then heat to plants become zero.
                            Qbenchheat=0; %Heating value is assigned to Qbenchheat
                            Qplantheat(j+1,1)=Qbenchheat; %This heating value per second is 
                 %assigned to Qplantheat 
                        end
          
                  end
      
                 if(x(j+1,2)>Tplants(i,1)+0.5) %If plant temperature is greater than mid-point 
              %temperature
                    signalplantheat=0; %Trigger for plant heating becomes 0.
                    Qbenchheat=0; %Heating value is assigned to Qbenchheat
                    Qplantheat(j+1,1)=Qbenchheat; %This heating value per second is assigned 
              %to Qplantheat 
                 end
                [trans,vent,infiltration,rhsec,mhum]=humidity(efficiencyevap,Aground,...
                 achinf,timestep,dena,cpa,fp,rhpsec,Tao(i,1),rhao(i,1),ns(j,1),V1new,...
                 P,L,LAI,Netenergy(i,1),c1,c2,c3,c4,c5,c6,Told); 
              %Function file for humidity calculator-below shade
                Vtop=V-V1new; %Vtop denotes volume above the shade
                rhsectop=humidityup(Aground,achinf,timestep,dena,cpa,rhpsec_top,...
                Tao(i,1),rhao(i,1),Vtop,P,L,Told); %Function file for humidity calculator-above shades
                rhpsec=rhsec; %Assigning the new relative humidity in the region beneath the 
                %shade for air to the variable holding the previous step's relative humidity
                rhpsec_top=rhsectop; %Assigning the new relative humidity in the region above 
                %the shade for air to the variable holding the previous step's relative humidity
                trans_mat(j,1)=trans; %Notes latent heat flux lost due to transpiration 
                %per second (W/m2)
                vent_mat(j,1)=vent; %Notes latent heat flux lost due to ventilation per second (W/m2)
                inf_mat(j,1)=infiltration; %Notes latent heat flux lost due to infiltration (W/m2)
                %per second
                diff=trans-vent-infiltration; %Computes net variation in latent load (W/m2)
                if(diff>0) %If variation in latent load is positive
                    dehum(j,1)=diff; %diff becomes net dehumidification load (W/m2)
                    hum(j,1)=0; 
                else 
                    hum(j,1)=-diff; %-diff becomes humidification load (W/m2)
                    dehum(j,1)=0;
                end
                humw(j,1)=mhum; %Amount of water sprayed inside the greenhouse to the air 
          %beneath the greenhouse to keep relative humidity at the lower set-point if 
          %it goes below set-point
                if(x(j,3)>Tao(i,1)) %If temperature of air beneath the shade is greater than the outside
          %air temperature.
                    Qheatremoved(j,1)=dena*cpa*ns(j,1)*(V1new/(length*width))*...
                        (x(j,3)-Tao(i,1)); 
                    Qheatadded(j,1)=0;
                    %heat removed due to ventilation
    
                else
                    Qheatadded(j,1)=dena*cpa*ns(j,1)*(V1new/(length*width))*...
                        (x(j,3)-Tao(i,1)); 
                    Qheatremoved(j,1)=0;
                    %heat added due to ventilation
    
                end
                 %Relative humidity check with assigned value.
                if(Totalnetenergy(i,1)==0) %For night time conditions
                    if(rhsec>rhnight(2)) %If relative humidity is greater than the 
                    %maximum relative humidity set-point 
                        signalvent=1; %Trigger ventilation for humidity control
                    end
                    if(rhsec<=rhnight(1)) %If relative humidity is lower than the mid point 
                    %relative humidity set-point
                        signalvent=0; %Ventilation is turned off
                    end
                else %For daytime conditions
                    if(rhsec>rhday(2)) %If relative humidity is greater than the maximum 
                    %relative humidity set-point
                        signalvent=1; %Trigger ventilation for humidity control
                    end
                    if(rhsec<=rhday(1)) %If relative humidity is lower than the mid-point 
                    %relative humidity set-point
                        signalvent=0; %Ventilation is turned off
                    end
                end
                maxach=nsat*Avft*60/(LAI*V1newft); %Maximum air changes per hour
                maxacheachfan=maxach/2; %Maximum air changes per fan (assuming 2 fans)
                nheachfan=ns(j,1)/2; %air changes per fan
                timeperhour=nheachfan/maxacheachfan; %Time each fans runs
                ventilation_powersec(j,1)=Voltage*Current*phasefactor*RMSvalue*...
                timeperhour*2/1000; %Electric power consumed by 2 fans (kWh)
                if(fp==1)
                    [watercons_evap]=evapcooling_water(dena,V1new,ns(j,1),Aground,Totaltemp(i,1),...
                    Totalrhao(i,1),efficiencyevap); %Function that computes amount of water consumed
                %from evaporative fan pad cooling 
                    watercons_evapsec(j,1)=watercons_evap; %water consumed by evaporative cooling (kg/m2-s)
                else
                    watercons_evapsec(j,1)=0;
                end
                j=j+1;
                    else
              

%Once the shade has finished rolling, the rest of the time,
%modelling is done considering a greenhouse completely covered
%with shades.
%Other factors remain the same.

%Conditions to assign timestep remains the same
                        if(j==1) %For the first second, we start with basic timestep;
                            timestep=1; %Timestep is one      
                        else
                            if(x(j,3)>=TotalTmax(i,1)) %If current temperature of air beneath shade 
                    %was greater than maximum temperature set-point
                                signalcool=1; %Control that triggers ventilation activates
                            end
                            if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0) %If temperature 
                    %of air beneath the shade is lower than the maximum temperature
                  %set-point but higher than the mid-point temperature,
                  %then control that triggers heating is turned off.
                                signalheat=0; %Control that triggers heating is deactivated.
                            end
                            if(x(j,3)<TotalTmid(i,1)&&x(j,3)-TotalTmin(i,1)>=0) %If temperature 
                  %of air beneath the shade is lower than the midpoint temperature
                  %set-point but higher than the lower temperature
                                signalcool=0; %then control that triggers cooling for temperature 
                   %control is turned off.
                            end
                            if(x(j,3)<TotalTmin(i,1)) %If temperature of air beneath the shade is 
                   %lower than the minimium temperature set-point
                                signalheat=1; %Control that triggers space heating is activated.
                            end
                            timestep=ts_daynight;
%                             if(x(j,3)<TotalTmin(i,1)||signalheat==1)
%                                 timestep=ts_daynight;
%                             else
%                                 if((x(j,2)<TotalTmin(i,1)||signalplantheat==1))
%                                     timestep=ts_daynight;
%                                 else
%                                     if(x(j,3)>TotalTmax(i,1)||signalcool==1||signalvent==1)
%                                         if(x(j,3)<x(j-1,3))
%                                             timestep=ts_daynight;
%                                         else
%                                             timestep=ts_daynight;
%                                         end
%                                     else
%                                         timestep=ts_daynight;
%                                     end
%                                 end
%               
%                             end
             
                        end
          
                        ct_sec1=ct_sec+timestep; %Depending on the timestep, this counter is 
            %changed.
                        if(ct_sec1>3600) %If because of the timestep, the counter exceeds 3600, 
            %then the timestep is lowered until the counter gets to 3600.         
             
                            while(ct_sec1>3600)
                                timestep=timestep-1;
                                ct_sec1=ct_sec+timestep;
                             end
             
                        end
          
          
                        if(ct_sec1<=3600)
                             ct_sec=ct_sec1;
                        end
          
 
                        tnsmvty_c=tnsmvty; %Transmittance of shade when completely rolled
                        width_c=width; %Width of greenhouse covered by shade
                        V1=length*width_c*h1; %Volume of region beneath shade.
    
    %Calculation to obtain the temperature of all components in the greenhouse for the current timestep
    %is performed using the same controls technique mentioned in the
    %first hour interation above
    
                        po=x(j,:); %Assign the current value of temperature of all components 
                %to po
                        Told=po; %Assign the value in po to Told 
                        if(x(j,3)>=TotalTmax(i,1)) %If air temperature inside the greenhouse 
                %below the shade is greater than the maximum set-point temperature. 
                            nhum(j,1)=0;
                            signalcool=1; %Trigger for denoting the need to start ventilation 
                    %for temperature control
                            Q(j,1)=0; %Assign heating value at this instant as 0. 
                            if(Totaltemp(i,1)>TotalTmax(i,1)) %If ambient air temperature is 
                    %greater than the maximum set-point temperature

                                fp = 1; %Fraction of air flowing through the pad system
                                nmax = ((nsat*Avft)/(LAI*60*V1ft)); %Air changes per second
                                nnew = nmax; %Updated air change rate
                                vmax = nmax*V1; %Volume change per second (m3/s)
                                v = vmax; %Volume flow rate (m3/s)
                                ns(j,1)=timestep*nmax; %Assign air change rate for every second to ns.
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                                tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                                Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                                dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                                fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                                Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,...
                                options);
                                %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
         
                            else %If ambient air temperature is lower than the maximum
                        %set-point temperature
            
                                if(j>1)
                            if(x(j-1,3)>=TotalTmax(i,1)&&x(j-1,3)<x(j,3))
                                fp=1; %Fraction of air flowing through the pad system
                                coolfast=1;
                            else
                                fp=0; 
                            end
                        else  
                        fp = 0; 
                        end
                                nmax = ((nsat*Avft)/(LAI*60*V1ft)); %Air changes per second
                                nnew = nmax; %Updated air change rate 
                                vmax = nmax*V1; %Volume change per second (m3/s)
                                v = vmax; %Volume flow rate (m3/s)
                                ns(j,1)=timestep*nmax; %Assign air change rate for every second to ns.
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                                kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                                Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                                dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                                fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                                tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                             %Solve for the temperature of each component for the next step
                        %using parameters mentioned in the first step.
                        %hvac_fnroofshade2 - denotes the case where shades are rolled
                        %inside the greenhouse.
         
                            end
        
                            if(i>1) 
                            %For second hour or greater
                            %When there is a switch in temperature from a higher 
                            %setpoint (usually during the day) to a lower stepoint 
                            %(usually at night), 
                            %the air has to be initially
                            %cooled. This is the variable that keeps a note that.
                                if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0)
                                    %At the time of change in temperature set-point
                                    nh_sl(i,1)=nh_sl(i,1)+ns(j,1); %The air change per hour 
                            %needed to bring down the temperature of air inside the 
                            %greenhouse beneath the shade from within a higher and lower temperature 
                            %set-point to within a changed higher and lower temperature set-point
                                end
        
                            end
        
                        end
        
                        if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0) %If air temperature inside 
            %the greenhouse below the shade is above the mid-point temperature and 
            %maximum temperature set-point
                            if(i>1)
              %Similar to providing cooling to bring air temperature inside the 
              %greenhouse below the shade from within a higher set-point temperature 
              %value to within a changed higher set-point temperature value, there is 
              %also a case for heating to reach within a changed higher value of 
              %temperature set-point. When the air exceeds the changed min. temperture 
              %set-point and crosses the heating cut-off point for the first time, 
              %the total heating required for this process is tabulated. This is the 
              %heating spent for transitioning from one set-point to the other
              
                                if(TotalTmin(i-1,1)~=TotalTmin(i,1))
                                    trigger=1; %Marks the point till where, the heating incurred 
                    %should be considered as the transition heating.
                                end
                            end 
                            signalheat=0; %Trigger indicating heating requirement is not needed 
                            if(signalcool==1) %Trigger for denoting the need to start ventilation 
            %for temperature control
                                Q(j,1)=0; %Assign heating value at this instant as 0.
                                nhum(j,1)=0;
                                if(Totaltemp(i,1)<=TotalTmax(i,1)) %If air temperature inside the 
                        %greenhouse below the shade is lower than the maximum set-point 
                        %temperature.
                                    if(coolfast==1)
                                        fp=1;
                                    else
                                        fp =0; %Fraction of air flowing through the pad system
                                    end
                                    nmax = ((nsat*Avft)/(LAI*60*V1ft)); %Air changes per second
                                    vmax = nmax*V1; %Volume change per second (m3/s)
                                    v = (vmax/pi())*(atan((1.5*po(1,3))-...
                                        (TotalTmax(i,1)+TotalTmin(i,1))/2)+(pi()/2)); 
                                    %Volume change per second (m3/s)
                                    nnew = v/V1; %Updated air change rate
                                    ns(j,1)=timestep*nnew; %Assign air change rate for every second to ns.
                                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                        Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                                    tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                                    Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                                    dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                                    fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                                    Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),...
                                    po,options);
                                %Solve for the temperature of each component for the next step
                                %using parameters mentioned in the first step.
                                %hvac_fnroofshade2 - denotes the case where shades are rolled
                                %inside the greenhouse.
                                else
              
                                    fp = 1; %Fraction of air flowing through the pad system 
                                    nmax = ((nsat*Avft)/(LAI*60*V1ft)); %Air changes per second
                                    vmax = nmax*V1; %Maximum flow rate (m3/s) 
                                    v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                    TotalTmin(i,1))/2)+(pi()/2)); %Volume flow rate (m3/s)
                                    nnew = v/V1; %Updated air change rate
                                    ns(j,1)=timestep*nnew; %Assign air change rate for every second to 
                                    %ns. 
                                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                    Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,...
                                    P_ground,kr,tc,transmittance_roof,...
                                    transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                                    Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                                    Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,...
                                    Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,...
                                    Twb(i,1),Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,...
                                    c3,c4,c5,c6,Awall,z),po,options);
                                %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
                                end
          
                            else %If signalcool is 0 then ventilation for temperature control 
                        %is not needed 
                                
           
                                   if(signalvent==1) %signalvent==1 denotes need for dehumidification
                                        nshade=nsat/30; %If the condition is true, then ventilation is 
                            %started. nshade denotes ventilation in cfm/ft2-min 
                                        nhum(j,1)=((nshade*Avft)/(LAI*60*V1ft));%Since this is used for 
                                        %humidity control, it is assigned to nhum.
                                        nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                                        %to nhum.      
                                   end
         
                                   if(signalvent==0) 
                                      nshade=0; %If humidity is within set-point, then ventilation is not 
                            %needed
                                      nhum(j,1)=0;
                                   end
                                   Q(j,1)=0; %Assign heating value at this instant as 0.
                                   fp = 0;  %Fraction of air flowing through the pad system   
                                   nmax = ((nshade*Avft)/(LAI*60*V1ft));%Air changes per second
                                   vmax = nmax*V1; %Maximum volume flow rate (m3/s)
                                   v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                   TotalTmin(i,1))/2)+(pi()/2)); %Volume flow rate (m3/s)
                                   nnew = v/V1; %Updated air change rate
                                   ns(j,1)=timestep*nnew; %Assign air change rate for every second to ns.
                                   x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                   Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,...
                                   P_ground,kr,tc,transmittance_roof,...
                                   transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                                   Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                                   Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,...
                                   Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,...
                                   Twb(i,1),Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,...
                                   c3,c4,c5,c6,Awall,z),po,options);
                               %Solve for the temperature of each component for the next step
                               %using parameters mentioned in the first step.
                               %hvac_fnroofshade2 - denotes the case where shades are rolled
                               %inside the greenhouse.
  
                            end
                            
       
                            if(i>1) %if the current hour is not the first hour of the 
                            %simulation
                                if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0) 
                                %At the time of change in temperature set-point the air change 
                                %per hour needed to bring down the temperature of air inside the 
                                %greenhouse beneath the shade from within a higher and lower 
                                %temperature set-point to within a changed higher and lower 
                                %temperature set-point is given here    
                                    nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                                end
                            end
        
                        end
        
                        if(x(j,3)<=TotalTmin(i,1)) %If air temperature inside the greenhouse 
                %below the shade is less than the minimum temperature set-point  
                            nhum(j,1)=0; %Ventilation for humidity control = 0
                            nshade=0; %Volume changes in cfm/ft2 provided through ventilation
                            signalheat=1; %Trigger indicating need for heating
                            signalcool=0; %Cooling is switched off
                            Q(j,1)=Qlossmaxwattsarea; %The amount of heat supplied to the 
                    %greenhouse is stored in Q 
                            if(i>1) %For hours other than the fisrt hour of the simulation
                                if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) %Condition for 
                        %heating to account for change in set-point temperature
                                    if(TotalTmin(i,1)-x(j,3)>0) %If temperature of air inside the 
                            %greenhouse beneath  the shade is lower than the updated 
                            %minimum set-point temperature 
                                        Qsl(i,1)=Qsl(i,1)+Q(j,1); %Heat added to the greenhouse 
                                %is accounted as transition heating 
                                    end
                
                                end
                
                            end
                
                         
                            fp = 0; %Fraction of air flowing through the pad system 
                            nmax = ((nshade*Avft)/(LAI*60*V1ft)); %Air changes per second
                            nnew = nmax; %Updated air change rate
                            vmax = nmax*V1; %Volume change per second (m3/s)
                            v = vmax; %Updated air change rate
                            ns(j,1)=timestep*nmax; %Assign air change rate for every second to 
                            %ns.
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                            kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                            Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                            Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,...
                            Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                            Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                            %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
   
                        end
         
                        if(x(j,3)>TotalTmin(i,1)&&x(j,3)-TotalTmid(i,1)<=0) %If air temperature 
                        %inside the greenhouse below the shade is between the minimum temperature setpoint
                        %and mid-point temperature
             
                            signalcool=0; %Trigger indicates that ventilation for temperature 
                            %control is turned off  
                            coolfast=0; 
                            if(signalheat==1) %Trigger that indicates heating requirement
                                nhum(j,1)=0;  
                                Q(j,1)=Qlossmaxwattsarea; %The amount of heat supplied to the 
                        %greenhouse is stored in Q
                                if(i>1) %if the current hour is not the first hour of the 
                            %simulation
                                    if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                                        %Condition for heating to account for change in 
                                %set-point temperature
                                        if(TotalTmid(i,1)-x(j,3)>0) %If air temperature beneath 
                                %the shade inside the greenhouse is lower than the 
                                %mid-point temperature
                                            Qsl(i,1)=Qsl(i,1)+Q(j,1); %Heat added to the 
                                    %greenhouse is accounted as transition heating
                         
                                        end
          
                                    end
          
                                end
          
                                fp = 0; %Fraction of air flowing through the pad system
                                nmax = ((nshade*Avft)/(LAI*60*V1ft)); %Air changes per second 
                                vmax = nmax*V1; %Updated air change rate
                                v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                TotalTmin(i,1))/2)+(pi()/2)); %Volume change per second (m3/s)
                                nnew = v/V1;%Updated air change rate
                                ns(j,1)=timestep*nnew; %Assign air change rate for every second to 
                                %ns.
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                                timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                                transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                                Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                                dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                                fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                                Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),...
                                po,options);
                            %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
 
                            else
              
                                if(signalvent==1) %signalvent==1 denotes need for dehumidification
                                    nshade=nsat/30; %If the condition is true, then ventilation is 
                            %started. nshade denotes ventilation in cfm/ft2-min
                                    nhum(j,1)=((nshade*Avft)/(LAI*60*V1ft));%Since this is used for 
                                    %humidity control, it is assigned to nhum.
                                    nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                                    %to nhum.      
                                end
          
                                if(signalvent==0) 
                                     nshade=0; %If humidity is within set-point, then ventilation is not 
                            %needed
                                     nhum(j,1)=0;
                                end
                                Q(j,1)=0; %Assign heating value at this instant as 0.
                                fp = 0; %Fraction of air flowing through the pad system   
                                nmax = ((nshade*Avft)/(LAI*60*V1ft)); %Maximum Air changes per second
                                vmax = nmax*V1; %Volume change per second (m3/s)
                                v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                TotalTmin(i,1))/2)+(pi()/2));%Volume flow rate (m3/s)    
                                nnew = v/V1; %Updated air change rate
                                ns(j,1)=timestep*nnew; %Assign air change rate for every second to ns. 
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                                kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                                Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                                Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,...
                                Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),...
                                Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,...
                                Awall,z),po,options);
                            %Solve for the temperature of each component for the next step
                            %using parameters mentioned in the first step.
                            %hvac_fnroofshade2 - denotes the case where shades are rolled
                            %inside the greenhouse.
                            end
          
                            if(i>1) %if the current hour is not the first hour of the 
                            %simulation
                                if(TotalTmax(i-1,1)~=TotalTmax(i,1)) %At the time of change 
                            %in temperature set-point the air change per hour needed to 
                            %bring down the temperature of air inside the greenhouse 
                            %beneath the shade from within a higher and lower temperature 
                            %set-point to within a changed higher and lower temperature 
                            %set-point is given. Here, when the air temperature beneath 
                            %shade goes below the mid-point temperature the cooling for 
                            %transitioning between set-point is complete. 
                                    trigger_cool=1; %Trigger_cool indicates the same
                                end
         
                            end
          
                        end
         
               %Plants can lose temperature due to long wave radiation.
               %In greenhouses, there is loop providing heat at the roof of 
               %the plant. This is bench heating system. Roughly a greenhouse
               %employs 50-85 W/m2 of heat to the plants. from the bench heating
               %system. Anything more than this can damage plants.
                        if(x(j+1,2)<Tplants(i,1)) %If plant temperature is lower than minimum set-point 
                        %temperature 
                            signalplantheat=1; %Trigger denoting plant needs heating
                            Qbenchheat=50; %Heating value is assigned to Qbenchheat (W/m2)
                            Qplantheat(j+1,1)=timestep*Qbenchheat; %This heating value per second is 
                            %assigned to Qplantheat
                        end
      
                        if(x(j+1,2)>=Tplants(i,1)&&x(j+1,2)<=Tplants(i,1)+0.5) %If plant temperature is between 
              %the minimum set-point temperature and mid-point temperature
                            if(signalplantheat==1) %If trigger indicates plant heating
                                Qbenchheat=50; %Heating value is assigned to Qbenchheat
                                Qplantheat(j+1,1)=timestep*Qbenchheat; %This heating value per second is 
                            %assigned to Qplantheat
                            else %If trigger is 0, then heat to plants become zero.             
                                Qbenchheat=0; %Heating value is assigned to Qbenchheat
                                Qplantheat(j+1,1)=Qbenchheat; %This heating value per second is 
                 %assigned to Qplantheat
                            end
          
                        end
      
                        if(x(j+1,2)>Tplants(i,1)+0.5) %If plant temperature is greater than mid-point 
              %temperature
                            signalplantheat=0; %Trigger for plant heating becomes 0.
                            Qbenchheat=0; %Heating value is assigned to Qbenchheat
                            Qplantheat(j+1,1)=Qbenchheat; %This heating value per second is assigned 
              %to Qplantheat
                        end
      
                        [trans,vent,infiltration,rhsec,mhum]=humidity(efficiencyevap,...
                         Aground,achinf,timestep,dena,cpa,fp,rhpsec,Tao(i,1),...
                         rhao(i,1),ns(j,1),V,P,L,LAI,Netenergy(i,1),c1,c2,c3,c4,c5,c6,...
                         Told);
                      %Function file for humidity calculator-below shade
                         rhsectop=rhsec; %Assigning the new relative humidity in the region above 
          %the shade for air to the variable holding the previous step's relative humidity
                         rhpsec=rhsec; %Assigning the new relative humidity in the region beneath the 
          %shade for air to the variable holding the previous step's relative humidity
                         rhpsec_top=rhsectop; 
                         trans_mat(j,1)=trans; %Notes latent heat flux lost due to transpiration 
          %per second (W/m2)
                         vent_mat(j,1)=vent; %Notes latent heat flux lost due to ventilation per second (W/m2)
                         inf_mat(j,1)=infiltration; %Notes latent heat flux lost due to infiltration (W/m2)
          %per second
                         diff=trans-vent-infiltration; %Computes net variation in latent load (W/m2)
                         if(diff>0) %If variation in latent load is positive
                            dehum(j,1)=diff; %diff becomes net dehumidification load (W/m2)
                            hum(j,1)=0;
                         else
    
                            hum(j,1)=-diff; %-diff becomes humidification load (W/m2)
                            dehum(j,1)=0;
                         end

                         humw(j,1)=mhum; %Amount of water sprayed inside the greenhouse to the air 
          %beneath the greenhouse to keep relative humidity at the lower set-point if 
          %it goes below set-point
                        if(x(j,3)>Tao(i,1)) %If temperature of air beneath the shade is greater than the outside
          %air temperature.
                            Qheatremoved(j,1)=dena*cpa*ns(j,1)*(V1/(length*width))*...
                            (x(j,3)-Tao(i,1));
                            Qheatadded(j,1)=0;
                            %heat removed due to ventilation

                        else
                            Qheatadded(j,1)=dena*cpa*ns(j,1)*(V1/(length*width))*...
                            (x(j,3)-Tao(i,1));
                            Qheatremoved(j,1)=0;
                            %heat added due to ventilation

                        end
                        %Relative humidity check with assigned value.

                        if(Totalnetenergy(i,1)==0) %For night time conditions
                            if(rhsec>rhnight(2)) %If relative humidity is greater than the 
                    %maximum relative humidity set-point
                                signalvent=1; %Trigger ventilation for humidity control 
                            end
                            if(rhsec<=rhnight(1)) %If relative humidity is lower than the mid point 
                    %relative humidity set-point
                                signalvent=0; %Ventilation is turned off
                            end

                        else %For daytime conditions
                            if(rhsec>rhday(2)) %If relative humidity is greater than the maximum 
                    %relative humidity set-point
                                signalvent=1; %Trigger ventilation for humidity control
                            end

                            if(rhsec<=rhday(1)) %If relative humidity is lower than the mid-point 
                    %relative humidity set-point
                                signalvent=0; %Ventilation is turned off
                            end

                        end

                        Q_shts(j,1)=timestep*Q(j,1); %Space heating after accounting for timestep (W/m2)
                        maxach=nsat*Avft*60/(LAI*V1ft); %Maximum air changes per hour
                        maxacheachfan=maxach/2; %Maximum air changes per fan (assuming 2 fans)
                        nheachfan=ns(j,1)/2; %air changes per fan
                        timeperhour=nheachfan/maxacheachfan; %Time each fans runs
                        ventilation_powersec(j,1)=Voltage*Current*phasefactor*RMSvalue*...
                        timeperhour*2/1000; %Electric power consumed by 2 fans (kWh) 
                        if(fp==1)
                            [watercons_evap]=evapcooling_water(dena,V1,ns(j,1),Aground,Totaltemp(i,1),...
                            Totalrhao(i,1),efficiencyevap); %Function that computes amount of water consumed
                %from evaporative fan pad cooling (kg/m2-s)
                            watercons_evapsec(j,1)=watercons_evap;
                        else
                            watercons_evapsec(j,1)=0;
                        end
                        j=j+1;
                    end

                    humw_matrix(i,1)=sum(humw(1:j-1,1)); %Total water per unit ground area added 
        %to the greenhouse in a hour (kg/m2-hour)
                    rhinhour(i,1)=rhsec; %Assign relative humidity of air beneath shade inside 
        %the greenhouse at the end of an hour to rhinhour
                    rhinhourtop(i,1)=rhsectop; %Assign relative humidity of air above shade inside 
        %the greenhouse at the end of an hour to rhinhourtop
                    trans_year(i,1)=sum(trans_mat(1:j-1,1)); %Assign hourly heat flux loss due to 
        %transpiration (W/m2)
                    trans_year_mass(i,1)=trans_year(i,1)/L; %Assign hourly water addtion per unit 
        %area to greenhouse air beneath shade due to transpiration (kg/m2)
                    vent_year(i,1)=sum(vent_mat(1:j-1,1)); %Hourly latent flux addition or removal 
        %in the region beneath the shade due to ventilation (W/m2)
                    inf_year(i,1)=sum(inf_mat(1:j-1,1)); %Hourly latent flux addition or removal in 
        %the region beneath the shade due to infiltration (W/m2)
                    Qheatremoved_mat(i,1)=sum(Qheatremoved(1:j-1,1)); %Hourly heat flux removed due 
        %to ventilation (W/m2)
                    Qheatadded_mat(i,1)=sum(Qheatadded(1:j-1,1)); 
                    %Total humidification load per unit ground area (W/m2)
                    hum_mat(i,1)=sum(hum(1:j-1,1)); %Total dehumidification load per unit ground 
        %area (W/m2)
                    dehum_mat(i,1)=sum(dehum(1:j-1,1)); %Total heating per unit area supplied to air 
        %beneath the shade per hour (W/m2) 
                    Qsumheat(i,1)=sum(Q_shts(1:j-1,1)); %Total heating per unit area 
        %supplied to plants per hour (W/m2)
                    Qsumplantheat(i,1)=sum(Qplantheat(1:j-1,1)); %Hourly air changes due to ventilation 
                    ventilation_powerhour(i,1)=sum(ventilation_powersec(1:j-1,1)); 
                    %Temperature of all components of the greenhouse at the end of an hour (degree celsius)
                    watercons_evaphour(i,1)=sum(watercons_evapsec(1:j-1,1));
                    nh(i,1)=sum(ns(1:j-1,1)); 
                    th(i,:)=x(j,:); 
                    nhum_m(i,1)=sum(nhum(1:j-1,1)); %air changes in an hour for 
        %humidity control
                end
         
            end
        
            %If previous hour is similar to current hour and both of it
            %have shades, then we just consider a case similar to the first
            %hour
            if(Totalnetenergy(i-1,1)==0) %If previous hour is also nighttime, 
            %then the shades are already rolled out       
    %Conditions to assign timestep remain the same
                while(ct_sec<3600) 
        %Conditions to assign timestep remains the same
                    if(j==1)
                        timestep=1;
                    else 
                        if(x(j,3)>=TotalTmax(i,1))
                            signalcool=1;
                        end
             
                        if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0)
                            signalheat=0;
                        end
                        if(x(j,3)<TotalTmid(i,1)&&x(j,3)-TotalTmin(i,1)>=0)
                            signalcool=0;
                        end
                        if(x(j,3)<TotalTmin(i,1))
                            signalheat=1;
                        end
                        if(signalheat==1&&signalplantheat==1)
                            timestep=ts_reduced;
                        else
                            if(signalheat==0&&signalplantheat==1)
                                timestep=timestep+2;
                            else 
                                if(signalheat==0&&signalplantheat==0) 
                                    if(signalvent==1)
                                        if(x(j,3)>x(j-1,3))
                                            timestep=timestep+2;
                                        else
                                            if(x(j-1,3)-x(j,3)<0.1)
                                               timestep=timestep+2;
                                            else
                                               timestep=ts_reduced;
                                               
                                            end
                             
                                        end
                         
                                    else
                         
                                        if(signalcool==1)
                                            if(x(j,3)>x(j-1,3))
                                                if(x(j-1,3)<=TotalTmax(i,1))
                                                    timestep=ts_reduced;
                                                else
                                                    timestep=timestep+2;
                                                end
                                            else
                             
                                                if(x(j-1,3)-x(j,3)<0.1)
                                                    timestep=timestep+2;
                                                else
                                                    timestep=ts_reduced;
                                                end
                                            end
                                        else
                                            timestep=timestep+2;  
                                        end
                         
                                    end 
  
                                else
                         
                                    if(signalheat==1&&signalplantheat==0)
                                        timestep=ts_reduced;
                                    end
                       
                                end
                     
                            end
                 
                        end      
                    end
            
                    ct_sec1=ct_sec+timestep;
                        if(ct_sec1>3600)
             
                            while(ct_sec1>3600)
                               timestep=timestep-1;
                               ct_sec1=ct_sec+timestep;
                            end
             
                        end
          
          
                        if(ct_sec1<=3600)
                            ct_sec=ct_sec1;
                        end
          
                        %Calculation to obtain the temperature of all components in 
                        %the greenhouse for the current timestep is performed using 
                        %the same controls technique mentioned in the first hour 
                        %interation above 
                         po=x(j,:); 
                         Told=po; 
                        if(x(j,3)>=TotalTmax(i,1)) 
                            nhum(j,1)=0;
                            signalcool=1; 
                            Q(j,1)=0; 
                            if(Totaltemp(i,1)>TotalTmax(i,1)) %If ambient air temperature is 
                            %greater than the maximum set-point temperature

                                fp = 1; 
                                nmax = ((nsat*Avft)/(LAI*60*V1ft)); 
                                nnew = nmax; 
                                vmax = nmax*V1; 
                                v = vmax; 
                                ns(j,1)=timestep*nmax; 
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,...
                                P_ground,kr,tc,transmittance_roof,transmittance_wall,...
                                Rs,ts1,ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,...
                                Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,...
                                tg,Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,...
                                Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                                tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
         
                            else
            
                                if(j>1)
                            if(x(j-1,3)>=TotalTmax(i,1)&&x(j-1,3)<x(j,3))
                                fp=1;
                                coolfast=1;
                            else
                                fp=0;
                            end
                        else  
                        fp = 0; %Fraction of air flowing through the pad system
                        end
                                nmax = ((nsat*Avft)/(LAI*60*V1ft)); 
                                nnew = nmax; 
                                vmax = nmax*V1; 
                                v = vmax; 
                                ns(j,1)=timestep*nmax; 
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                                kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,...
                                ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,...
                                cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,...
                                kg,tg,Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,...
                                Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                                tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
       
                            end
        
                            if(i>1) 
                                if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0) 
                                    nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                                end
        
                            end
        
                        end
        
                        if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0) 
                            if(i>1) 
              
                                if(TotalTmin(i-1,1)~=TotalTmin(i,1))
                                    trigger=1; 
                                end
         
                            end
          
                            signalheat=0; 
                            if(signalcool==1) 
                                Q(j,1)=0; 
                                nhum(j,1)=0;
                                if(Totaltemp(i,1)<=TotalTmax(i,1)) 
                                    if(coolfast==1)
                                        fp=1;
                                    else
                                        fp =0; %Fraction of air flowing through the pad system
                                    end
                                    
                                    nmax = ((nsat*Avft)/(LAI*60*V1ft));
                                    vmax = nmax*V1; 
                                    v = (vmax/pi())*(atan((1.5*po(1,3))-...
                                    (TotalTmax(i,1)+TotalTmin(i,1))/2)+(pi()/2));
                                    nnew = v/V1; 
                                    ns(j,1)=timestep*nnew; 
                                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                    Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,...
                                    P_ground,kr,tc,transmittance_roof,...
                                    transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                                    Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                                    Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,...
                                    kg,tg,Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),...
                                    LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                                    tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
  
                                else
              
                                    fp = 1;     
                                    nmax = ((nsat*Avft)/(LAI*60*V1ft)); 
                                    vmax = nmax*V1; 
                                    v = (vmax/pi())*(atan((1.5*po(1,3))-...
                                    (TotalTmax(i,1)+TotalTmin(i,1))/2)+(pi()/2));
                                    nnew = v/V1; 
                                    ns(j,1)=timestep*nnew; 
                                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                    Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,...
                                    P_ground,kr,tc,transmittance_roof,transmittance_wall,...
                                    Rs,ts1,ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),...
                                    Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,...
                                    kg,tg,Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                                    tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
      
                                end
          
                            else
           
                            if(signalvent==1) 
                                nshade=nsat/30; 
                                nhum(j,1)=((nshade*Avft)/(LAI*60*V1ft));%Since this is used for 
                                %humidity control, it is assigned to nhum.
                                nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                                %to nhum.     
                            end
                            if(signalvent==0) 
                                nshade=0; 
                                nhum(j,1)=0;
                            end
              
                            Q(j,1)=0; 
                            fp = 0;  
                            nmax = ((nshade*Avft)/(LAI*60*V1ft)); 
                            vmax = nmax*V1; 
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));
                            nnew = v/V1; 
                            ns(j,1)=timestep*nnew; 
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                            kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                            Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                            Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,...
                            Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                            Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
   
                            end
       
                            if(i>1) 
                                if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0)
                                    nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                                end
                            end
                        end
        
                       if(x(j,3)<=TotalTmin(i,1)) 
                          nhum(j,1)=0;
                          nshade=0; 
                          signalheat=1; 
                          signalcool=0; 
                          Q(j,1)=Qlossmaxwattsarea; 
                         if(i>1) 
                            if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                                if(TotalTmin(i,1)-x(j,3)>0) 
                                    Qsl(i,1)=Qsl(i,1)+Q(j,1);
                                end
                            end
                         end
                         
                         fp = 0; 
                         nmax = ((nshade*Avft)/(LAI*60*V1ft)); 
                         nnew = nmax; 
                         vmax = nmax*V1; 
                         v = vmax; 
                        ns(j,1)=timestep*nmax;  
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                        tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                        Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                        dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,V1,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                        tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);

                       end
         
                       if(x(j,3)>TotalTmin(i,1)&&x(j,3)-TotalTmid(i,1)<=0)     
                            signalcool=0; 
                            coolfast=0;
                            if(signalheat==1) 
                                nhum(j,1)=0;  
                                Q(j,1)=Qlossmaxwattsarea; 
                                if(i>1) 
                                    if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                                        if(TotalTmid(i,1)-x(j,3)>0) 
                                            Qsl(i,1)=Qsl(i,1)+Q(j,1); 
                         
                                        end
          
                                    end
          
                                end
          
                                fp = 0; 
                                nmax = ((nshade*Avft)/(LAI*60*V1ft));
                                vmax = nmax*V1; 
                                v = (vmax/pi())*(atan((1.5*po(1,3))-...
                                    (TotalTmax(i,1)+TotalTmin(i,1))/2)+(pi()/2));
                                nnew = v/V1; 
                                ns(j,1)=timestep*nnew;  
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                                tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                                Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                                Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,...
                                Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,...
                                Twb(i,1),Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,...
                                c3,c4,c5,c6,Awall,z),po,options);
                            else
              
                                if(signalvent==1)
                                    nshade=nsat/30; 
                                    nhum(j,1)=((nshade*Avft)/(LAI*60*V1ft));%Since this is used for 
                                    %humidity control, it is assigned to nhum.
                                    nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                                    %to nhum.      
                                end
          
                                if(signalvent==0) 
                                    nshade=0; 
                                    nhum(j,1)=0;
                                end
                                Q(j,1)=0; 
                                fp = 0;    
                                nmax = ((nshade*Avft)/(LAI*60*V1ft)); 
                                vmax = nmax*V1;
                                v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                TotalTmin(i,1))/2)+(pi()/2));
                                nnew = v/V1; 
                                ns(j,1)=timestep*nnew; 
                                
                                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,...
                                P_ground,kr,tc,transmittance_roof,transmittance_wall,...
                                Rs,ts1,ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,...
                                Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,...
                                tg,Told,Ac,Ec,Tgw,fp,V,V1,Totalho(i,1),LAI,TA,v,...
                                Twb(i,1),Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,c3,...
                                c4,c5,c6,Awall,z),po,options);
          
                            end
          
                            if(i>1) 
                                if(TotalTmax(i-1,1)~=TotalTmax(i,1)) 
                                    trigger_cool=1;
                                end
                            end
          
                       end
         
        
                       if(x(j+1,2)<Tplants(i,1)) 
                            signalplantheat=1; 
                            Qbenchheat=50; 
                            Qplantheat(j+1,1)=timestep*Qbenchheat; 
                       end
                       if(x(j+1,2)>=Tplants(i,1)&&x(j+1,2)<=Tplants(i,1)+0.5) 
                            signalcool=0; 
                            if(signalplantheat==1) 
                                Qbenchheat=50; 
                               Qplantheat(j+1,1)=timestep*Qbenchheat; 
                            else
              
                                Qbenchheat=0; 
                                Qplantheat(j+1,1)=Qbenchheat; 
                            end
          
                       end
      
                      if(x(j+1,2)>Tplants(i,1)+0.5) 
                        signalplantheat=0; 
                        Qbenchheat=0; 
                        Qplantheat(j+1,1)=Qbenchheat; 
                      end    
                     [trans,vent,infiltration,rhsec,mhum]=humidity(efficiencyevap,...
                      Aground,achinf,timestep,dena,cpa,fp,rhpsec,Tao(i,1),...
                    rhao(i,1),ns(j,1),V1,P,L,LAI,Netenergy(i,1),c1,c2,c3,c4,c5,c6,Told); 
                    Vtop=V-V1; 
                    rhsectop=humidityup(Aground,achinf,timestep,dena,cpa,rhpsec_top,...
                    Tao(i,1),rhao(i,1),Vtop,P,L,Told); 
                    rhpsec=rhsec; 
                    rhpsec_top=rhsectop; 
                    trans_mat(j,1)=trans; 
                    vent_mat(j,1)=vent;
                    inf_mat(j,1)=infiltration; 
                    diff=trans-vent-infiltration; 
                    if(diff>0)
                        dehum(j,1)=diff; 
                        hum(j,1)=0;
                    else
                        hum(j,1)=-diff; 
                        dehum(j,1)=0;
                    end
                    humw(j,1)=mhum; 
                    if(x(j,3)>Tao(i,1))  
                        Qheatremoved(j,1)=dena*cpa*ns(j,1)*(V1/(length*width))*...
                            (x(j,3)-Tao(i,1));
                        Qheatadded(j,1)=0;

                    else
                        Qheatadded(j,1)=dena*cpa*ns(j,1)*(V1/(length*width))*...
                            (x(j,3)-Tao(i,1));
                        Qheatremoved(j,1)=0;

                    end

                    if(Totalnetenergy(i,1)==0) 
                    if(rhsec>rhnight(2)) 
                        signalvent=1; 
                    end
                    if(rhsec<=rhnight(1)) 
                        signalvent=0; 
                    end
                    else 
                    if(rhsec>rhday(2)) 
                        signalvent=1; 
                    end
                    if(rhsec<=rhday(1)) 
                        signalvent=0; 
                    end
                    end
                    Q_shts(j,1)=timestep*Q(j,1);
                    maxach=nsat*Avft*60/(LAI*V1ft);
                    maxacheachfan=maxach/2;
                    nheachfan=ns(j,1)/2;
                    timeperhour=nheachfan/maxacheachfan;
                    ventilation_powersec(j,1)=Voltage*Current*phasefactor*RMSvalue*...
                    timeperhour*2/1000;
                    if(fp==1)
                        [watercons_evap]=evapcooling_water(dena,V1,ns(j,1),Aground,Totaltemp(i,1),...
                        Totalrhao(i,1),efficiencyevap);
                        watercons_evapsec(j,1)=watercons_evap;
                    else
                        watercons_evapsec(j,1)=0;
                    end
                    j=j+1;

                end

                humw_matrix(i,1)=sum(humw(1:j-1,1));
                rhinhour(i,1)=rhpsec; 
                rhinhourtop(i,1)=rhpsec_top; 
                trans_year(i,1)=sum(trans_mat(1:j-1,1));
                trans_year_mass(i,1)=trans_year(i,1)/L; 
                vent_year(i,1)=sum(vent_mat(1:j-1,1)); 
                inf_year(i,1)=sum(inf_mat(1:j-1,1)); 
                Qheatremoved_mat(i,1)=sum(Qheatremoved(1:j-1,1));
                Qheatadded_mat(i,1)=sum(Qheatadded(1:j-1,1)); 
                hum_mat(i,1)=sum(hum(1:j-1,1)); 
                dehum_mat(i,1)=sum(dehum(1:j-1,1)); 
                Qsumheat(i,1)=sum(Q_shts(1:j-1,1)); 
                Qsumplantheat(i,1)=sum(Qplantheat(1:j-1,1));
                ventilation_powerhour(i,1)=sum(ventilation_powersec(1:j-1,1));
                watercons_evaphour(i,1)=sum(watercons_evapsec(1:j-1,1));
                nh(i,1)=sum(ns(1:j-1,1));
                th(i,:)=x(j,:); 
                nhum_m(i,1)=sum(nhum(1:j-1,1)); 
            end

         end


        if(Totalnetenergy(i,1)>0) %Daytime conditions
        %If the previous hour did not have a net solar radiation,
        %Then the shades would have been active. This shade has to be 
        %rolled off. When it is being rolled off, it is ensured 
        %that the temperature of air beneath the shades doesn't drop
        %below its set-point temperature. If it does, the shades stop
        %rolling back until the temperature is back above the set-point
            if(Totalnetenergy(i-1,1)==0)
                inc=1;%Shade rolling back start
                while(ct_sec<3600)
                %Conditions to assign timestep remains the same
                if(j==1)
                    timestep=1;
                else
                    if(x(j,3)>=TotalTmax(i,1))
                        signalcool=1;
                    end
                    if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0)
                        signalheat=0;
                    end
                    if(x(j,3)<TotalTmid(i,1)&&x(j,3)-TotalTmin(i,1)>=0)
                        signalcool=0;
                    end
                    if(x(j,3)<TotalTmin(i,1))
                        signalheat=1;
                    end

                    if(x(j,3)<TotalTmin(i,1)||signalheat==1)
                        timestep=ts_daynight;
                    else
                 
                        if(x(j,3)>TotalTmax(i,1)||signalcool==1||signalvent==1)
                            if(x(j,3)<x(j-1,3))
                                timestep=ts_daynight;
                            else
                                timestep=ts_daynight;
                            end
                        else
                            timestep=ts_daynight;
                        end
              
                    end
                end
          
                ct_sec1=ct_sec+timestep;
                if(ct_sec1>3600)
             
                    while(ct_sec1>3600)
                        timestep=timestep-1;
                        ct_sec1=ct_sec+timestep;
                    end
             
                end
          
                if(ct_sec1<=3600)
                    ct_sec=ct_sec1;
                end
                if(inc<=(shade_rolltime))
                    if(j==1||x(j,3)>=TotalTmin(i,1))
                        tnsmvty_c=tnsmvty+(tnsmvty*inc/shade_rolltime);%Shade rolls back
                        width_c=width-(width*inc)/shade_rolltime; %Width of greenhouse 
                        %covered with shade
                        Vup=length*width_c*theohtup; %Volume of greenhouse above shade 
                        %(m3)
                        inc=inc+timestep; %Counter that is incremented everytime the 
                        %shade is rolled back a step
                        V1new=V-Vup; %Updated value of volume uncovered by shade
                        V1newft=V1new*3.28*3.28*3.28; %Updated value of volume 
                        %uncovered by shade (ft3)
                        V1change=V1new-V1; %Increment in volume of shades uncovered by
                        %shades (m3)
                        Paisat_top=exp((-5800.2206/(x(j,7)+273.15))+1.3914993-...
                        (0.04860239*(x(j,7)+273.15))+(0.41764768e-4*...
                        ((x(j,7)+273.15)^2))-(0.14452093e-7*((x(j,7)+273.15)^3))+...
                        (6.5459673*log((x(j,7)+273.15)))); %Saturated air vapor pressure 
                        %for air above shade (Pa)
                        Paisat=exp((-5800.2206/(x(j,3)+273.15))+1.3914993-...
                        (0.04860239*(x(j,3)+273.15))+(0.41764768e-4*...
                        ((x(j,3)+273.15)^2))-(0.14452093e-7*((x(j,3)+273.15)^3))+...
                        (6.5459673*log((x(j,3)+273.15)))); %Saturated air vapor pressure 
                        %for air below shade (Pa)
                        Pai_top=rhpsec_top*Paisat_top; %vapor pressure for air above shade
                        %(Pa)
                        Pai=rhpsec*Paisat; %Vapor pressure for air below shade (Pa)
                        wpsec_top=0.622*Pai_top/(P-Pai_top); %humidity ratio of air 
                        %above shade   
                        wpsec=0.622*Pai/(P-Pai); %humidity ratio of air below shade
                        x(j,7)=((Vup*x(j,7))+(V1change*x(j,3)))/(Vup+V1change); %Mixing of temperature of region
                        %above shade and temperature in the region uncovered by shade as
                        %of now but supposed to be above shade. This is represented by
                        %the temperature of the air below the shade.
                        wpsec_top=((Vup*wpsec_top)+(V1change*wpsec))/(Vup+V1change); 
                        %Mixing of humidity of region above shade and humidity in the 
                        %region uncovered by shade as of now but supposed to be above 
                        %shade. This is represented by the humidity of the air below the 
                        %shade.
                        Paisat_top=exp((-5800.2206/(x(j,7)+273.15))+1.3914993-...
                        (0.04860239*(x(j,7)+273.15))+(0.41764768e-4*...
                        ((x(j,7)+273.15)^2))-(0.14452093e-7*((x(j,7)+273.15)^3))+...
                        (6.5459673*log((x(j,7)+273.15)))); %Saturated air vapor 
                        %pressure for air above shade (Pa)
                        Pai_top=(P*wpsec_top)/(0.622+wpsec_top); %air vapor pressure 
                        %for air above shade (Pa)
                        rhpsec_top=Pai_top/Paisat_top; %Relative humidity of air above 
                        %the shade
           
                        po=x(j,:);
                        Told=po;
           
                    end
           
                    %Calculation to obtain the temperature of all components in the 
                    %greenhouse for the current timestep is performed using the same 
                    %controls technique mentioned in the first hour interation above
                    if(j>1&&x(j,3)<TotalTmin(i,1))
           
                        Paisat_top=exp((-5800.2206/(x(j,7)+273.15))+1.3914993-...
                        (0.04860239*(x(j,7)+273.15))+(0.41764768e-4*...
                        ((x(j,7)+273.15)^2))-(0.14452093e-7*((x(j,7)+273.15)^3))+...
                        (6.5459673*log((x(j,7)+273.15)))); %Saturated air vapor pressure 
                        %for air above shade (Pa)
                        Paisat=exp((-5800.2206/(x(j,3)+273.15))+1.3914993-...
                        (0.04860239*(x(j,3)+273.15))+(0.41764768e-4*...
                        ((x(j,3)+273.15)^2))-(0.14452093e-7*((x(j,3)+273.15)^3))+...
                        (6.5459673*log((x(j,3)+273.15)))); %Saturated air vapor pressure for air 
                        %below shade (Pa)
                        Pai_top=rhpsec_top*Paisat_top; % vapor pressure for air above shade (Pa)
                        Pai=rhpsec*Paisat; %vapor pressure for air below shade (Pa)
                        wpsec_top=0.622*Pai_top/(P-Pai_top); %humidity ratio of air above shade   
                        wpsec=0.622*Pai/(P-Pai); %humidity ratio of air below shade
                        x(j,7)=((Vup*x(j,7))+(V1change*x(j,3)))/(Vup+V1change); %Mixing of 
                        %temperature of region above shade and temperature in the region 
                        %uncovered by shade as of now but supposed to be above shade. 
                        %This is represented by the temperature of the air below the shade.
                        wpsec_top=((Vup*wpsec_top)+(V1change*wpsec))/(Vup+V1change); 
                       %Mixing of humidity of region above shade and humidity in the region 
                       %uncovered by shade as of now but supposed to be above shade. 
                       %This is represented by the humidity of the air below the shade.
                       Paisat_top=exp((-5800.2206/(x(j,7)+273.15))+1.3914993-...
                       (0.04860239*(x(j,7)+273.15))+(0.41764768e-4*...
                       ((x(j,7)+273.15)^2))-(0.14452093e-7*((x(j,7)+273.15)^3))+...
                       (6.5459673*log((x(j,7)+273.15)))); %Saturated air vapor pressure for air 
                       %above shade (Pa)
                       Pai_top=(P*wpsec_top)/(0.622+wpsec_top); %air vapor pressure for air above 
                       %shade (Pa) 
                       rhpsec_top=Pai_top/Paisat_top; %Relative humidity of air above the shade
                       po=x(j,:); %Assign the current value of temperature of all components to po
                       Told=po; %Assign the value in po to Told 
                    end
                  
           
           if(x(j,3)>=TotalTmax(i,1)) %If ambient air temperature is 
                    %greater than the maximum set-point temperature
                        
                nhum(j,1)=0;
                signalcool=1; 
                Q(j,1)=0; 
                if(Totaltemp(i,1)>TotalTmax(i,1))

                        
                    fp = 1; 
                    nmax = ((nsat*Avft)/(LAI*60*V1newft)); 
                    nnew = nmax; 
                    vmax = nmax*V1new;
                    v = vmax; 
                    ns(j,1)=timestep*nmax; 
                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                    timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                    transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,...
                    Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,...
                    sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),...
                    Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
  
                else
                   if(j>1)
                            if(x(j-1,3)>=TotalTmax(i,1)&&x(j-1,3)<x(j,3))
                                fp=1;
                                coolfast=1;
                            else
                                fp=0;
                            end
                        else  
                        fp = 0; %Fraction of air flowing through the pad system
                        end
                    nmax = ((nsat*Avft)/(LAI*60*V1newft)); 
                    nnew = nmax; 
                    vmax = nmax*V1new; 
                    v = vmax; 
                    ns(j,1)=timestep*nmax; 
                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                    timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                    transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,...
                    Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,...
                    Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,V1new,Totalho(i,1),LAI,TA,v,...
                    Twb(i,1),Q(j,1),Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,...
                    Awall,z),po,options);
        
                end
        
                if(i>1) 
                    if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0)
                        nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                    end
        
                end
        
           end
        
            if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0)
                if(i>1)
                    if(TotalTmin(i-1,1)~=TotalTmin(i,1)) 
                        trigger=1; 
                    end
         
                end
          
                signalheat=0; 
                    if(signalcool==1) 
                        Q(j,1)=0; 
                        nhum(j,1)=0;
                        if(Totaltemp(i,1)<=TotalTmax(i,1)) 
                            
                            if(coolfast==1)
                                fp=1;
                            else
                                fp =0; %Fraction of air flowing through the pad system
                            end
                              
                            nmax = ((nsat*Avft)/(LAI*60*V1newft)); 
                            vmax = nmax*V1new;  
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2)); 
                            nnew = v/V1new; 
                            ns(j,1)=timestep*nnew; 
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                            kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                            Fvcplant,Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,...
                            Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,...
                            Ec,Tgw,fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                            Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,...
                            Awall,z),po,options);
          
                        else
              
                            fp = 1;
                            nmax = ((nsat*Avft)/(LAI*60*V1newft)); 
                            vmax = nmax*V1new; 
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));
                            nnew = v/V1new; 
                            ns(j,1)=timestep*nnew; 
                            x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                            tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                            Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                            dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                            fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                            Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
         
                        end
          
                    else
           
                        if(signalvent==1)
                            nshade=nsat/30; 
                            nhum(j,1)=((nshade*Avft)/(LAI*60*V1newft));%Since this is used for 
                            %humidity control, it is assigned to nhum.
                            nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                            %to nhum.      
                        end
              
                        if(signalvent==0)
                            nshade=0; 
                            nhum(j,1)=0;
                        end
              
                         Q(j,1)=0; 
                         fp = 0;   
                         nmax = ((nshade*Avft)/(LAI*60*V1newft)); 
                         vmax = nmax*V1new;
                         v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                         TotalTmin(i,1))/2)+(pi()/2));
                        nnew = v/V1new; 
                        ns(j,1)=timestep*nnew; 
                        x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                        Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                        tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                        Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                        dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                        Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
               
                    end
       
                    if(i>1) 
                        if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0)
           
                            nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                        end
        
                    end
        
            end
        
           if(x(j,3)<=TotalTmin(i,1)) 
                nhum(j,1)=0;
                nshade=0; 
                signalheat=1; 
                signalcool=0; 
                Q(j,1)=Qlossmaxwattsarea; 
                if(i>1) 
                    if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                        if(TotalTmin(i,1)-x(j,3)>0) 
                            Qsl(i,1)=Qsl(i,1)+Q(j,1); 
                        end
                    end
                end
                         
                fp = 0; 
                nmax = ((nshade*Avft)/(LAI*60*V1newft));  
                nnew = nmax; 
                vmax = nmax*V1new; 
                v = vmax; 
                ns(j,1)=timestep*nmax; 
                x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,Netenergyroof(i,1),...
                Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,...
                Tgw,fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
               
           end
         
           if(x(j,3)>TotalTmin(i,1)&&x(j,3)-TotalTmid(i,1)<=0) 
                signalcool=0; 
                coolfast=0;
                if(signalheat==1) 
                    nhum(j,1)=0;
                    Q(j,1)=Qlossmaxwattsarea; 
                    if(i>1) 
                        if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                            if(TotalTmid(i,1)-x(j,3)>0) 
                                Qsl(i,1)=Qsl(i,1)+Q(j,1); 
                         
                            end
          
                        end
          
                    end
          
                    fp = 0; 
                    nmax = ((nshade*Avft)/(LAI*60*V1newft));
                    vmax = nmax*V1new; 
                    v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                        TotalTmin(i,1))/2)+(pi()/2));
                    nnew = v/V1new; 
                    ns(j,1)=timestep*nnew; 
                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                    Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                    tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                    Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                    dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                    fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                    Totalnetenergy(i,1),tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
          
                else
              
                    if(signalvent==1) 
                        nshade=nsat/30; 
                        nhum(j,1)=((nshade*Avft)/(LAI*60*V1newft));%Since this is used for 
                        %humidity control, it is assigned to nhum.
                        nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                        %to nhum.      
                    end
          
                    if(signalvent==0) 
                        nshade=0; 
                        nhum(j,1)=0;
                    end
                    Q(j,1)=0; 
                    fp = 0;   
                    nmax = ((nshade*Avft)/(LAI*60*V1newft)); 
                    vmax = nmax*V1new; 
                     v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                     TotalTmin(i,1))/2)+(pi()/2));
                    nnew = v/V1new; 
                    ns(j,1)=timestep*nnew; 
                    x(j+1,:)=fsolve(@(z)hvac_fnroofshade2(heat_totallamps(i,1),achinf,...
                    Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                    tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                    Qbenchheat,Netenergyroof(i,1),Ts,Mp,cpw,Totaltemp(i,1),...
                    dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                    fp,V,V1new,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                    tnsmvty,c1,c2,c3,c4,c5,c6,Awall,z),po,options);
         
                end
          
                if(i>1) 
                    if(TotalTmax(i-1,1)~=TotalTmax(i,1)) 
                        trigger_cool=1;
                    end

                end

           end

          if(x(j+1,2)<Tplants(i,1)) 
                signalplantheat=1; 
                Qbenchheat=50; 
                Qplantheat(j+1,1)=timestep*Qbenchheat; 
        
          end
          
          if(x(j+1,2)>=Tplants(i,1)&&x(j+1,2)<=Tplants(i,1)+0.5)
          
              if(signalplantheat==1) 
                  Qbenchheat=50;
                  Qplantheat(j+1,1)=timestep*Qbenchheat; 
              else
              
                  Qbenchheat=0; 
                  Qplantheat(j+1,1)=Qbenchheat; 
              end
          
          end
      
          if(x(j+1,2)>Tplants(i,1)+0.5) 
            signalplantheat=0; 
            Qbenchheat=0; 
            Qplantheat(j+1,1)=Qbenchheat; 
          end     
         [trans,vent,infiltration,rhsec,mhum]=humidity(efficiencyevap,Aground,...
         achinf,timestep,dena,cpa,fp,rhpsec,Tao(i,1),...
         rhao(i,1),ns(j,1),V1new,P,L,LAI,Netenergy(i,1),c1,c2,c3,c4,c5,c6,Told); 
         Vtop=V-V1new; 
         rhsectop=humidityup(Aground,achinf,timestep,dena,cpa,rhpsec_top,Tao(i,1),...
         rhao(i,1),Vtop,P,L,Told); 
         rhpsec=rhsec; 
         rhpsec_top=rhsectop; 
         trans_mat(j,1)=trans; 
         vent_mat(j,1)=vent;     
         inf_mat(j,1)=infiltration; 
         diff=trans-vent-infiltration; 
         if(diff>0) 
            dehum(j,1)=diff; 
            hum(j,1)=0;
         else
    
            hum(j,1)=-diff; 
            dehum(j,1)=0;
         end

            humw(j,1)=mhum; 
            if(x(j,3)>Tao(i,1)) 
                Qheatremoved(j,1)=dena*cpa*ns(j,1)*(V1new/(length*width))*(x(j,3)-Tao(i,1));
                Qheatadded(j,1)=0;
    
            else
                Qheatadded(j,1)=dena*cpa*ns(j,1)*(V1new/(length*width))*(x(j,3)-Tao(i,1));
                Qheatremoved(j,1)=0;
   
            end


            if(Totalnetenergy(i,1)==0) 
                if(rhsec>rhnight(2)) 
                    signalvent=1;
                end

                if(rhsec<=rhnight(1))
                    signalvent=0; 
                end
            else
    
                if(rhsec>rhday(2)) 
                    signalvent=1; 
                end

                if(rhsec<=rhday(1)) 
                    signalvent=0; 
                end

            end
            maxach=nsat*Avft*60/(LAI*V1newft);
            maxacheachfan=maxach/2;
            nheachfan=ns(j,1)/2;
            timeperhour=nheachfan/maxacheachfan;
            ventilation_powersec(j,1)=Voltage*Current*phasefactor*RMSvalue*...
            timeperhour*2/1000;
            if(fp==1)
                [watercons_evap]=evapcooling_water(dena,V1new,ns(j,1),Aground,Totaltemp(i,1),...
                Totalrhao(i,1),efficiencyevap);
                watercons_evapsec(j,1)=watercons_evap;
            else
                watercons_evapsec(j,1)=0;
            end

           else %Once shades are completely rolled back out

                x(j,7)=x(j,3); %Temperature of air above shade and region below shade (C) 
                %are same
                rhsectop=rhsec; % Relative humidity of air below and above shade 
                %are similar in the current step
                rhpsec_top=rhsectop; %Assigning relative humidity found in current step 
                %as the previous step value for new set of iterations.

                %Calculation to obtain the temperature of all components in the 
                %greenhouse for the current timestep
                %is performed using the same controls technique mentioned in the
                %first hour interation above

                po=x(j,:);  
                Told=po; 
                if(x(j,3)>=TotalTmax(i,1)) 
                    nhum(j,1)=0;
                    signalcool=1; 
                    Q(j,1)=0; 
                    if(Totaltemp(i,1)>TotalTmax(i,1)) %If ambient air temperature is 
                    %greater than the maximum set-point temperature

                        fp = 1; 
                        nmax = ((nsat*Avft)/(LAI*60*Vft)); 
                        nnew = nmax; 
                        vmax = nmax*V; 
                           v = vmax; 
                        ns(j,1)=timestep*nmax; 
                        x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                        timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                        transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,Ts,Mp,cpw,...
                        Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,...
                        Tgw,fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                        Totalnetenergy(i,1),c1,c2,c3,c4,c5,c6,Awall,z),po,options);

                    else 
    
                        if(j>1)
                            if(x(j-1,3)>=TotalTmax(i,1)&&x(j-1,3)<x(j,3))
                                fp=1;
                                coolfast=1;
                            else
                                fp=0;
                            end
                        else  
                        fp = 0; %Fraction of air flowing through the pad system
                        end
                        nmax = ((nsat*Avft)/(LAI*60*Vft)); 
                        nnew = nmax; 
                        vmax = nmax*V; 
                         v = vmax; 
                        ns(j,1)=timestep*nmax; 
                        x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                        Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                        tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                        Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,...
                        tg,Told,Ac,Ec,Tgw,fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                        Totalnetenergy(i,1),c1,c2,c3,c4,c5,c6,Awall,z),po,options);

                    end

                    if(i>1) 

                        if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0) 
                            nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                        end

                    end

                end


                if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0)  
                    if(i>1)
    
                        if(TotalTmin(i-1,1)~=TotalTmin(i,1)) 
                            trigger=1;
                        end

                    end

                    signalheat=0;
                    if(signalcool==1) 
                        Q(j,1)=0; 
                        nhum(j,1)=0;
                        if(Totaltemp(i,1)<=TotalTmax(i,1))  
                           if(coolfast==1)
                                fp=1;
                            else
                                fp =0; %Fraction of air flowing through the pad system
                           end
                              
                            nmax = ((nsat*Avft)/(LAI*60*Vft)); 
                            vmax = nmax*V; 
                            v =(vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));
                            nnew = v/V; 
                            ns(j,1)=timestep*nnew;
                            x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                            tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                            Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,...
                            Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,Totalho(i,1),LAI,TA,v,...
                            Twb(i,1),Q(j,1),Totalnetenergy(i,1),c1,c2,c3,c4,c5,c6,...
                            Awall,z),po,options);

                        else
    
                            fp = 1; 
                            nmax = ((nsat*Avft)/(LAI*60*Vft));  
                            vmax = nmax*V;  
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));
                            nnew = v/V; 
                            ns(j,1)=timestep*nnew; 
                            x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                            tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                            Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,...
                            Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,Totalho(i,1),LAI,TA,v,...
                            Twb(i,1),Q(j,1),Totalnetenergy(i,1),c1,c2,c3,c4,c5,c6,...
                            Awall,z),po,options);
  
                        end

                    else
    
                        if(signalvent==1) 
                            nshade=nsat/30;  
                            nhum(j,1)=((nshade*Avft)/(LAI*60*Vft));%Since this is 
                            %used for humidity control, it is assigned to nhum.
                            nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                            %to nhum.     
                        end
   
                        if(signalvent==0)
                            nshade=0; 
                            nhum(j,1)=0;
                        end
   
                            Q(j,1)=0;  
                            fp = 0; 
                            nmax = ((nshade*Avft)/(LAI*60*Vft));
                            vmax = nmax*V; 
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));
                            nnew = v/V;
                            ns(j,1)=timestep*nnew;
                            x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                            tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                            Fvcplant,Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,...
                            rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,Totalho(i,1),LAI,...
                            TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),c1,c2,c3,c4,c5,...
                            c6,Awall,z),po,options);
   
                    end

                    if(i>1) 
                        if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0) 
                            nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                        end

                    end

                end


                if(x(j,3)<=TotalTmin(i,1)) 
                    nhum(j,1)=0;          
                    nshade=0; 
                    signalheat=1; 
                    signalcool=0; 
                    Q(j,1)=Qlossmaxwattsarea; 
                    if(i>1) 
                        if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                            if(TotalTmin(i,1)-x(j,3)>0) 
                                Qsl(i,1)=Qsl(i,1)+Q(j,1); 
                            end

                        end

                    end

                    fp = 0; 
                    nmax = ((nshade*Avft)/(LAI*60*Vft));
                    nnew = nmax;
                    vmax = nmax*V;
                    v = vmax;
                    ns(j,1)=timestep*nmax;
                    x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                    timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                    transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,Ts,Mp,cpw,...
                    Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                    fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),c1,...
                    c2,c3,c4,c5,c6,Awall,z),po,options);

                end



                if(x(j,3)>TotalTmin(i,1)&&x(j,3)-TotalTmid(i,1)<=0) 
                    signalcool=0; 
                    coolfast=0;
                    if(signalheat==1) 
                        nhum(j,1)=0;
                        Q(j,1)=Qlossmaxwattsarea; 
                        if(i>1)
                            if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0) 
                                if(TotalTmid(i,1)-x(j,3)>0) 
                                    Qsl(i,1)=Qsl(i,1)+Q(j,1); 
                         
                                end
   
                            end
   
                        end
   
                        fp = 0;
                        nmax = ((nshade*Avft)/(LAI*60*Vft)); 
                        vmax = nmax*V; 
                        v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                        TotalTmin(i,1))/2)+(pi()/2));
                        nnew = v/V; 
                        ns(j,1)=timestep*nnew; 
                        x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                        timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                        transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,Ts,Mp,cpw,...
                        Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                        c1,c2,c3,c4,c5,c6,Awall,z),po,options);
   
                    else
    
                        if(signalvent==1)
                            nshade=nsat/30; 
                            nhum(j,1)=((nshade*Avft)/(LAI*60*Vft));%Since this is used for 
                            %humidity control, it is assigned to nhum.
                            nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                            %to nhum.      
                        end
   
                        if(signalvent==0)
                            nshade=0; 
                            nhum(j,1)=0;
                        end
   
                        Q(j,1)=0; 
                        fp = 0;           
                        nmax = ((nshade*Avft)/(LAI*60*Vft)); 
                        vmax = nmax*V; 
                        v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                        TotalTmin(i,1))/2)+(pi()/2));
                        nnew = v/V; 
                        ns(j,1)=timestep*nnew;  
                        x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),...
                        timestep,Cg,Aground,Fp,P_ground,kr,tc,transmittance_roof,...
                        transmittance_wall,Rs,ts1,ts2,Fvcplant,Qbenchheat,Ts,Mp,cpw,...
                        Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,...
                        fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                        c1,c2,c3,c4,c5,c6,Awall,z),po,options);

                    end

                    if(i>1) 
   
                        if(TotalTmax(i-1,1)~=TotalTmax(i,1)) 
           
                            trigger_cool=1; 
                        end

                    end

                end

                if(x(j+1,2)<Tplants(i,1)) 
                    signalplantheat=1; 
                    Qbenchheat=50; 
                    Qplantheat(j+1,1)=timestep*Qbenchheat; 
                end
      
                if(x(j+1,2)>=Tplants(i,1)&&x(j,2)<=Tplants(i,1)+0.5) 
                    if(signalplantheat==1) 
                        Qbenchheat=50;
                        Qplantheat(j+1,1)=timestep*Qbenchheat; 
                    else
                        Qbenchheat=0; 
                        Qplantheat(j+1,1)=Qbenchheat; 
                    end
          
                end
      
                if(x(j+1,2)>Tplants(i,1)+0.5) 
                    signalplantheat=0; 
                    Qbenchheat=0; 
                    Qplantheat(j+1,1)=Qbenchheat; 
                end
      
                [trans,vent,infiltration,rhsec,mhum]=humidity(efficiencyevap,Aground,...
                achinf,timestep,dena,cpa,fp,rhpsec,Tao(i,1),rhao(i,1),ns(j,1),V,P,L,...
                LAI,Netenergy(i,1),c1,c2,c3,c4,c5,c6,Told); 
                rhsectop=rhsec; 
                rhpsec=rhsec;
                rhpsec_top=rhsectop; 
                trans_mat(j,1)=trans; 
                vent_mat(j,1)=vent; 
                inf_mat(j,1)=infiltration; 
                diff=trans-vent-infiltration;  
                if(diff>0) 
                    dehum(j,1)=diff; 
                    hum(j,1)=0;
                else
    
                    hum(j,1)=-diff; 
                    dehum(j,1)=0;
                end

                humw(j,1)=mhum; 
                if(x(j,3)>Tao(i,1))  
                    Qheatremoved(j,1)=dena*cpa*ns(j,1)*(V/(length*width))*...
                    (x(j,3)-Tao(i,1)); 
                    Qheatadded(j,1)=0;
    
                else
    
                    Qheatadded(j,1)=dena*cpa*ns(j,1)*(V/(length*width))*...
                    (x(j,3)-Tao(i,1));
                    Qheatremoved(j,1)=0;
    
                end


                if(Totalnetenergy(i,1)==0) 
                    if(rhsec>rhnight(2))
                        signalvent=1; 
                    end

                    if(rhsec<=rhnight(1)) 
                        signalvent=0; 
                    end

                else 
                    if(rhsec>rhday(2)) 
                        signalvent=1; 
                    end

                    if(rhsec<=rhday(1)) 
                        signalvent=0; 
                    end

                end
                if(fp==1)
                    [watercons_evap]=evapcooling_water(dena,V,ns(j,1),Aground,Totaltemp(i,1),...
                    Totalrhao(i,1),efficiencyevap);
                    watercons_evapsec(j,1)=watercons_evap;
                else
                    watercons_evapsec(j,1)=0;
                end
                maxach=nsat*Avft*60/(LAI*Vft);
                maxacheachfan=maxach/2;
                nheachfan=ns(j,1)/2;
                timeperhour=nheachfan/maxacheachfan;
                ventilation_powersec(j,1)=Voltage*Current*phasefactor*RMSvalue*...
                timeperhour*2/1000;

                end

                Q_shts(j,1)=timestep*Q(j,1);
                j=j+1;
                end

                humw_matrix(i,1)=sum(humw(1:j-1,1)); 
                rhinhour(i,1)=rhsec; 
                rhinhourtop(i,1)=rhsectop; 
                trans_year(i,1)=sum(trans_mat(1:j-1,1)); 
                trans_year_mass(i,1)=trans_year(i,1)/L; 
                vent_year(i,1)=sum(vent_mat(1:j-1,1)); 
                inf_year(i,1)=sum(inf_mat(1:j-1,1)); 
                Qheatremoved_mat(i,1)=sum(Qheatremoved(1:j-1,1)); 
                Qheatadded_mat(i,1)=sum(Qheatadded(1:j-1,1)); 
                hum_mat(i,1)=sum(hum(1:j-1,1));
                dehum_mat(i,1)=sum(dehum(1:j-1,1)); 
                Qsumheat(i,1)=sum(Q_shts(1:j-1,1)); 
                Qsumplantheat(i,1)=sum(Qplantheat(1:j-1,1)); 
                ventilation_powerhour(i,1)=sum(ventilation_powersec(1:j-1,1));
                watercons_evaphour(i,1)=sum(watercons_evapsec(1:j-1,1));
                nh(i,1)=sum(ns(1:j-1,1)); 
                th(i,:)=x(j,:);
                nhum_m(i,1)=sum(nhum(1:j-1,1)); 
            end
    

            if(Totalnetenergy(i-1,1)>0)
            %If the previous hour also has non zero solar heat gain,
            %then again greenhouse without shades are modelled. All parameters are
            %as same as explained before.
                while(ct_sec<3600)
                    if(j==1)
                        timestep=1;
                    else
              
                        if(x(j,3)>=TotalTmax(i,1))
                            signalcool=1;
                        end
             
                        if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0)
                            signalheat=0;
                        end
                        if(x(j,3)<TotalTmid(i,1)&&x(j,3)-TotalTmin(i,1)>=0)
                            signalcool=0;
                        end
               
                        if(x(j,3)<TotalTmin(i,1))
                            signalheat=1;
                        end
                        if(signalheat==1&&signalplantheat==1)
                            timestep=ts_reduced;
                        else
                     
                            if(signalheat==0&&signalplantheat==1)
                                timestep=timestep+2;
                            else 
                                if(signalheat==0&&signalplantheat==0) 
                                    if(signalvent==1)
                                        if(x(j,3)>x(j-1,3))
                                            timestep=timestep+2;
                                        else
                                            if(x(j-1,3)-x(j,3)<0.1)
                                                timestep=timestep+2;
                                            else
                                                timestep=ts_reduced;
                                            end
                                        end
                         
                                    else
                                        if(signalcool==1)
                                            if(x(j,3)>x(j-1,3))
                                                if(x(j-1,3)<=TotalTmax(i,1))
                                                    timestep=ts_reduced;
                                                else
                                                    timestep=timestep+2;
                                                end
                              
                                            else
                             
                                                if(x(j-1,3)-x(j,3)<0.1)
                                                    timestep=timestep+2;
                                                else
                                 
                                                    timestep=ts_reduced;
                                                end
                             
                                            end
                          
                                        else
                             
                                            timestep=timestep+2;  
                                        end
                         
                                    end
                     
                        
                                else
                                    
                                    if(signalheat==1&&signalplantheat==0)
                                        timestep=ts_reduced;
                                    end
                       
                                end
                     
                            end
                 
                        end
                 
             
                    end
            
                    ct_sec1=ct_sec+timestep;
                    if(ct_sec1>3600)
             
                        while(ct_sec1>3600)
                            timestep=timestep-1;
                            ct_sec1=ct_sec+timestep;
                        end
                    end
                    if(ct_sec1<=3600)
                        ct_sec=ct_sec1;
                    end
                    %Calculation to obtain the temperature of all components 
                    %in the greenhouse for the current timestep
                    %is performed using the same controls technique mentioned in the
                    %first hour interation above          
                    po=x(j,:);  
                    Told=po;  
                    if(x(j,3)>=TotalTmax(i,1))
                        nhum(j,1)=0;
                        signalcool=1;
                        Q(j,1)=0;
                        if(Totaltemp(i,1)>TotalTmax(i,1)) %If ambient air temperature is 
                    %greater than the maximum set-point temperature

                            fp = 1;
                            nmax = ((nsat*Avft)/(LAI*60*Vft));
                            nnew = nmax;
                            vmax = nmax*V;
                            v = vmax;
                            ns(j,1)=timestep*nmax;  
                            x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                            kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                            Fvcplant,Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,...
                            L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,Totalho(i,1),...
                            LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),c1,c2,c3,c4,...
                            c5,c6,Awall,z),po,options);
                        else
                            if(j>1)
                            if(x(j-1,3)>=TotalTmax(i,1)&&x(j-1,3)<x(j,3)&&x(j-1,3)<x(j,3))
                                fp=1;
                                coolfast=1;
                            else
                                fp=0;
                            end
                        else  
                        fp = 0; %Fraction of air flowing through the pad system
                        end
                            nmax = ((nsat*Avft)/(LAI*60*Vft));
                            nnew = nmax;
                            vmax = nmax*V;
                            v = vmax;
                            ns(j,1)=timestep*nmax;
                            x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                            kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                            Fvcplant,Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,...
                            P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,Totalho(i,1),...
                            LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),c1,c2,c3,c4,...
                            c5,c6,Awall,z),po,options);
                        end

                        if(i>1)
                            if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0)
                                nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                            end

                        end

                    end
                    if(x(j,3)<TotalTmax(i,1)&&x(j,3)-TotalTmid(i,1)>=0)
                        if(i>1)
                            if(TotalTmin(i-1,1)~=TotalTmin(i,1))
                                trigger=1;
                            end

                        end

                        signalheat=0;
                        if(signalcool==1)
                            nhum(j,1)=0;
                            Q(j,1)=0;
                            if(Totaltemp(i,1)<=TotalTmax(i,1))
                               if(coolfast==1)
                                fp=1;
                               else
                                fp =0; %Fraction of air flowing through the pad system
                              end
                                nmax = ((nsat*Avft)/(LAI*60*Vft));
                                vmax = nmax*V;
                                v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                TotalTmin(i,1))/2)+(pi()/2));
                                nnew = v/V;
                                ns(j,1)=timestep*nnew;
                                x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                                kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,...
                                ts2,Fvcplant,Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,...
                                cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,...
                                Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                                c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                            else
    
                                fp = 1;
                                nmax = ((nsat*Avft)/(LAI*60*Vft));
                                vmax = nmax*V;
                                v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                TotalTmin(i,1))/2)+(pi()/2));
                                nnew = v/V;
                                ns(j,1)=timestep*nnew;
                                x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,...
                                kr,tc,transmittance_roof,transmittance_wall,Rs,ts1,...
                                ts2,Fvcplant,Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),...
                                dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,...
                                Ac,Ec,Tgw,fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                                Totalnetenergy(i,1),c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                            end

                        else
    
                            if(signalvent==1)
                                nshade=nsat/30;
                                nhum(j,1)=((nshade*Avft)/(LAI*60*Vft));%Since this is 
                                %used for humidity control, it is assigned to nhum.
                                nhum(j,1)=timestep*nhum(j,1); %Assign air change rate for every second 
                                %to nhum.     
                            end
   
                            if(signalvent==0)
                                nshade=0;
                                nhum(j,1)=0;
                            end
   
                                Q(j,1)=0;
                                fp = 0; 
                                nmax = ((nshade*Avft)/(LAI*60*Vft));
                                vmax = nmax*V;
                                v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                                TotalTmin(i,1))/2)+(pi()/2));
                                nnew = v/V;
                                ns(j,1)=timestep*nnew;
                                x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                                Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,...
                                P_ground,kr,tc,transmittance_roof,transmittance_wall,...
                                Rs,ts1,ts2,Fvcplant,Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),...
                                dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,...
                                Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),Totalnetenergy(i,1),...
                                c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        end

                        if(i>1)
                            if(TotalTmax(i-1,1)~=TotalTmax(i,1)&&trigger_cool==0)
                                nh_sl(i,1)=nh_sl(i,1)+ns(j,1); 
                            end

                        end

                    end
                    if(x(j,3)<=TotalTmin(i,1))
                        nshade=0;
                        nhum(j,1)=0;
                        signalheat=1;
                        signalcool=0;
                        Q(j,1)=Qlossmaxwattsarea;
                        if(i>1)
                            if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0)
                                if(TotalTmin(i,1)-x(j,3)>0)
                                    Qsl(i,1)=Qsl(i,1)+Q(j,1);
                                end

                            end

                        end

                        fp = 0;
                        nmax = ((nshade*Avft)/(LAI*60*Vft));
                        nnew = nmax;
                        vmax = nmax*V;
                        v = vmax;
                        ns(j,1)=timestep*nmax;    
                        x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                        tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                        Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,sig,kg,tg,Told,...
                        Ac,Ec,Tgw,fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                        Totalnetenergy(i,1),c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                    end
                    
                    if(x(j,3)>TotalTmin(i,1)&&x(j,3)-TotalTmid(i,1)<=0)
                        signalcool=0;
                        coolfast=0;
                        if(signalheat==1)
                            nhum(j,1)=0;
                            Q(j,1)=Qlossmaxwattsarea; 
                            if(i>1)
                                if(TotalTmin(i-1,1)~=TotalTmin(i,1)&&trigger==0)
                                    if(TotalTmid(i,1)-x(j,3)>0)
                                        Qsl(i,1)=Qsl(i,1)+Q(j,1);
                         
                                    end
   
                                end
   
                            end
   
                            fp = 0;
                            nmax = ((nshade*Avft)/(LAI*60*Vft));
                            vmax = nmax*V;
                            v = (vmax/pi())*(atan((1.5*po(1,3))-(TotalTmax(i,1)+...
                            TotalTmin(i,1))/2)+(pi()/2));
                            nnew = v/V;
                            ns(j,1)=timestep*nnew;    
                            x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,...
                            Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                            tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,Fvcplant,...
                            Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,P,L,rhpsec,Ev,...
                            sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                            Totalnetenergy(i,1),c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        else
                            if(signalvent==1)
                                nshade=nsat/30;
                                nhum(j,1)=((nshade*Avft)/(LAI*60*Vft));
                                %Since this is used for humidity control, 
                                %it is assigned to nhum.
                                nhum(j,1)=timestep*nhum(j,1); %Assign air change rate 
                                %for every second to nhum.     
                            end
   
                            if(signalvent==0)
                                nshade=0;
                                nhum(j,1)=0;
                            end
   
                                Q(j,1)=0;
                                fp = 0;               
                                nmax = ((nshade*Avft)/(LAI*60*Vft));
                                vmax = nmax*V;
                                v = (vmax/pi())*(atan((1.5*po(1,3))-...
                                (TotalTmax(i,1)+TotalTmin(i,1))/2)+(pi()/2));
                                nnew = v/V;
                                ns(j,1)=timestep*nnew;
                                x(j+1,:)=fsolve(@(z)hvac_fnroof2(heat_totallamps(i,1),achinf,Netenergyroofabs(i,1),timestep,Cg,Aground,Fp,P_ground,kr,...
                                tc,transmittance_roof,transmittance_wall,Rs,ts1,ts2,...
                                Fvcplant,Qbenchheat,Ts,Mp,cpw,Totaltemp(i,1),dena,cpa,...
                                P,L,rhpsec,Ev,sig,kg,tg,Told,Ac,Ec,Tgw,fp,V,Totalho(i,1),LAI,TA,v,Twb(i,1),Q(j,1),...
                                Totalnetenergy(i,1),c1,c2,c3,c4,c5,c6,Awall,z),po,options);
                        end

                        if(i>1)
                            if(TotalTmax(i-1,1)~=TotalTmax(i,1))
                                trigger_cool=1;
                            end

                        end

                    end

                    if(x(j+1,2)<Tplants(i,1))
                        signalplantheat=1;
                        Qbenchheat=50;
                        Qplantheat(j+1,1)=timestep*Qbenchheat;
                    end
      
                    if(x(j+1,2)>=Tplants(i,1)&&x(j+1,2)<=Tplants(i,1)+0.5)
                        if(signalplantheat==1)
                            Qbenchheat=50;
                            Qplantheat(j+1,1)=timestep*Qbenchheat; 
                        else
              
                            Qbenchheat=0;
                            Qplantheat(j+1,1)=Qbenchheat;
                        end
          
                    end
      
                    if(x(j+1,2)>Tplants(i,1)+0.5)
                        signalplantheat=0;
                        Qbenchheat=0;
                        Qplantheat(j+1,1)=Qbenchheat;
                    end
      
                    [trans,vent,infiltration,rhsec,mhum]=humidity(efficiencyevap,...
                     Aground,achinf,timestep,dena,cpa,fp,rhpsec,Tao(i,1),...
                     rhao(i,1),ns(j,1),V,P,L,LAI,Netenergy(i,1),c1,c2,c3,c4,c5,c6,Told);
                     rhsectop=rhsec;
                     rhpsec=rhsec;
                     rhpsec_top=rhsectop;
                     trans_mat(j,1)=trans;
                     vent_mat(j,1)=vent;
                     inf_mat(j,1)=infiltration;
                     diff=trans-vent-infiltration;
                     if(diff>0)
                        dehum(j,1)=diff;
                        hum(j,1)=0;
                     else
    
                        hum(j,1)=-diff;
                        dehum(j,1)=0;
                     end

                        humw(j,1)=mhum;
                        if(x(j,3)>Tao(i,1))
                            Qheatremoved(j,1)=dena*cpa*ns(j,1)*(V/(length*width))*...
                            (x(j,3)-Tao(i,1));
                            Qheatadded(j,1)=0;
                        else
    
                            Qheatadded(j,1)=dena*cpa*ns(j,1)*(V/(length*width))*...
                            (x(j,3)-Tao(i,1));
                            Qheatremoved(j,1)=0;
                        end

                        if(Totalnetenergy(i,1)==0)
                            if(rhsec>rhnight(2))
                                signalvent=1;
                            end

                            if(rhsec<=rhnight(1))
                                signalvent=0;
                            end

                        else
                            if(rhsec>rhday(2))
                                signalvent=1;
                            end

                            if(rhsec<=rhday(1))
                                signalvent=0;
                            end

                        end

                        Q_shts(j,1)=timestep*Q(j,1);
                        maxach=nsat*Avft*60/(LAI*Vft);
                        maxacheachfan=maxach/2;
                        nheachfan=ns(j,1)/2;
                        timeperhour=nheachfan/maxacheachfan;
                        ventilation_powersec(j,1)=Voltage*Current*phasefactor*RMSvalue*...
                        timeperhour*2/1000;
                        if(fp==1)
                            [watercons_evap]=evapcooling_water(dena,V,ns(j,1),Aground,Totaltemp(i,1),...
                            Totalrhao(i,1),efficiencyevap);
                            watercons_evapsec(j,1)=watercons_evap;
                        else
                            watercons_evapsec(j,1)=0;
                        end
                     
                        j=j+1;
                        
                end
                             
                humw_matrix(i,1)=sum(humw(1:j-1,1));
                rhinhour(i,1)=rhsec;
                rhinhourtop(i,1)=rhsectop;
                trans_year(i,1)=sum(trans_mat(1:j-1,1));
                trans_year_mass(i,1)=trans_year(i,1)/L;
                vent_year(i,1)=sum(vent_mat(1:j-1,1));
                inf_year(i,1)=sum(inf_mat(1:j-1,1));
                Qheatremoved_mat(i,1)=sum(Qheatremoved(1:j-1,1));
                Qheatadded_mat(i,1)=sum(Qheatadded(1:j-1,1));
                hum_mat(i,1)=sum(hum(1:j-1,1));
                dehum_mat(i,1)=sum(dehum(1:j-1,1));
                Qsumheat(i,1)=sum(Q_shts(1:j-1,1));
                Qsumplantheat(i,1)=sum(Qplantheat(1:j-1,1));
                ventilation_powerhour(i,1)=sum(ventilation_powersec(1:j-1,1));
                watercons_evaphour(i,1)=sum(watercons_evapsec(1:j-1,1));
                nh(i,1)=sum(ns(1:j-1,1));
                th(i,:)=x(j,:);
                nhum_m(i,1)=sum(nhum(1:j-1,1));
            end

        end
                       
end
toc
Qtotalheat=Qsumheat+Qsumplantheat; %Total heat which includes space heating and heat supplied to the plant (W/m2)
for i=1:8760
    if(nhum_m(i,1)>nh(i,1))
        nhum_m(i,1)=nh(i,1); %Air changes per hour to control humidity.
    end
end
Powerday1=zeros(365,1); %Daily solar power generation (Wh/m2-day)
for b=1:365
    for c=(b*24)-23:(b*24)
       Powerday1(b,1)=Powerday1(b,1)+Pouter(c,1)+Poutwr(c,1)+Pouterd(c,1)+Poutwrd(c,1);
    end
end
%Hourly solar power generation (Wh/m2-hour) 
for i=1:8760
    Powerhour(i,1)=Pouter(i,1)+Poutwr(i,1)+Pouterd(i,1)+Poutwrd(i,1);
end
Powerhour=Powerhour/1000; %Solar power generation (kWh/m2-hour) 
Powerday1=Powerday1/1000; %Daily solar power generation (kWh/m2-day)
Powermonth=zeros(12,1); %Monthly solar power generation (kWh/m2-day)
Powermonth(1,1)=sum(Powerday1(1:31,1)); 
Powermonth(2,1)=sum(Powerday1(32:59,1));
Powermonth(3,1)=sum(Powerday1(60:90,1));
Powermonth(4,1)=sum(Powerday1(91:120,1));
Powermonth(5,1)=sum(Powerday1(121:151,1));
Powermonth(6,1)=sum(Powerday1(152:181,1));
Powermonth(7,1)=sum(Powerday1(182:212,1));
Powermonth(8,1)=sum(Powerday1(213:243,1));
Powermonth(9,1)=sum(Powerday1(244:273,1));
Powermonth(10,1)=sum(Powerday1(274:304,1));
Powermonth(11,1)=sum(Powerday1(305:334,1));
Powermonth(12,1)=sum(Powerday1(335:365,1));
%save('t_150_tempchange.mat'); %Save all results
matFileName = fullfile(pwd, sprintf('PTB7TH_IEICO4F_AN_%d.mat',pcov*100)); %Save all results
save(matFileName);
end